@@ -1,12 +1,11 @@
 #!/usr/bin/env python
-# $Id: 4560b6c on Wed Oct 2 17:10:50 2013 +0200 by Benedict Verhegghe $
 ##
-##  This file is part of pyFormex 0.9.1  (Tue Oct 15 21:05:25 CEST 2013)
+##  This file is part of pyFormex 1.0.5  (Sat Feb 16 10:40:32 CET 2019)
 ##  pyFormex is a tool for generating, manipulating and transforming 3D
 ##  geometrical models by sequences of mathematical operations.
 ##  Home page: http://pyformex.org
 ##  Project page:  http://savannah.nongnu.org/projects/pyformex/
-##  Copyright 2004-2013 (C) Benedict Verhegghe (benedict.verhegghe@ugent.be)
+##  Copyright 2004-2018 (C) Benedict Verhegghe (benedict.verhegghe@ugent.be)
 ##  Distributed under the GNU General Public License version 3 or later.
 ##
 ##  This program is free software: you can redistribute it and/or modify
@@ -28,6 +27,7 @@
 This script creates the list of files to be included in
 the pyFormex source distribution.
 """
+from __future__ import print_function
 import os,re
 
 def prefixFiles(prefix,files):
@@ -40,8 +40,8 @@ def matchMany(regexps,target):
 
 
 def matchCount(regexps,target):
-    """Return the number of matches of target to  regexps."""
-    return len(filter(None,matchMany(regexps,target)))
+    """Return the number of matches of target to regexps."""
+    return len([ m for m in matchMany(regexps,target) if m ])
 
 
 def matchAny(regexps,target):
@@ -87,7 +87,7 @@ def listTree(path,listdirs=True,topdown=True,sorted=False,excludedirs=[],exclude
         if listdirs and topdown:
             filelist.append(root)
         if excludefiles:
-            files = [ f for f in files if matchNone(excludefiles,f) ]
+            files = [ f for f in files if not matchAny(excludefiles,f) ]
         if includefiles:
             files = [ f for f in files if matchAny(includefiles,f) ]
         filelist.extend(prefixFiles(root,files))
@@ -125,40 +125,49 @@ DATA_FILES = listTree(
     excludefiles=['.*\.pyc','.*~$','PTAPE.*'],
     includefiles=[
         'README',
-        'benedict_6.jpg',
-        'bifurcation.off',
-        'blippo.pgf',
-        'butterfly.png',
-        'hesperia-nieve.prop',
-        'horse.off',
-        'horse.pgf',
-        'materials.db',
-        'sections.db',
-        'splines.pgf',
-        'supershape.txt',
-        'teapot.off',
-        'world.jpg',
+        'template.py',
+        'benedict_6\.jpg',
+        'bifurcation\.off',
+        'blippo\.pgf',
+        'blippok\.ttf',
+        'butterfly\.png',
+        'fewgl\.js',
+        'hesperia-nieve\.prop',
+        'horse\.off',
+        'horse\.pgf',
+        'mark_cross\.png',
+        'materials\.db',
+        'sections\.db',
+        'splines\.pgf',
+        'supershape\.txt',
+        'teapot\.off',
+        'world\.jpg',
+        'xtk_xdat\.gui\.js',
+        ],
+    ) + listTree(
+    'pyformex/glsl',listdirs=False,sorted=True,
+    includefiles=[
+        '.*\.c',
         ],
     )
 
-
 # scripts to install extra programs
 EXTRA_FILES = listTree(
     'pyformex/extra',listdirs=True,sorted=True,
     includedirs=[
         'calpy',
         'dxfparser',
+###        'freetype-py',  now included in pyformex
         'gts',
         'postabq',
         'pygl2ps',
-        'tetgen'
         ],
     excludefiles=['.*~$','.*\.1\.rst'],
     includefiles=[
         'README',
         'Makefile',
         '.*\.sh$',
-        '.*\.rst$'
+        '.*\.rst$',
         '.*\.patch$',
         '.*\.c$',
         '.*\.cc$',
@@ -167,6 +176,7 @@ EXTRA_FILES = listTree(
         '.*\.py$',
         '.*\.1$',
         '.*\.pc$',
+#        'freetype-py-0.4.1.tar.gz',
         ],
     )
 
@@ -189,65 +199,69 @@ DIST_FILES = [
     'README',
     'COPYING',
     'Description',
+#    'Makefile',
     'ReleaseNotes',
     'manifest.py',
     'setup.py',
     'setup.cfg',
     ] + \
     listTree('pyformex',listdirs=False,sorted=True,
-             excludedirs=['.svn'],
-             includedirs=['gui','plugins'],
+             includedirs=['gui','menus','plugins','opengl','fe'],
              includefiles=['.*\.py$','pyformex(rc)?$','pyformex.conf$'],
              excludefiles=['core.py','curvetools.py','backports.py'],
              ) + \
+    listTree('pyformex/freetype',listdirs=False,sorted=True,
+             includedirs=['ft_enums'],
+             includefiles=['.*\.py$'],
+             ) + \
     listTree('pyformex/icons',listdirs=False,sorted=True,
-             excludedirs=['.svn'],
-             includefiles=['README','.*\.xpm$','pyformex.*\.png$']
+             includefiles=['README','.*\.xpm$','.*\.png$']
              ) + \
     listTree('pyformex/lib',listdirs=False,sorted=True,
-             excludedirs=['.svn'],
              includefiles=['.*\.c$','.*\.py$']
              ) + \
     listTree('pyformex/bin',listdirs=False,sorted=True,
-             excludedirs=['.svn'],
              excludefiles=['.*~$'],
              ) + \
     listTree('pyformex/examples',listdirs=False,sorted=True,
-             excludedirs=['.svn','Demos'],
+             excludedirs=['Demos'],
              excludefiles=['.*\.pyc','.*~$',
-#                           'NurbsCircle.py',  # missing nurbs
-#                           'NurbsSurface.py',     # idem
                            ],
              includefiles=['[_A-Z].*\.py$','apps.cat','README']
              ) + \
+    listTree('pyformex/vtk_light',listdirs=False,sorted=True,
+             includedirs=['util'],
+             includefiles=['README','.*\.py$'],
+             ) + \
     DATA_FILES + \
     DOC_FILES + \
     EXTRA_FILES
 
 
 for i in OTHER_DATA:
-   DIST_FILES += i[1]
+    DIST_FILES += i[1]
+
 
 if __name__ == '__main__':
-   import sys
+    import sys
 
-   todo = sys.argv[1:]
-   if not todo:
-      todo = ['doc','data','dist']
+    todo = sys.argv[1:]
+    if not todo:
+        todo = ['doc','data','dist']
 
-   for a in todo:
-      if a == 'doc':
-         print "=========DOC_FILES========="
-         print '\n'.join(DOC_FILES)
-      elif a == 'data':
-         print "=========DATA_FILES========"
-         print '\n'.join(DATA_FILES)
-      elif a == 'other':
-         print "=========OTHER_DATA========"
-         for i in OTHER_DATA:
-            print '\n'.join(i[1])
-      else:
-         print "=========DIST_FILES========"
-         print '\n'.join(DIST_FILES)
+    for a in todo:
+        if a == 'doc':
+            print("=========DOC_FILES=========")
+            print('\n'.join(DOC_FILES))
+        elif a == 'data':
+            print("=========DATA_FILES========")
+            print('\n'.join(DATA_FILES))
+        elif a == 'other':
+            print("=========OTHER_DATA========")
+            for i in OTHER_DATA:
+                print('\n'.join(i[1]))
+        else:
+            print("=========DIST_FILES========")
+            print('\n'.join(DIST_FILES))
 
 # End
