@@ -1,11 +1,11 @@
-# $Id: a796130 on Sun Jun 30 16:20:08 2013 +0200 by Benedict Verhegghe $
+#
 ##
-##  This file is part of pyFormex 0.9.1  (Tue Oct 15 21:05:25 CEST 2013)
+##  This file is part of pyFormex 1.0.5  (Sat Feb 16 10:40:32 CET 2019)
 ##  pyFormex is a tool for generating, manipulating and transforming 3D
 ##  geometrical models by sequences of mathematical operations.
 ##  Home page: http://pyformex.org
 ##  Project page:  http://savannah.nongnu.org/projects/pyformex/
-##  Copyright 2004-2013 (C) Benedict Verhegghe (benedict.verhegghe@ugent.be)
+##  Copyright 2004-2018 (C) Benedict Verhegghe (benedict.verhegghe@ugent.be)
 ##  Distributed under the GNU General Public License version 3 or later.
 ##
 ##  This program is free software: you can redistribute it and/or modify
@@ -25,10 +25,11 @@
 
 This module defines the Collection class.
 """
-from __future__ import print_function
+from __future__ import absolute_import, division, print_function
+
 
 import pyformex as pf
-from arraytools import *
+import numpy as np
 
 ################# Collection of Actors or Actor Elements ###############
 
@@ -41,6 +42,34 @@ class Collection(object):
     as an integer array with unique values.
     This is e.g. used to identify a set of individual parts of one or more
     OpenGL actors.
+
+    Examples:
+
+    >>> a = Collection()
+    >>> a.add(range(7),3)
+    >>> a.add(range(4))
+    >>> a.remove([2,4],3)
+    >>> print(a)
+    -1 [0 1 2 3]; 3 [0 1 3 5 6];
+    >>> a.add([[2,0],[2,3],[-1,7],[3,88]])
+    >>> print(a)
+    -1 [0 1 2 3 7]; 2 [0 3]; 3 [ 0  1  3  5  6 88];
+    >>> a[2] = [1,2,3]
+    >>> print(a)
+    -1 [0 1 2 3 7]; 2 [1 2 3]; 3 [ 0  1  3  5  6 88];
+    >>> a[2] = []
+    >>> print(a)
+    -1 [0 1 2 3 7]; 3 [ 0  1  3  5  6 88];
+    >>> a.set([[2,0],[2,3],[-1,7],[3,88]])
+    >>> print(a)
+    -1 [7]; 2 [0 3]; 3 [88];
+    >>> print(a.keys())
+    [-1  2  3]
+    >>> print([k for k in a])
+    [-1, 2, 3]
+    >>> 2 in a
+    True
+
     """
     def __init__(self,object_type=None):
         self.d = {}
@@ -51,7 +80,7 @@ class Collection(object):
         return len(self.d)
 
 
-    def setType(self,obj_type):
+    def setType(self, obj_type):
         self.obj_type = obj_type
 
 
@@ -59,7 +88,7 @@ class Collection(object):
         if keys:
             for k in keys:
                 k = int(k)
-                if k in self.d.keys():
+                if k in self.d:
                     del self.d[k]
         else:
             self.d = {}
@@ -73,29 +102,29 @@ class Collection(object):
         separately, or a default value will be used.
 
         data can also be another Collection, if it has the same object
-        typ.
+        type.
         """
-        if isinstance(data,Collection):
+        if isinstance(data, Collection):
             if data.obj_type == self.obj_type:
                 for k in data.d:
-                    self.add(data.d[k],k)
+                    self.add(data.d[k], k)
                 return
                 return
             else:
-                raise ValueError,"Cannot add Collections with different object type"
+                raise ValueError("Cannot add Collections with different object type")
 
         if len(data) == 0:
             return
-        data = asarray(data)
+        data = np.asarray(data)
         if data.ndim == 2:
-            for key in unique(data[:,0]):
-                self.add(data[data[:,0]==key,1],key)
+            for key in np.unique(data[:, 0]):
+                self.add(data[data[:, 0]==key, 1], key)
 
         else:
             key = int(key)
-            data = unique(data)
+            data = np.unique(data)
             if key in self.d:
-                self.d[key] = union1d(self.d[key],data)
+                self.d[key] = np.union1d(self.d[key], data)
             elif data.size > 0:
                 self.d[key] = data
 
@@ -107,99 +136,92 @@ class Collection(object):
         before adding.
         """
         self.clear()
-        self.add(data,key)
+        self.add(data, key)
 
 
     def remove(self,data,key=-1):
         """Remove data from the collection."""
-        if isinstance(data,Collection):
+        if isinstance(data, Collection):
             if data.obj_type == self.obj_type:
                 for k in data.d:
-                    self.remove(data.d[k],k)
+                    self.remove(data.d[k], k)
                 return
             else:
-                raise ValueError,"Cannot remove Collections with different object type"
+                raise ValueError("Cannot remove Collections with different object type")
 
-        data = asarray(data)
+        data = np.asarray(data)
         if data.ndim == 2:
-            for key in unique(data[:,0]):
-                self.remove(data[data[:,0]==key,1],key)
+            for key in np.unique(data[:, 0]):
+                self.remove(data[data[:, 0]==key, 1], key)
 
         else:
             key = int(key)
             if key in self.d:
-                data = setdiff1d(self.d[key],unique(data))
+                data = np.setdiff1d(self.d[key], np.unique(data))
                 if data.size > 0:
                     self.d[key] = data
                 else:
                     del self.d[key]
             else:
-                pf.debug("Not removing from non-existing selection for actor %s" % key,pf.DEBUG.DRAW)
-
-    def has_key(self,key):
-        """Check whether the collection has an entry for the key."""
-        return key in self.d
+                pf.debug("Not removing from non-existing selection for actor %s" % key, pf.DEBUG.DRAW)
 
 
-    def __setitem__(self,key,data):
+    def __contains__(self, key):
+         """Check whether the collection has an entry for the key.
+
+         This inplements the 'in' operator for a Collection.
+         """
+         return key in self.d
+
+
+    def __setitem__(self, key, data):
         """Set new values for the given key."""
         key = int(key)
-        data = unique(data)
+        data = np.unique(data)
         if data.size > 0:
             self.d[key] = data
         else:
             del self.d[key]
 
 
-    def __getitem__(self,key):
+    def __iter__(self):
+        """Return an iterator for the Collection
+
+        The iterator loops over the sorted keys.
+        """
+        return iter(self.keys())
+
+
+    def __getitem__(self, key):
         """Return item with given key."""
         return self.d[key]
 
 
-    def get(self,key,default=[]):
+    def get(self, key, default=[]):
         """Return item with given key or default."""
         key = int(key)
-        return self.d.get(key,default)
+        return self.d.get(key, default)
 
 
     def keys(self):
         """Return a sorted array with the keys"""
-        k = asarray(self.d.keys())
-        k.sort()
-        return k
+        keys = sorted(self.d.keys())
+        return np.asarray(keys)
 
 
     def items(self):
-        """Return a zipped list of keys and values."""
+        """Return an iterator over (key,value) pairs."""
         return self.d.items()
 
 
     def __str__(self):
-        s = ''
-        keys = self.d.keys()
-        keys.sort()
-        for k in keys:
-            s += "%s %s; " % (k,self.d[k])
+        if len(self) == 0:
+            s = 'Empty Collection'
+        else:
+            s = ''
+            for k in self.keys():
+                s += "%s %s; " % (k, self.d[k])
+            s = s.rstrip()
         return s
 
-
-################# Testing ###############
-
-if __name__ == "__main__":
-    print("Testing the Collection object")
-    a = Collection()
-    a.add(range(7),3)
-    a.add(range(4))
-    a.remove([2,4],3)
-    print(a)
-    a.add([[2,0],[2,3],[-1,7],[3,88]])
-    print(a)
-    a[2] = [1,2,3]
-    print(a)
-    a[2] = []
-    print(a)
-    a.set([[2,0],[2,3],[-1,7],[3,88]])
-    print(a)
-
-
 # End
