@@ -1,11 +1,11 @@
-# $Id: 8a9069c on Fri Sep 13 17:26:02 2013 +0200 by Benedict Verhegghe $
+# $Id$
 ##
-##  This file is part of pyFormex 0.9.1  (Tue Oct 15 21:05:25 CEST 2013)
+##  This file is part of pyFormex 1.0.5  (Sat Feb 16 10:40:32 CET 2019)
 ##  pyFormex is a tool for generating, manipulating and transforming 3D
 ##  geometrical models by sequences of mathematical operations.
 ##  Home page: http://pyformex.org
 ##  Project page:  http://savannah.nongnu.org/projects/pyformex/
-##  Copyright 2004-2013 (C) Benedict Verhegghe (benedict.verhegghe@ugent.be)
+##  Copyright 2004-2018 (C) Benedict Verhegghe (benedict.verhegghe@ugent.be)
 ##  Distributed under the GNU General Public License version 3 or later.
 ##
 ##  This program is free software: you can redistribute it and/or modify
@@ -25,17 +25,15 @@
 
 Create a parametric barrel vault.
 """
-from __future__ import print_function
+from __future__ import absolute_import, division, print_function
+
+
 _status = 'checked'
 _level = 'beginner'
 _topics = ['frame']
 _techniques = ['dialog']
-_opengl2 = True
-_opengl2_comments = """
-- Lines are black (propcolor)
-"""
 
-from gui.draw import *
+from pyformex.gui.draw import *
 
 def run():
     global barrel
@@ -43,11 +41,11 @@ def run():
     wireframe()
 
     res = askItems([
-        dict(name='m',value=10,text='number of modules in axial direction'),
-        dict(name='n',value=8,text='number of modules in tangential direction'),
-        dict(name='r',value=10.,text='barrel radius'),
-        dict(name='a',value=180.,text='barrel opening angle'),
-        dict(name='l',value=30.,text='barrel length'),
+        dict(name='m', value=10, text='number of modules in axial direction'),
+        dict(name='n', value=8, text='number of modules in tangential direction'),
+        dict(name='r', value=10., text='barrel radius'),
+        dict(name='a', value=180., text='barrel opening angle'),
+        dict(name='l', value=30., text='barrel length'),
         ])
     if not res:
         return
@@ -55,16 +53,16 @@ def run():
     globals().update(res)
 
     # Diagonals
-    d = Formex('l:5',1).rosette(4,90).translate([1,1,0]).replic2(m,n,2,2)
+    d = Formex('l:5', 1).rosette(4, 90).translate([1, 1, 0]).replicm((m, n), (2, 2))
     # Longitudinals
-    h = Formex('l:1',3).replic2(2*m,2*n+1,1,1)
+    h = Formex('l:1', 3).replicm((2*m, 2*n+1))
     # End bars
-    e = Formex('l:2',0).replic2(2,2*n,2*m,1)
+    e = Formex('l:2', 0).replicm((2, 2*n), (2*m, 1))
     # Create barrel
-    barrel = (d+h+e).rotate(90,1).translate(0,r).scale([1.,a/(2*n),l/(2*m)]).cylindrical()
+    barrel = (d+h+e).rotate(90, 1).translate(0, r).scale([1., a/(2*n), l/(2*m)]).cylindrical()
 
     draw(barrel)
 
-if __name__ == 'draw':
+if __name__ == '__draw__':
     run()
 # End
