@@ -1,11 +1,11 @@
-# $Id: ece1888 on Thu Sep 12 16:54:33 2013 +0200 by Benedict Verhegghe $
+# $Id$
 ##
-##  This file is part of pyFormex 0.9.1  (Tue Oct 15 21:05:25 CEST 2013)
+##  This file is part of pyFormex 1.0.5  (Sat Feb 16 10:40:32 CET 2019)
 ##  pyFormex is a tool for generating, manipulating and transforming 3D
 ##  geometrical models by sequences of mathematical operations.
 ##  Home page: http://pyformex.org
 ##  Project page:  http://savannah.nongnu.org/projects/pyformex/
-##  Copyright 2004-2013 (C) Benedict Verhegghe (benedict.verhegghe@ugent.be)
+##  Copyright 2004-2018 (C) Benedict Verhegghe (benedict.verhegghe@ugent.be)
 ##  Distributed under the GNU General Public License version 3 or later.
 ##
 ##  This program is free software: you can redistribute it and/or modify
@@ -24,19 +24,20 @@
 """Baumkuchen Vault
 
 """
-from __future__ import print_function
+from __future__ import absolute_import, division, print_function
+
+
 _status = 'checked'
 _level = 'beginner'
 _topics = ['structure']
-_techniques = ['color','bump']
-_opengl2 = True
-_opengl2_comment = "Not enough light"
+_techniques = ['color', 'bump']
 
-from gui.draw import *
+from pyformex.gui.draw import *
 
 def run():
-    global a1,a2,a3,a4
+    global a1, a2, a3, a4
     clear()
+    smoothwire()
     m = 12 # number of cells in direction 0
     n = 36 # number of cells in direction 1
     k = 7  # number of vaults in direction 0
@@ -47,26 +48,26 @@ def run():
 
     if beam:
         # Create a grid of beam elements
-        a1 = Formex('l:2').replic2(m+1,n,1,1,0,1) + \
-             Formex('l:1').replic2(m,n+1,1,1,0,1)
+        a1 = Formex('l:2').replicm((m+1, n)) + \
+             Formex('l:1').replicm((m, n+1))
     else:
         # Create a grid of quad elements
-        a1 = Formex('4:0123').replic2(m,n,1,1,0,1)
+        a1 = Formex('4:0123').replicm((m, n))
 
-    draw(a1,view='front')
+    draw(a1, view='front')
     p = array(a1.center())
     p[2] = e1
     f = lambda x:1-(x/18)**2/2
-    a2 = a1.bump(2,p,f,1)
-    draw(a2,view='bottom',color='red')
+    a2 = a1.bump(2, p, f, 1)
+    draw(a2, view='bottom', color='red')
     p[2] = e2
-    a3 = a2.bump(2,p,lambda x:1-(x/6)**2/2,0)
-    draw(a3,view='bottom',color='green')
+    a3 = a2.bump(2, p, lambda x:1-(x/6)**2/2, 0)
+    draw(a3, view='bottom', color='green')
     # Replicate the structure in x-direction
-    a4 = a3.replicate(k,dir=0,step=m)
-    draw(a4,view='bottom',color='blue')
+    a4 = a3.replicate(k, dir=0, step=m)
+    draw(a4, view='bottom', color='blue')
     return
 
-if __name__ == 'draw':
+if __name__ == '__draw__':
     run()
 # End
