@@ -1,11 +1,11 @@
-# $Id: 954dbe2 on Mon Mar 25 13:11:26 2013 +0100 by Benedict Verhegghe $
+# $Id$
 ##
-##  This file is part of pyFormex 0.9.1  (Tue Oct 15 21:05:25 CEST 2013)
+##  This file is part of pyFormex 1.0.5  (Sat Feb 16 10:40:32 CET 2019)
 ##  pyFormex is a tool for generating, manipulating and transforming 3D
 ##  geometrical models by sequences of mathematical operations.
 ##  Home page: http://pyformex.org
 ##  Project page:  http://savannah.nongnu.org/projects/pyformex/
-##  Copyright 2004-2013 (C) Benedict Verhegghe (benedict.verhegghe@ugent.be)
+##  Copyright 2004-2018 (C) Benedict Verhegghe (benedict.verhegghe@ugent.be)
 ##  Distributed under the GNU General Public License version 3 or later.
 ##
 ##  This program is free software: you can redistribute it and/or modify
@@ -35,24 +35,26 @@ BezierCurve
 This example illustrates the use of Bernstein polynomials to evaluate points
 on a Bezier curve.
 """
-from __future__ import print_function
+from __future__ import absolute_import, division, print_function
+
+
 _status = 'checked'
 _level = 'normal'
 _topics = ['geometry', 'curve']
 _techniques = []
 
-from gui.draw import *
+from pyformex.gui.draw import *
 
 
-from plugins.curve import *
-from plugins.nurbs import *
+from pyformex.plugins.curve import *
+from pyformex.plugins.nurbs import *
 
 def run():
-    predefined = ['514','1234','51414336','custom']
+    predefined = ['514', '1234', '51414336', 'custom']
 
     res = askItems([
-        dict(name='pattern',choices=predefined),
-        dict(name='custom',value=''),
+        dict(name='pattern', choices=predefined),
+        dict(name='custom', value=''),
         ])
 
     if not res:
@@ -70,19 +72,18 @@ def run():
     linewidth(2)
     flat()
 
-    draw(C,bbox='auto',view='front')
+    draw(C, bbox='auto', view='front')
     draw(C.coords)
     drawNumbers(C.coords)
 
     setDrawOptions({'bbox':None})
     n = 100
     u = arange(n+1)*1.0/n
-    P = pointsOnBezierCurve(C.coords,u)
+    P = pointsOnBezierCurve(C.coords, u)
     draw(P)
 
 
 
-if __name__ == 'draw':
+if __name__ == '__draw__':
     run()
 # End
-
