@@ -1,11 +1,11 @@
 # $Id$
 ##
-##  This file is part of pyFormex 0.9.1  (Tue Oct 15 21:05:25 CEST 2013)
+##  This file is part of pyFormex 1.0.5  (Sat Feb 16 10:40:32 CET 2019)
 ##  pyFormex is a tool for generating, manipulating and transforming 3D
 ##  geometrical models by sequences of mathematical operations.
 ##  Home page: http://pyformex.org
 ##  Project page:  http://savannah.nongnu.org/projects/pyformex/
-##  Copyright 2004-2013 (C) Benedict Verhegghe (benedict.verhegghe@ugent.be)
+##  Copyright 2004-2018 (C) Benedict Verhegghe (benedict.verhegghe@ugent.be)
 ##  Distributed under the GNU General Public License version 3 or later.
 ##
 ##  This program is free software: you can redistribute it and/or modify
@@ -27,21 +27,23 @@
 This example shows how to create extension tubes on the borders of a
 surface techniques.
 """
-from __future__ import print_function
+from __future__ import absolute_import, division, print_function
+
+
 _status = 'checked'
 _level = 'normal'
 _topics = ['surface']
-_techniques = ['extrude','borderfill','cut']
+_techniques = ['extrude', 'borderfill', 'cut']
 
-from gui.draw import *
-import geomtools
+from pyformex.gui.draw import *
+from pyformex import geomtools
 
 def run():
     reset()
     clear()
     # read and draw the surface
     chdir(getcfg('datadir'))
-    S = TriSurface.read('bifurcation.off')
+    S = TriSurface.read('bifurcation.off.gz')
     draw(S)
     # Get the center point and the border curves
     CS = S.center()
@@ -49,32 +51,32 @@ def run():
 
     BL = []
     for B in border:
-        draw(B,color=red,linewidth=2)
+        draw(B, color=red, linewidth=2)
         # find the smallest direction of the curve
-        d,s = geomtools.smallestDirection(B.coords,return_size=True)
+        d, s = geomtools.smallestDirection(B.coords, return_size=True)
         # Find outbound direction of extension
         CB = B.center()
-        p = sign(projection((CB-CS),d))
+        p = sign(projection((CB-CS), d))
         # Flatten the border curve and translate it outwards
-        B1 = B.projectOnPlane(d,CB).trl(d,s*4*p)
-        draw(B1,color=green)
-        # create a surface between border curve and translted flat curve
+        B1 = B.projectOnPlane(d, CB).trl(d, s*8*p)
+        draw(B1, color=green)
+        # create a surface between border curve and translated flat curve
         M = B.connect(B1)
-        draw(M,color=blue,bkcolor=yellow)
+        draw(M, color=blue, bkcolor=yellow)
         BL.append(M)
 
     zoomAll()
 
     if ack("Convert extensions to 'tri3' and add to surface?"):
         # convert extensions to 'tri3'
-        BL = [ B.setProp(i+1).convert('tri3') for i,B in enumerate(BL) ]
+        BL = [ B.setProp(i+1).convert('tri3') for i, B in enumerate(BL) ]
         T = TriSurface.concatenate([S]+BL).fixNormals()
         clear()
         draw(T)
         export({'T':T})
 
 
-if __name__ == 'draw':
+if __name__ == '__draw__':
     run()
 
 # End
