@@ -1,11 +1,11 @@
-# $Id: 954dbe2 on Mon Mar 25 13:11:26 2013 +0100 by Benedict Verhegghe $
+# $Id$
 ##
-##  This file is part of pyFormex 0.9.1  (Tue Oct 15 21:05:25 CEST 2013)
+##  This file is part of pyFormex 1.0.5  (Sat Feb 16 10:40:32 CET 2019)
 ##  pyFormex is a tool for generating, manipulating and transforming 3D
 ##  geometrical models by sequences of mathematical operations.
 ##  Home page: http://pyformex.org
 ##  Project page:  http://savannah.nongnu.org/projects/pyformex/
-##  Copyright 2004-2013 (C) Benedict Verhegghe (benedict.verhegghe@ugent.be)
+##  Copyright 2004-2018 (C) Benedict Verhegghe (benedict.verhegghe@ugent.be)
 ##  Distributed under the GNU General Public License version 3 or later.
 ##
 ##  This program is free software: you can redistribute it and/or modify
@@ -27,15 +27,16 @@
 This example illustrates the use of the Mesh conversion techniques and the
 creation of colored value plots on surfaces.
 """
-from __future__ import print_function
+from __future__ import absolute_import, division, print_function
+
 _status = 'checked'
 _level = 'normal'
-_topics = ['mesh','illustration','surface']
-_techniques = ['color','random','image','movie']
+_topics = ['mesh', 'illustration', 'surface']
+_techniques = ['color', 'random', 'image', 'movie', 'extrude']
 
-from gui.draw import *
-from plugins import trisurface,surface_menu
-from elements import *
+from pyformex.gui.draw import *
+from pyformex.plugins import surface_menu
+from pyformex.elements import *
 
 def atExit():
     pf.cfg['gui/autozoomfactor'] = saved_autozoomfactor
@@ -45,11 +46,11 @@ def atExit():
 def drawMesh(M):
     clear()
     draw(M)
-    drawText("%s %s elements" % (M.nelems(),M.elName()),20,20,size=20)
+    drawText("%s %s elements" % (M.nelems(), M.elName()), (20, 20), size=20)
 
 def run():
     # make sure this is a good aspect ratio if you want a movie
-    nx,ny = 4,3
+    nx, ny = 4, 3
     global saved_autozoomfactor
     saved_autozoomfactor = pf.cfg['gui/autozoomfactor']
 
@@ -60,8 +61,9 @@ def run():
     view('front')
     smoothwire()
     transparent()
+    linewidth(1)
 
-    M = Formex(origin()).extrude(nx,1.,0).extrude(ny,1.,1).toMesh().setProp(1)
+    M = Formex(origin()).extrude(nx, 0).extrude(ny, 1).toMesh().setProp(1)
 
     V = surface_menu.SelectableStatsValues
     possible_keys = [ k for k in V.keys() if not V[k][1] ][:-1]
@@ -76,10 +78,10 @@ def run():
 
     def carpet(M):
         conversions = []
-        nconv = random.randint(minconv,maxconv)
+        nconv = random.randint(minconv, maxconv)
 
         while (len(conversions) < nconv and M.nelems() < maxelems) or M.nelems() < minelems:
-            possible_conversions = M.elType().conversions.keys()
+            possible_conversions = list(M.elType().conversions)
             i = random.randint(len(possible_conversions))
             conv = possible_conversions[i]
             conversions.append(conv)
@@ -96,13 +98,13 @@ def run():
         key = possible_keys[random.randint(nkeys)]
         print("colored by %s" % key)
         func = V[key][0]
-        S = trisurface.TriSurface(M)
+        S = TriSurface(M)
         val = func(S)
         export({'surface':S})
         surface_menu.selection.set(['surface'])
-        surface_menu.showSurfaceValue(S,str(conversions),val,False)
-        pf.canvas.removeDecoration()
-
+        surface_menu.showSurfaceValue(S, str(conversions), val, False)
+        for a in pf.canvas.scene.decorations+pf.canvas.scene.annotations:
+            undraw(a)
 
     clear()
     flatwire()
@@ -110,15 +112,21 @@ def run():
     transparent(False)
 
     if pf.interactive:
-        canvasSize(nx*200,ny*200)
+        canvasSize(nx*200, ny*200)
         #canvasSize(720,576)
         print("running interactively")
-        n = ask("How many?",['0','1000','100','10','1'])
-        n = int(n)
-        save = ack("Save images?")
+        res = askItems([
+            _I('n',1,text='Number of carpets'),
+            _I('save',False,text='Save images'),
+            ])
+        if not res:
+            return
+
+        n = res['n']
+        save = res['save']
         if save:
-            from gui import image
-            image.save(filename='Carpetry-000.jpg',window=False,multi=True,hotkey=False,autosave=False,border=False,rootcrop=False,format=None,quality=95,verbose=False)
+            from pyformex.gui import image
+            image.save(filename='Carpetry-000.jpg', window=False, multi=True, hotkey=False, autosave=False, border=False, format=None, quality=95, verbose=False)
 
         A = None
         for i in range(n):
@@ -132,22 +140,22 @@ def run():
 
         if save:
             files = image.multisave[0].files()
-            image.createMovie(files,encoder='convert',delay=1,colors=256)
+            image.createMovie(files, encoder='convert', delay=1, colors=256)
             image.save()   # reset the multisave mode, disabling further saves
 
     else:
         import sys
         print(sys.argv)
         print(argv)
-        canvasSize(nx*200,ny*200)
+        canvasSize(nx*200, ny*200)
         print("just saving image")
-        from gui import image,guimain
+        from pyformex.gui import image, guimain
         carpet(M)
         image.save('testje2.png')
         #return(all=True)
         guimain.quitGUI()
 
 
-if __name__ == 'draw':
+if __name__ == '__draw__':
     run()
 # End
