@@ -1,11 +1,11 @@
-# $Id: 954dbe2 on Mon Mar 25 13:11:26 2013 +0100 by Benedict Verhegghe $
+# $Id$
 ##
-##  This file is part of pyFormex 0.9.1  (Tue Oct 15 21:05:25 CEST 2013)
+##  This file is part of pyFormex 1.0.5  (Sat Feb 16 10:40:32 CET 2019)
 ##  pyFormex is a tool for generating, manipulating and transforming 3D
 ##  geometrical models by sequences of mathematical operations.
 ##  Home page: http://pyformex.org
 ##  Project page:  http://savannah.nongnu.org/projects/pyformex/
-##  Copyright 2004-2013 (C) Benedict Verhegghe (benedict.verhegghe@ugent.be)
+##  Copyright 2004-2018 (C) Benedict Verhegghe (benedict.verhegghe@ugent.be)
 ##  Distributed under the GNU General Public License version 3 or later.
 ##
 ##  This program is free software: you can redistribute it and/or modify
@@ -24,64 +24,67 @@
 """CircumCircle
 
 """
-from __future__ import print_function
+from __future__ import absolute_import, division, print_function
+from pyformex import zip
+
 _status = 'checked'
 _level = 'beginner'
 _topics = ['geometry']
-_techniques = ['function','import','dialog','viewport']
+_techniques = ['function', 'import', 'dialog', 'viewport']
 
-from gui.draw import *
-import simple
-from examples.Cube import cube_tri
-from geomtools import *
+from pyformex.gui.draw import *
+from pyformex import simple
+from pyformex.examples.Cube import cube_tri
+from pyformex.geomtools import *
 
 
 def draw_circles(circles,color=red):
-    for r,c,n in circles:
-        C = simple.circle(r=r,n=n,c=c)
-        draw(C,color=color)
+    for r, c, n in circles:
+        C = simple.circle(r=r, n=n, c=c)
+        draw(C, color=color)
 
 
 def drawCircles(F,func,color=red):
-    r,c,n = func(F.coords)
-    draw(c,color=color)
-    draw_circles(zip(r,c,n),color=color)
-    
+    r, c, n = func(F.coords)
+    draw(c, color=color)
+    draw_circles(zip(r, c, n), color=color)
+
 
 def run():
-    layout(2)
+    # multiple viewports is currently broken
+    #layout(2)
     wireframe()
 
     # draw in viewport 0
-    viewport(0)
+    #viewport(0)
     view('front')
     clear()
-    rtri = Formex('3:016932').scale([1.5,1,0])
-    F = rtri + rtri.shear(0,1,-0.5).trl(0,-4.0) + rtri.shear(0,1,0.75).trl(0,3.0)
+    rtri = Formex('3:016932').scale([1.5, 1, 0])
+    F = rtri + rtri.shear(0, 1, -0.5).trl(0, -4.0) + rtri.shear(0, 1, 0.75).trl(0, 3.0)
     draw(F)
 
-    drawCircles(F,triangleCircumCircle,color=red)
-    zoomAll()   
-    drawCircles(F,triangleInCircle,color=blue)
-    drawCircles(F,triangleBoundingCircle,color=black)
-    zoomAll()   
+    drawCircles(F, triangleCircumCircle, color=red)
+    zoomAll()
+    drawCircles(F, triangleInCircle, color=blue)
+    drawCircles(F, triangleBoundingCircle, color=black)
+    zoomAll()
 
 
     # draw in viewport 1
-    viewport(1)
+    #viewport(1)
+    pause()
     view('iso')
     clear()
-    F,c = cube_tri()
+    F = cube_tri()
     draw(F)
-    drawCircles(F,triangleInCircle)
-    zoomAll()   
+    drawCircles(F, triangleInCircle)
+    zoomAll()
 
-    if not ack("Keep both viewports ?"):
-        print("Removing a viewport")
-        # remove last viewport
-        removeViewport()
+    # if not ack("Keep both viewports ?"):
+    #     print("Removing a viewport")
+    #     # remove last viewport
+    #     removeViewport()
 
-if __name__ == 'draw':
+if __name__ == '__draw__':
     run()
 # End
-
