@@ -1,11 +1,11 @@
-# $Id: 954dbe2 on Mon Mar 25 13:11:26 2013 +0100 by Benedict Verhegghe $
+#
 ##
-##  This file is part of pyFormex 0.9.1  (Tue Oct 15 21:05:25 CEST 2013)
+##  This file is part of pyFormex 1.0.5  (Sat Feb 16 10:40:32 CET 2019)
 ##  pyFormex is a tool for generating, manipulating and transforming 3D
 ##  geometrical models by sequences of mathematical operations.
 ##  Home page: http://pyformex.org
 ##  Project page:  http://savannah.nongnu.org/projects/pyformex/
-##  Copyright 2004-2013 (C) Benedict Verhegghe (benedict.verhegghe@ugent.be)
+##  Copyright 2004-2018 (C) Benedict Verhegghe (benedict.verhegghe@ugent.be)
 ##  Distributed under the GNU General Public License version 3 or later.
 ##
 ##  This program is free software: you can redistribute it and/or modify
@@ -25,16 +25,18 @@
 """Clock
 
 """
-from __future__ import print_function
+from __future__ import absolute_import, division, print_function
+
+
 _status = 'checked'
 _level = 'advanced'
 _topics = []
 _techniques = ['timer']
 
-from gui.draw import *
-import simple
+from pyformex.gui.draw import *
+from pyformex import simple
 from datetime import datetime
-from gui import QtCore
+from pyformex.gui import QtCore
 
 class AnalogClock(object):
     """An analog clock built from Formices"""
@@ -44,12 +46,12 @@ class AnalogClock(object):
         self.linewidth = lw
         self.circle = simple.circle()
         radius = Formex('l:2')
-        self.mainmark = radius.divide([mm,1.0])
-        self.hourmark = radius.divide([hm,1.0])
-        self.mainhand = radius.divide([0.0,mh])
-        self.hourhand = radius.divide([0.0,hh])
+        self.mainmark = radius.subdivide([mm, 1.0])
+        self.hourmark = radius.subdivide([hm, 1.0])
+        self.mainhand = radius.subdivide([0.0, mh])
+        self.hourhand = radius.subdivide([0.0, hh])
         if sh > 0.0:
-            self.secshand = radius.divide([0.0,sh])
+            self.secshand = radius.subdivide([0.0, sh])
         else:
             self.secshand = None
         self.hands = []
@@ -58,10 +60,10 @@ class AnalogClock(object):
 
     def draw(self):
         """Draw the clock (without hands)"""
-        draw(self.circle,color='black',linewidth=self.linewidth)
-        draw(self.mainmark.rosette(4,90),color='black',linewidth=self.linewidth)
-        draw(self.hourmark.rot(30).rosette(2,30).rosette(4,90),
-             color='black',linewidth=0.5*self.linewidth)
+        draw(self.circle, color='black', linewidth=self.linewidth)
+        draw(self.mainmark.rosette(4, 90), color='black', linewidth=self.linewidth)
+        draw(self.hourmark.rot(30).rosette(2, 30).rosette(4, 90),
+             color='black', linewidth=0.5*self.linewidth)
 
 
     def drawTime(self,hrs,min,sec=None):
@@ -72,19 +74,19 @@ class AnalogClock(object):
         hrot = - hrs*30. - min*0.5
         mrot = - min*6.
         undraw(self.hands)
-        MH = draw(self.mainhand.rot(mrot),bbox=None,color='red',linewidth=self.linewidth)
-        HH = draw(self.hourhand.rot(hrot),bbox=None,color='red',linewidth=self.linewidth)
-        self.hands = [MH,HH]
+        MH = draw(self.mainhand.rot(mrot), bbox=None, color='red', linewidth=self.linewidth)
+        HH = draw(self.hourhand.rot(hrot), bbox=None, color='red', linewidth=self.linewidth)
+        self.hands = [MH, HH]
         if self.secshand and sec:
             srot = - sec*6.
-            SH = draw(self.secshand.rot(srot),bbox=None,color='orange',linewidth=0.5*self.linewidth)
+            SH = draw(self.secshand.rot(srot), bbox=None, color='orange', linewidth=0.5*self.linewidth)
             self.hands.append(SH)
 
 
     def drawNow(self):
         """Draw the hands showing the current time."""
         now = datetime.now()
-        self.drawTime(now.hour,now.minute,now.second)
+        self.drawTime(now.hour, now.minute, now.second)
         breakpt("The clock has been stopped!")
 
 
@@ -113,7 +115,7 @@ def run():
     C = AnalogClock()
     C.draw()
     setDrawOptions({'bbox':None})
-    res = askItems([_I('runtime',15,text='Run time (seconds)')])
+    res = askItems([_I('runtime', 15, text='Run time (seconds)')])
     if res and res['runtime'] > 0:
         C.drawNow()
         C.run()
@@ -121,6 +123,6 @@ def run():
         C.stop()
         print(pf.scriptlock)
 
-if __name__ == 'draw':
+if __name__ == '__draw__':
     run()
 # End
