@@ -1,11 +1,11 @@
-# $Id: 954dbe2 on Mon Mar 25 13:11:26 2013 +0100 by Benedict Verhegghe $
+# $Id$
 ##
-##  This file is part of pyFormex 0.9.1  (Tue Oct 15 21:05:25 CEST 2013)
+##  This file is part of pyFormex 1.0.5  (Sat Feb 16 10:40:32 CET 2019)
 ##  pyFormex is a tool for generating, manipulating and transforming 3D
 ##  geometrical models by sequences of mathematical operations.
 ##  Home page: http://pyformex.org
 ##  Project page:  http://savannah.nongnu.org/projects/pyformex/
-##  Copyright 2004-2013 (C) Benedict Verhegghe (benedict.verhegghe@ugent.be)
+##  Copyright 2004-2018 (C) Benedict Verhegghe (benedict.verhegghe@ugent.be)
 ##  Distributed under the GNU General Public License version 3 or later.
 ##
 ##  This program is free software: you can redistribute it and/or modify
@@ -33,23 +33,25 @@ the image pixel values.
 Finally, before the result is drawn, the geometry can be transformed into some
 other shape or be projected on a another surface.
 """
-from __future__ import print_function
+from __future__ import absolute_import, division, print_function
+
+
 _status = 'checked'
 _level = 'normal'
 _topics = ['image']
-_techniques = ['color','image']
+_techniques = ['color', 'image']
 
-from gui.draw import *
-from gui.widgets import ImageView
-from plugins.imagearray import *
-from odict import ODict
+from pyformex.gui.draw import *
+from pyformex.gui.widgets import ImageView
+from pyformex.plugins.imagearray import *
+from pyformex.odict import OrderedDict
 
 resetAll()
 
 viewer = None
 
-def selectImage(fn):
-    fn = askImageFile(fn)
+def selectImage(field):
+    fn = askImageFile(field.value())
     if fn:
         viewer.showImage(fn)
         loadImage(fn)
@@ -63,8 +65,8 @@ def loadImage(fn):
         warning("Could not load image '%s'" % fn)
         return None
 
-    w,h = image.width(),image.height()
-    print("size = %sx%s" % (w,h))
+    w, h = image.width(), image.height()
+    print("size = %sx%s" % (w, h))
 
     diag = currentDialog()
     if diag:
@@ -75,7 +77,7 @@ def loadImage(fn):
         scale = sqrt(maxsiz/w/h)
         w = int(w*scale)
         h = int(h*scale)
-    return w,h
+    return w, h
 
 
 def run():
@@ -89,24 +91,24 @@ def run():
     filename = getcfg('datadir')+'/butterfly.png'
     image = None
     scaled_image = None
-    w,h = 200,200
+    w, h = 200, 200
 
     # image viewer widget
     viewer = ImageView(filename)
 
-    transforms = ODict([
+    transforms = OrderedDict([
         ('flat', lambda F: F),
-        ('cylindrical', lambda F: F.cylindrical([2,0,1],[2.,90./float(nx),1.]).rollAxes(-1)),
-        ('spherical', lambda F: F.spherical(scale=[1.,90./float(nx),2.]).rollAxes(-1)),
-        ('projected_on_cylinder', lambda F: F.projectOnCylinder(2*R,1)),
+        ('cylindrical', lambda F: F.cylindrical([2, 0, 1], [2., 90./float(nx), 1.]).rollAxes(-1)),
+        ('spherical', lambda F: F.spherical(scale=[1., 90./float(nx), 2.]).rollAxes(-1)),
+        ('projected_on_cylinder', lambda F: F.projectOnCylinder(2*R, 1)),
         ])
 
     res = askItems([
-        _I('filename',filename,text='Image file',itemtype='button',func=selectImage),
+        _I('filename', filename, text='Image file', itemtype='button', func=selectImage),
         viewer,   # image previewing widget
-        _I('nx',w,text='width'),
-        _I('ny',h,text='height'),
-        _I('transform',itemtype='vradio',choices=transforms.keys()),
+        _I('nx', w, text='width'),
+        _I('ny', h, text='height'),
+        _I('transform', itemtype='vradio', choices=tuple(transforms.keys())),
         ])
 
 
@@ -124,16 +126,16 @@ def run():
 
     # Create the colors
     sz = image.size()
-    print("Image size is (%s,%s)" % (sz.width(),sz.height()))
-    color,colortable = image2glcolor(image.scaled(nx,ny))
+    print("Image size is (%s,%s)" % (sz.width(), sz.height()))
+    color, colortable = qimage2glcolor(image.scaled(nx, ny))
     print("Converting image to color array")
 
     # Create a 2D grid of nx*ny elements
     print("Creating grid")
     R = float(nx)/pi
     L = float(ny)
-    F = Formex('4:0123').replic2(nx,ny).centered()
-    F = F.translate(2,R)
+    F = Formex('4:0123').replicm((nx, ny)).centered()
+    F = F.translate(2, R)
 
     # Transform grid and draw
     def drawTransform(transform):
@@ -142,8 +144,8 @@ def run():
         G = trf(F)
         clear()
         print("Drawing Colored grid")
-        draw(G,color=color,colormap=colortable)
-        drawText('Created with pyFormex',20,20,size=24)
+        draw(G, color=color, colormap=colortable)
+        drawText('Created with pyFormex', (20, 20), size=24)
 
     drawTransform(transform)
     zoomAll()
@@ -158,6 +160,6 @@ def run():
     ## drawTransform('spherical')
     ## zoomAll()
 
-if __name__ == 'draw':
+if __name__ == '__draw__':
     run()
 # End
