@@ -1,11 +1,11 @@
-# $Id: 954dbe2 on Mon Mar 25 13:11:26 2013 +0100 by Benedict Verhegghe $
+# $Id$
 ##
-##  This file is part of pyFormex 0.9.1  (Tue Oct 15 21:05:25 CEST 2013)
+##  This file is part of pyFormex 1.0.5  (Sat Feb 16 10:40:32 CET 2019)
 ##  pyFormex is a tool for generating, manipulating and transforming 3D
 ##  geometrical models by sequences of mathematical operations.
 ##  Home page: http://pyformex.org
 ##  Project page:  http://savannah.nongnu.org/projects/pyformex/
-##  Copyright 2004-2013 (C) Benedict Verhegghe (benedict.verhegghe@ugent.be)
+##  Copyright 2004-2018 (C) Benedict Verhegghe (benedict.verhegghe@ugent.be)
 ##  Distributed under the GNU General Public License version 3 or later.
 ##
 ##  This program is free software: you can redistribute it and/or modify
@@ -42,41 +42,46 @@ During the display of the first half of the set of texts,
 the previous text is removed after each new one is shown.
 During the second half, all texts remain on the canvas.
 """
-from __future__ import print_function
+from __future__ import absolute_import, division, print_function
+
+
 _status = 'checked'
 _level = 'beginner'
 _topics = []
-_techniques = ['color','text', 'random', 'animation']
+_techniques = ['color', 'text', 'random', 'animation']
 
-from gui.draw import *
+from pyformex.gui.draw import *
+from pyformex.opengl.textext import *
 
 def run():
     n = 40
-    T = ['Python','NumPy','OpenGL','QT4','pyFormex']
-    fonts = ['times','helvetica','fixed']
-    ftmin,ftmax = 12,48
+    T = ['Python', 'NumPy', 'OpenGL', 'QT4', 'pyFormex']
+    fonts = utils.listMonoFonts()
 
-    r = random.random((n,8))
-    w,h = pf.canvas.width(), pf.canvas.height()
-    a = r[:,:2] * array([w,h]).astype(int)
-    size = (ftmin + r[:,2] * (ftmax-ftmin)).astype(int)
-    colors = r[:,3:6]
-    t = (r[:,6] * len(T)).astype(int)
-    f = (r[:,7] * len(fonts) - 0.5).astype(int).clip(0,len(fonts)-1)
+    ftmin, ftmax = 12, 48
+
+    r = random.random((n, 8))
+    w, h = pf.canvas.width(), pf.canvas.height()
+    a = r[:, :2] * array([w, h]).astype(int)
+    size = (ftmin + r[:, 2] * (ftmax-ftmin)).astype(int)
+    colors = r[:, 3:6]
+    t = (r[:, 6] * len(T)).astype(int)
+    f = (r[:, 7] * len(fonts) - 0.5).astype(int).clip(0, len(fonts)-1)
     clear()
 
     bgcolor(white)
     lights(False)
     TA = None
 
-    for i in range(n):
-        TB = drawText(T[t[i]],a[i][0],a[i][1],font=fonts[f[i]],size=size[i],color=list(colors[i]))
+
+    for i,s in enumerate(size):
+        TB = drawText(T[t[i]], a[i], font=fonts[f[i]], size=s, color=list(colors[i]))
         sleep(0.5)
         breakpt()
-        if i < n/2:
+        if i < n//2:
             undecorate(TA)
         TA = TB
 
-if __name__ == 'draw':
+if __name__ == '__draw__':
     run()
 # End
