@@ -1,11 +1,11 @@
-# $Id: 954dbe2 on Mon Mar 25 13:11:26 2013 +0100 by Benedict Verhegghe $
+# $Id$
 ##
-##  This file is part of pyFormex 0.9.1  (Tue Oct 15 21:05:25 CEST 2013)
+##  This file is part of pyFormex 1.0.5  (Sat Feb 16 10:40:32 CET 2019)
 ##  pyFormex is a tool for generating, manipulating and transforming 3D
 ##  geometrical models by sequences of mathematical operations.
 ##  Home page: http://pyformex.org
 ##  Project page:  http://savannah.nongnu.org/projects/pyformex/
-##  Copyright 2004-2013 (C) Benedict Verhegghe (benedict.verhegghe@ugent.be)
+##  Copyright 2004-2018 (C) Benedict Verhegghe (benedict.verhegghe@ugent.be)
 ##  Distributed under the GNU General Public License version 3 or later.
 ##
 ##  This program is free software: you can redistribute it and/or modify
@@ -29,29 +29,32 @@ topics = ['geometry','surface']
 techniques = ['dialog', 'color']
 
 """
-from __future__ import print_function
+from __future__ import absolute_import, division, print_function
+
+
 _status = 'checked'
 _level = 'beginner'
-_topics = ['geometry','surface']
+_topics = ['geometry', 'surface']
 _techniques = ['dialog', 'color']
 
-from gui.draw import *
-import simple
+from pyformex.gui.draw import *
+from pyformex import simple
 
 def run():
+    global Cone,B1,B2,B3
     reset()
     smooth()
     r=3.
     h=15.
     n=64
 
-    F = simple.sector(r,360.,n,n,h=h,diag=None)
-    F.setProp(0)
-    draw(F,view='bottom')
+    Cone = simple.sector(r, 360., n, n, h=h, diag=None)
+    #C.setProp(0)
+    draw(Cone, view='bottom')
     #setDrawOptions({'bbox':None})
 
-    print(map(str,range(4)))
-    ans = ask('How many balls do you want?',['0','1','2','3'])
+    print([str(i) for i in range(4)])
+    ans = ask('How many balls do you want?', ['0', '1', '2', '3'])
 
     try:
         nb = int(ans)
@@ -59,24 +62,24 @@ def run():
         nb = 3
 
     if nb > 0:
-        B = simple.sphere3(n,n,r=0.9*r,bot=-90,top=90)
-        B1 = B.translate([0.,0.,0.95*h])
+        B = simple.sphere3(n, n, r=0.9*r, bot=-90, top=90)
+        B1 = B.translate([0., 0., 0.95*h])
         B1.setProp(1)
         draw(B1)
 
         if nb > 1:
-            B2 = B.translate([0.2*r,0.,1.15*h])
+            B2 = B.translate([0.2*r, 0., 1.15*h])
             B2.setProp(2)
             draw(B2)
 
         if nb > 2:
-            B3 = B.translate([-0.2*r,0.1*r,1.25*h])
+            B3 = B.translate([-0.2*r, 0.1*r, 1.25*h])
             B3.setProp(6)
             draw(B3)
 
         zoomAll()
-    
 
-if __name__ == 'draw':
+
+if __name__ == '__draw__':
     run()
 # End
