@@ -1,11 +1,11 @@
-# $Id: 954dbe2 on Mon Mar 25 13:11:26 2013 +0100 by Benedict Verhegghe $
+# $Id$
 ##
-##  This file is part of pyFormex 0.9.1  (Tue Oct 15 21:05:25 CEST 2013)
+##  This file is part of pyFormex 1.0.5  (Sat Feb 16 10:40:32 CET 2019)
 ##  pyFormex is a tool for generating, manipulating and transforming 3D
 ##  geometrical models by sequences of mathematical operations.
 ##  Home page: http://pyformex.org
 ##  Project page:  http://savannah.nongnu.org/projects/pyformex/
-##  Copyright 2004-2013 (C) Benedict Verhegghe (benedict.verhegghe@ugent.be)
+##  Copyright 2004-2018 (C) Benedict Verhegghe (benedict.verhegghe@ugent.be)
 ##  Distributed under the GNU General Public License version 3 or later.
 ##
 ##  This program is free software: you can redistribute it and/or modify
@@ -24,16 +24,18 @@
 """Cones
 
 """
-from __future__ import print_function
+from __future__ import absolute_import, division, print_function
+
+
 _status = 'checked'
 _level = 'normal'
 _topics = ['geometry']
-_techniques = ['connect','dialog']
+_techniques = ['connect', 'dialog']
 
-from gui.draw import *
+from pyformex.gui.draw import *
 
-import simple
-from gui import widgets
+from pyformex import simple
+from pyformex.gui import widgets
 
 
 def cone(r0,r1,h,t=360.,nr=1,nt=24,diag=None):
@@ -52,16 +54,16 @@ def cone(r0,r1,h,t=360.,nr=1,nt=24,diag=None):
 
     The cone is modeled by nr elements in height direction and nt elements in
     circumferential direction.
-    
+
     By default, the result is a 4-plex Formex whose elements are quadrilaterals
     (some of which may collapse into triangles).
     If diag='up' or diag = 'down', all quads are divided by an up directed
     diagonal and a plex-3 Formex results.
     """
-    B = simple.rectangle(nt,nr,1.,1.,diag=diag) # grid with size 1x1
-    B = B.map(lambda x,y,z:[x,y,r0-y*(r0-r1)]) # translate and tilt it
-    B = B.scale([t,h,1.])             # scale to fit parameters
-    return B.cylindrical(dir=[2,0,1]) # roll it into a cone
+    B = simple.rectangle(nt, nr, 1., 1., diag=diag) # grid with size 1x1
+    B = B.map(lambda x, y, z:[x, y, r0-y*(r0-r1)]) # translate and tilt it
+    B = B.scale([t, h, 1.])             # scale to fit parameters
+    return B.cylindrical(dir=[2, 0, 1]) # roll it into a cone
 
 
 def cone1(r0,r1,h,t=360.,nr=1,nt=24,diag=None):
@@ -80,35 +82,35 @@ def cone1(r0,r1,h,t=360.,nr=1,nt=24,diag=None):
 
     The cone is modeled by nr elements in height direction and nt elements in
     circumferential direction.
-    
+
     By default, the result is a 4-plex Formex whose elements are quadrilaterals
     (some of which may collapse into triangles).
     If diag='up' or diag = 'down', all quads are divided by an up directed
     diagonal and a plex-3 Formex results.
     """
-    r0,r1,h,t = map(float,(r0,r1,h,t))
-    p = Formex(simple.regularGrid([r0,0.,0.],[r1,h,0.],[0,nr,0]).reshape(-1,3))
+    r0, r1, h, t = [float(f) for f in (r0, r1, h, t)]
+    p = Formex(simple.regularGrid([r0, 0., 0.], [r1, h, 0.], [0, nr, 0]).reshape(-1, 3))
     #draw(p,color=red)
-    a = (r1-r0)/h 
+    a = (r1-r0)/h
     if a != 0.:
-        p = p.shear(0,1,a)
+        p = p.shear(0, 1, a)
     #draw(p)
-    q = p.rotate(t/nt,axis=1)
+    q = p.rotate(t/nt, axis=1)
     #draw(q,color=green)
     if diag == 'u':
-        F = connect([p,p,q],bias=[0,1,1]) + \
-            connect([p,q,q],bias=[1,2,1])
+        F = connect([p, p, q], bias=[0, 1, 1]) + \
+            connect([p, q, q], bias=[1, 2, 1])
     elif diag == 'd':
-        F = connect([q,p,q],bias=[0,1,1]) + \
-            connect([p,p,q],bias=[1,2,1])
+        F = connect([q, p, q], bias=[0, 1, 1]) + \
+            connect([p, p, q], bias=[1, 2, 1])
     else:
-        F = connect([p,p,q,q],bias=[0,1,1,0])
+        F = connect([p, p, q, q], bias=[0, 1, 1, 0])
 
-    F = Formex.concatenate([F.rotate(i*t/nt,1) for i in range(nt)])
+    F = Formex.concatenate([F.rotate(i*t/nt, 1) for i in range(nt)])
     return F
 
 
-from simple import rectangle
+from pyformex.simple import rectangle
 
 r0=3.   # bottom radius
 r1=1.   # top radius
@@ -120,10 +122,10 @@ diag=''
 
 def run():
     items = [
-        widgets.simpleInputItem(n,globals()[n])
-        for n in ['r0','r1','h','t', 'nr','nt']
+        widgets.simpleInputItem(n, globals()[n])
+        for n in ['r0', 'r1', 'h', 't', 'nr', 'nt']
         ] + [
-        widgets.simpleInputItem('diag',diag,itemtype='radio',choices=['','u','d'])
+        widgets.simpleInputItem('diag', diag, itemtype='radio', choices=['', 'u', 'd'])
         ]
     dialog = widgets.InputDialog(items)
 
@@ -134,16 +136,17 @@ def run():
             break
 
         globals().update(res)
-        F = cone(r0,r1,h,t,nr,nt,diag)
-        G = cone1(r0,r1,h,t,nr,nt,diag).swapAxes(1,2).trl(0,2*max(r0,r1))
+        F = cone(r0, r1, h, t, nr, nt, diag)
+        G = cone1(r0, r1, h, t, nr, nt, diag).swapAxes(1, 2).trl(0, 2*max(r0, r1))
         G.setProp(1)
         H = F+G
         clear()
+        smoothwire()
         draw(H)
         return
-    
+
 #return
 
-if __name__ == 'draw':
+if __name__ == '__draw__':
     run()
 # End
