@@ -1,11 +1,11 @@
-# $Id: 954dbe2 on Mon Mar 25 13:11:26 2013 +0100 by Benedict Verhegghe $
+# $Id$
 ##
-##  This file is part of pyFormex 0.9.1  (Tue Oct 15 21:05:25 CEST 2013)
+##  This file is part of pyFormex 1.0.5  (Sat Feb 16 10:40:32 CET 2019)
 ##  pyFormex is a tool for generating, manipulating and transforming 3D
 ##  geometrical models by sequences of mathematical operations.
 ##  Home page: http://pyformex.org
 ##  Project page:  http://savannah.nongnu.org/projects/pyformex/
-##  Copyright 2004-2013 (C) Benedict Verhegghe (benedict.verhegghe@ugent.be)
+##  Copyright 2004-2018 (C) Benedict Verhegghe (benedict.verhegghe@ugent.be)
 ##  Distributed under the GNU General Public License version 3 or later.
 ##
 ##  This program is free software: you can redistribute it and/or modify
@@ -25,15 +25,17 @@
 """ConnectMesh
 
 """
-from __future__ import print_function
+from __future__ import absolute_import, division, print_function
+
+
 _status = 'checked'
 _level = 'normal'
 _topics = ['mesh']
-_techniques = ['connect','color']
+_techniques = ['connect', 'color']
 
-from gui.draw import *
+from pyformex.gui.draw import *
 
-import simple
+from pyformex import simple
 
 def run():
     clear()
@@ -46,23 +48,23 @@ def run():
     delay(2)
 
     # A rectangular mesh
-    M1 = simple.rectangle(nx,ny).toMesh().setProp(1)
+    M1 = simple.rectangle(nx, ny).toMesh().setProp(1)
     # Same mesh, rotated and translated
-    M2 = M1.rotate(45,0).translate([1.,-1.,nz]).setProp(3)
-    draw([M1,M2])
+    M2 = M1.rotate(45, 0).translate([1., -1., nz]).setProp(3)
+    draw([M1, M2])
 
     # Leave out the first and the last two elements
     sel = arange(M1.nelems())[1:-2]
     m1 = M1.select(sel)
     m2 = M2.select(sel)
     clear()
-    draw([m1,m2],view=None)
+    draw([m1, m2], view=None)
 
     # Connect both meshes to a hexaeder mesh
-    m = m1.connect(m2,nz)
+    m = m1.connect(m2, nz)
     clear()
-    draw(m,color=red,view=None)
+    draw(m, color=red, view=None)
 
-if __name__ == 'draw':
+if __name__ == '__draw__':
     run()
 # End
