@@ -1,11 +1,11 @@
-# $Id: 954dbe2 on Mon Mar 25 13:11:26 2013 +0100 by Benedict Verhegghe $
+# $Id$
 ##
-##  This file is part of pyFormex 0.9.1  (Tue Oct 15 21:05:25 CEST 2013)
+##  This file is part of pyFormex 1.0.5  (Sat Feb 16 10:40:32 CET 2019)
 ##  pyFormex is a tool for generating, manipulating and transforming 3D
 ##  geometrical models by sequences of mathematical operations.
 ##  Home page: http://pyformex.org
 ##  Project page:  http://savannah.nongnu.org/projects/pyformex/
-##  Copyright 2004-2013 (C) Benedict Verhegghe (benedict.verhegghe@ugent.be)
+##  Copyright 2004-2018 (C) Benedict Verhegghe (benedict.verhegghe@ugent.be)
 ##  Distributed under the GNU General Public License version 3 or later.
 ##
 ##  This program is free software: you can redistribute it and/or modify
@@ -29,24 +29,26 @@ of the cube are drawn as triangles or as quadrilaterals, and what color
 scheme is to be used: no color (black), a single color, a single color per
 face, or a color gradient over the faces.
 """
-from __future__ import print_function
+from __future__ import absolute_import, division, print_function
+
+
 _status = 'checked'
 _level = 'normal'
-_topics = ['geometry','surface']
-_techniques = ['color','elements','reverse']
+_topics = ['geometry', 'surface']
+_techniques = ['color', 'elements', 'reverse']
 
-from gui.draw import *
-from elements import Hex8
+from pyformex.gui.draw import *
+from pyformex.elements import Hex8
 
 # This could be obtained from a Mesh conversion
 def cube_tri(color=None):
     """Create a cube with triangles."""
     back = Formex('3:012934')
-    left = back.rotate(-90,1)
-    bot = back.rotate(90,0)
-    front = back.translate(2,1)
-    right = left.translate(0,1).reverse()
-    top = bot.translate(1,1).reverse()
+    left = back.rotate(-90, 1)
+    bot = back.rotate(90, 0)
+    front = back.translate(2, 1)
+    right = left.translate(0, 1).reverse()
+    top = bot.translate(1, 1).reverse()
     back = back.reverse()
     faces = front+top+right+back+bot+left
     if color == 'None':
@@ -54,57 +56,57 @@ def cube_tri(color=None):
     elif color == 'Single':
         color = 'blue'
     elif color == 'Face':
-        color = arange(1,7).repeat(2)
+        color = arange(1, 7).repeat(2)
     elif color == 'Full':
-        color = array([[4,5,7],[7,6,4],[7,3,2],[2,6,7],[7,5,1],[1,3,7],
-                       [3,1,0],[0,2,3],[0,1,5],[5,4,0],[0,4,6],[6,2,0]])
-    return faces,color
+        color = array([[4, 5, 7], [7, 6, 4], [7, 3, 2], [2, 6, 7], [7, 5, 1], [1, 3, 7],
+                       [3, 1, 0], [0, 2, 3], [0, 1, 5], [5, 4, 0], [0, 4, 6], [6, 2, 0]])
+    faces.attrib(color=color)
+    return faces
 
 
 def cube_quad(color=None):
     """Create a cube with quadrilaterals."""
     v = Hex8.vertices
     f = Hex8.faces
-    faces = Formex(v[f],eltype=f.eltype)
+    faces = Formex(v[f], eltype=f.eltype)
     if color == 'Single':
         color = 'red'
     elif color == 'Face':
-        color = [4,1,5,2,6,3]
+        color = [4, 1, 5, 2, 6, 3]
     elif color == 'Full':
-        color = array([7,6,4,5,3,2,0,1])[f]
-    return faces,color
+        color = array([7, 6, 4, 5, 3, 2, 0, 1])[f]
+    faces.attrib(color=color)
+    return faces
 
 
-def showCube(base,color):
-    #print base,color
+def showCube(base, color):
     if base == 'Triangle':
         cube = cube_tri
     else:
         cube = cube_quad
-    cube,color = cube(color)
-    clear()
-    draw(cube,color=color)
+    cube = cube(color)
+    draw(cube,clear=True)
     export({'cube':cube})
 #    zoomAll()
 
 
 def run():
-    from gui import widgets
+    from pyformex.gui import widgets
 
     clear()
     reset()
     smooth()
     view('iso')
 
-    baseshape = ['Quad','Triangle']
-    colormode = ['None','Single','Face','Full']
+    baseshape = ['Quad', 'Triangle']
+    colormode = ['None', 'Single', 'Face', 'Full']
 
     while True:
         res = askItems([
-            _I('All',False),
-            _I('Base','Quad',choices=baseshape),
-            _I('Color','Full',choices=colormode),
-            ],caption="Make a selection or check 'All'")
+            _I('All', False),
+            _I('Base', 'Quad', choices=baseshape),
+            _I('Color', 'Full', choices=colormode),
+            ], caption="Make a selection or check 'All'")
         if not res:
             break;
 
@@ -120,7 +122,7 @@ def run():
             lights(False)
 
             for color in colors:
-                showCube(base,color)
+                showCube(base, color)
                 if all:
                     sleep(1)
 
@@ -128,6 +130,6 @@ def run():
         if widgets.input_timeout >= 0:
             break
 
-if __name__ == 'draw':
+if __name__ == '__draw__':
     run()
 # End
