@@ -1,11 +1,11 @@
-# $Id: 954dbe2 on Mon Mar 25 13:11:26 2013 +0100 by Benedict Verhegghe $
+# $Id$
 ##
-##  This file is part of pyFormex 0.9.1  (Tue Oct 15 21:05:25 CEST 2013)
+##  This file is part of pyFormex 1.0.5  (Sat Feb 16 10:40:32 CET 2019)
 ##  pyFormex is a tool for generating, manipulating and transforming 3D
 ##  geometrical models by sequences of mathematical operations.
 ##  Home page: http://pyformex.org
 ##  Project page:  http://savannah.nongnu.org/projects/pyformex/
-##  Copyright 2004-2013 (C) Benedict Verhegghe (benedict.verhegghe@ugent.be)
+##  Copyright 2004-2018 (C) Benedict Verhegghe (benedict.verhegghe@ugent.be)
 ##  Distributed under the GNU General Public License version 3 or later.
 ##
 ##  This program is free software: you can redistribute it and/or modify
@@ -28,30 +28,31 @@ This example illustrates the use of simple.sector() and simple.cylinder()
 to create a parametric cylindrical surface.
 
 """
-from __future__ import print_function
+from __future__ import absolute_import, division, print_function
+
+
 _status = 'checked'
 _level = 'beginner'
 _topics = ['geometry', 'surface', 'cylinder']
 _techniques = ['import']
 
-from gui.draw import *
-import simple
-#from plugins.trisurface import TriSurface
+from pyformex.gui.draw import *
+from pyformex import simple
 
 def run():
     n=12
     h=5.
-    A = simple.sector(1.,360.,1,n,diag='u')
-    B = simple.cylinder(2.,h,n,4,diag='u').reverse()
-    C = A.reverse()+B+A.trl(2,h)
+    A = simple.sector(1., 360., 1, n, diag='u')
+    B = simple.cylinder(2., h, n, 4, diag='u').reverse()
+    C = A.reverse()+B+A.trl(2, h)
     S = TriSurface(C)
     export({'surface':S})
 
     clear()
     smoothwire()
     view('iso')
-    draw(S,color=red,bkcolor=black)
+    draw(S, color=red, bkcolor=black)
 
-if __name__ == 'draw':
+if __name__ == '__draw__':
     run()
 # End
