@@ -1,11 +1,11 @@
-# $Id: 3298c1e on Wed Mar 27 15:18:09 2013 +0100 by Gianluca De Santis $
+# $Id$
 ##
-##  This file is part of pyFormex 0.9.1  (Tue Oct 15 21:05:25 CEST 2013)
+##  This file is part of pyFormex 1.0.5  (Sat Feb 16 10:40:32 CET 2019)
 ##  pyFormex is a tool for generating, manipulating and transforming 3D
 ##  geometrical models by sequences of mathematical operations.
 ##  Home page: http://pyformex.org
 ##  Project page:  http://savannah.nongnu.org/projects/pyformex/
-##  Copyright 2004-2013 (C) Benedict Verhegghe (benedict.verhegghe@ugent.be)
+##  Copyright 2004-2018 (C) Benedict Verhegghe (benedict.verhegghe@ugent.be)
 ##  Distributed under the GNU General Public License version 3 or later.
 ##
 ##  This program is free software: you can redistribute it and/or modify
@@ -39,13 +39,15 @@ The application shows two viewports. In the left viewport element per
 element interpolation is shown. The right viewport shows the result of the
 nodal averaging.
 """
-from __future__ import print_function
+from __future__ import absolute_import, division, print_function
+
+
 _status = 'checked'
 _level = 'advanced'
-_topics = [ 'mesh','postprocess']
-_techniques = ['calpy','color']
+_topics = [ 'mesh', 'postprocess']
+_techniques = ['calpy', 'color']
 
-from gui.draw import *
+from pyformex.gui.draw import *
 
 # First, we need to import calpy. If you do not have calpy,
 # download it from ftp://bumps.ugent.be/pub/calpy
@@ -54,7 +56,7 @@ from gui.draw import *
 def run():
 
     # Locate calpy and load interface
-    from plugins import calpy_itf
+    from pyformex.plugins import calpy_itf
     try:
         Q = calpy_itf.QuadInterpolator
     except:
@@ -64,29 +66,29 @@ def run():
 
     # Now, let's create a grid of 'quad8' elements
     # size of the grid
-    nx,ny = 4,3
+    nx, ny = 4, 3
     # plexitude
     nplex = 8
     clear()
     flatwire()
-    M = Formex('4:0123').replic2(nx,ny).toMesh().convert('quad%s'%nplex,fuse=True)
+    M = Formex('4:0123').replicm((nx, ny)).toMesh().convert('quad%s'%nplex, fuse=True)
     #draw(M,color=yellow)
 
     # Create the Mesh interpolator
-    gprule = (5,1) # integration rule: minimum (1,1),  maximum (5,5)
-    Q = calpy_itf.QuadInterpolator(M.nelems(),M.nplex(),gprule)
+    gprule = (3,1) # integration rule: minimum (1,1),  maximum (5,5)
+    Q = calpy_itf.QuadInterpolator(M.nelems(), M.nplex(), gprule)
 
     # Define some random data at the GP.
     # We use 3 data per GP, because we will use the data directly as colors
     ngp = prod(gprule) # number of datapoints per element
-    data = random.rand(M.nelems(),ngp,3)
+    data = random.rand(M.nelems(), ngp, 3)
     print("Number of data points per element: %s" % ngp)
     print("Original element data: %s" % str(data.shape))
     # compute the data at the nodes, per element
     endata = Q.GP2Nodes(data)
     print("Element nodal data: %s" % str(endata.shape))
     # compute nodal averages
-    nodata = Q.NodalAvg(M.elems+1,endata,M.nnodes())
+    nodata = Q.NodalAvg(M.elems+1, endata, M.nnodes())
     print("Average nodal data: %s" % str(nodata.shape))
     # extract the colors per element
     colors = nodata[M.elems]
@@ -97,18 +99,18 @@ def run():
     clear()
     smoothwire()
     lights(False)
-    draw(M,color=endata)
+    draw(M, color=endata)
     drawNumbers(M.coords)
-    drawText("Per element interpolation",20,20,font='9x15')
+    drawText("Per element interpolation", (20, 20))
 
     viewport(1)
     clear()
     smoothwire()
     lights(False)
-    draw(M,color=colors)
+    draw(M, color=colors)
     drawNumbers(M.coords)
-    drawText("Averaged nodal values",20,20,font='9x15')
+    drawText("Averaged nodal values", (20, 20))
 
-if __name__ == 'draw':
+if __name__ == '__draw__':
     run()
 # End
