@@ -1,11 +1,11 @@
-# $Id: 954dbe2 on Mon Mar 25 13:11:26 2013 +0100 by Benedict Verhegghe $
+#
 ##
-##  This file is part of pyFormex 0.9.1  (Tue Oct 15 21:05:25 CEST 2013)
+##  This file is part of pyFormex 1.0.5  (Sat Feb 16 10:40:32 CET 2019)
 ##  pyFormex is a tool for generating, manipulating and transforming 3D
 ##  geometrical models by sequences of mathematical operations.
 ##  Home page: http://pyformex.org
 ##  Project page:  http://savannah.nongnu.org/projects/pyformex/
-##  Copyright 2004-2013 (C) Benedict Verhegghe (benedict.verhegghe@ugent.be)
+##  Copyright 2004-2018 (C) Benedict Verhegghe (benedict.verhegghe@ugent.be)
 ##  Distributed under the GNU General Public License version 3 or later.
 ##
 ##  This program is free software: you can redistribute it and/or modify
@@ -24,13 +24,16 @@
 """Diamatic dome
 
 """
-from __future__ import print_function
+from __future__ import absolute_import, division, print_function
+
+
 _status = 'checked'
 _level = 'beginner'
-_topics = ['structure','domes']
-_techniques = ['color']
+_topics = ['structure', 'domes']
+_techniques = ['color', 'circulize']
+
+from pyformex.gui.draw import *
 
-from gui.draw import *
 
 def run():
     wireframe()
@@ -40,16 +43,16 @@ def run():
     r = 36.    # radius of the dome
 
     # Topology for 1 sector
-    T = Formex('l:164',3).replic2(n,n,1,1,0,1,0,-1)
+    T = Formex('l:164', 3).replic2(n, n, 1, 1, 0, 1, 0, -1)
 
 
     # 4 sectors
     m = 4
     angle = 360./m
     # circulize sector
-    D = T.scale(u).circulize(angle)
-    D = D.mapd(2,lambda d:sqrt(r**2-d**2),[0,0,0],[0,1])
-    dome1=D.rosette(m,angle)
+    D = T.scale(u).circulize(m)
+    D = D.mapd(2, lambda d:sqrt(r**2-d**2), [0, 0, 0], [0, 1])
+    dome1=D.rosette(m, angle)
     clear()
     draw(dome1)
 
@@ -57,11 +60,11 @@ def run():
     m = 6
     angle = 360./m
     a = sqrt(3.)/2
-    D = T.shear(0,1,0.5).scale([1,a,1])
+    D = T.shear(0, 1, 0.5).scale([1, a, 1])
     #D = T.replic2(n,n,1,a,0,1,0.5,-1)
-    D = D.scale(u).circulize(angle)
-    D = D.mapd(2,lambda d:sqrt(r**2-d**2),[0,0,0],[0,1])
-    dome2=D.rosette(m,angle)
+    D = D.scale(u).circulize(m)
+    D = D.mapd(2, lambda d:sqrt(r**2-d**2), [0, 0, 0], [0, 1])
+    dome2=D.rosette(m, angle)
 
     clear()
     draw(dome2)
@@ -70,12 +73,12 @@ def run():
     m = 8
     angle = 360./m
     a = sqrt(2.)/2
-    T = Formex([[[0,0],[1,0]],[[1,0],[a,a]],[[a,a],[0,0]]],3)
-    D = T.replic2(n,n,1,a,0,1,a,-1)
+    T = Formex([[[0, 0], [1, 0]], [[1, 0], [a, a]], [[a, a], [0, 0]]], 3)
+    D = T.replic2(n, n, 1, a, 0, 1, a, -1)
     # circulize sector
-    D = D.scale(u).circulize(angle)
-    D = D.mapd(2,lambda d:sqrt(r**2-d**2),[0,0,0],[0,1])
-    dome3=D.rosette(m,angle)
+    D = D.scale(u).circulize(m)
+    D = D.mapd(2, lambda d:sqrt(r**2-d**2), [0, 0, 0], [0, 1])
+    dome3=D.rosette(m, angle)
 
     clear()
     draw(dome3)
@@ -83,11 +86,11 @@ def run():
     # circulize1
     m = 6
     angle = 360./m
-    T = Formex('l:127',3)
-    D = T.replic2(n,n,1,1,0,1,1,-1)
+    T = Formex('l:127', 3)
+    D = T.replic2(n, n, 1, 1, 0, 1, 1, -1)
     D = D.scale(u).circulize1()
-    D = D.mapd(2,lambda d:sqrt(r**2-d**2),[0,0,0],[0,1])
-    dome4=D.rosette(m,angle)
+    D = D.mapd(2, lambda d:sqrt(r**2-d**2), [0, 0, 0], [0, 1])
+    dome4=D.rosette(m, angle)
 
     clear()
     draw(dome4)
@@ -98,8 +101,8 @@ def run():
 
     clear()
     d=1.1*r
-    draw(dome1+dome2.translate([d,0,0])+dome3.translate([0,d,0])+dome4.translate([d,d,0]))
+    draw(dome1+dome2.translate([d, 0, 0])+dome3.translate([0, -d, 0])+dome4.translate([d, -d, 0]))
 
-if __name__ == 'draw':
+if __name__ == '__draw__':
     run()
 # End
