@@ -1,11 +1,11 @@
-# $Id: 954dbe2 on Mon Mar 25 13:11:26 2013 +0100 by Benedict Verhegghe $
+# $Id$
 ##
-##  This file is part of pyFormex 0.9.1  (Tue Oct 15 21:05:25 CEST 2013)
+##  This file is part of pyFormex 1.0.5  (Sat Feb 16 10:40:32 CET 2019)
 ##  pyFormex is a tool for generating, manipulating and transforming 3D
 ##  geometrical models by sequences of mathematical operations.
 ##  Home page: http://pyformex.org
 ##  Project page:  http://savannah.nongnu.org/projects/pyformex/
-##  Copyright 2004-2013 (C) Benedict Verhegghe (benedict.verhegghe@ugent.be)
+##  Copyright 2004-2018 (C) Benedict Verhegghe (benedict.verhegghe@ugent.be)
 ##  Distributed under the GNU General Public License version 3 or later.
 ##
 ##  This program is free software: you can redistribute it and/or modify
@@ -27,26 +27,30 @@
 This example is intended for testing the drawing functions for each of the
 implemented element types.
 """
-from __future__ import print_function
+from __future__ import absolute_import, division, print_function
+
+
 _status = 'checked'
 _level = 'normal'
-_topics = ['geometry','mesh']
-_techniques = ['dialog','elements']
+_topics = ['geometry', 'mesh']
+_techniques = ['dialog', 'elements']
 
-from gui.draw import *
+from pyformex.gui.draw import *
 
-from elements import *
-from mesh import Mesh
-import utils
-import olist
+from pyformex.elements import elementType,elementNames
+from pyformex.mesh import Mesh
+from pyformex import utils
+from pyformex import olist
 
 
-colors = [black,blue,yellow,red]
+colors = [black, blue, yellow, red]
 
-def showElement(eltype,options):
+def showElement(eltype, options):
+    print(eltype)
     clear()
-    drawText("Element type: %s" %eltype,100,200,font='times',size=18,color=black)
+    drawText("Element type: %s" %eltype, (100, 200), size=18, color=black)
     el = elementType(eltype)
+    print(el)
 
     if options['Show report']:
         print(el.report())
@@ -70,16 +74,16 @@ def showElement(eltype,options):
         M.coords = M.coords.addNoise(rsize=0.1)
         if options['Force dimensionality']:
             if ndim < 3:
-                M.coords[...,2] = 0.0
+                M.coords[..., 2] = 0.0
             if ndim < 2:
-                M.coords[...,1] = 0.0
+                M.coords[..., 1] = 0.0
 
     i = 'xyz'.find(options['Mirrored'])
     if i>=0:
-        M = M.trl(i,0.2)
+        M = M.trl(i, 0.2)
         M = M + M.reflect(i)
 
-    M.setProp([5,6])
+    M.setProp([5, 6])
 
     if options['Draw as'] == 'Formex':
         M = M.toFormex()
@@ -87,42 +91,42 @@ def showElement(eltype,options):
         M = M.getBorderMesh()
 
     draw(M.coords)#,color=None,wait=False)
-    drawNumbers(M.coords,color=None)
+    drawNumbers(M.coords, color=None)
 
 
     if options['Color setting'] == 'prop':
         draw(M)
     else:
-        draw(M,color=red,bkcolor=blue)
+        draw(M, color=red, bkcolor=blue)
 
 
 
 def run():
     ElemList = []
-    for ndim in [0,1,2,3]:
-        ElemList += elementTypes(ndim)
+    for ndim in [0, 1, 2, 3]:
+        ElemList += elementNames(ndim)
 
     res = {
-        'Deformed':True,
-        'Mirrored':'No',
-        'Draw as':'Mesh',
-        'Color setting':'direct',
-        'Force dimensionality':False,
-        'Show report':False,
+        'Deformed': True,
+        'Mirrored': 'No',
+        'Draw as': 'Mesh',
+        'Color setting': 'direct',
+        'Force dimensionality': False,
+        'Show report': False,
         }
-    res.update(pf.PF.get('Elements_data',{}))
+    res.update(pf.PF.get('Elements_data', {}))
     #print res
 
     res = askItems(
         store=res,
         items=[
-            _I('Element Type',choices=['All',]+ElemList),
-            _I('Deformed',itemtype='bool'),
-            _I('Mirrored',itemtype='radio',choices=['No','x','y','z']),
-            _I('Draw as',itemtype='radio',choices=['Mesh','Formex','Border']),
-            _I('Color setting',itemtype='radio',choices=['direct','prop']),
-            _I('Force dimensionality',itemtype='bool'),
-            _I('Show report',itemtype='bool'),
+            _I('Element Type', choices=['All',]+ElemList),
+            _I('Deformed', itemtype='bool'),
+            _I('Mirrored', itemtype='radio', choices=['No', 'x', 'y', 'z']),
+            _I('Draw as', itemtype='radio', choices=['Mesh', 'Formex', 'Border']),
+            _I('Color setting', itemtype='radio', choices=['direct', 'prop']),
+            _I('Force dimensionality', itemtype='bool'),
+            _I('Show report', itemtype='bool'),
             ])
     if not res:
         return
@@ -138,9 +142,9 @@ def run():
     clear()
     #delay(1)
     for el in ellist:
-        showElement(el,res)
+        showElement(el, res)
 
 
-if __name__ == 'draw':
+if __name__ == '__draw__':
     run()
 # End
