@@ -1,11 +1,11 @@
-# $Id: 954dbe2 on Mon Mar 25 13:11:26 2013 +0100 by Benedict Verhegghe $
+# $Id$
 ##
-##  This file is part of pyFormex 0.9.1  (Tue Oct 15 21:05:25 CEST 2013)
+##  This file is part of pyFormex 1.0.5  (Sat Feb 16 10:40:32 CET 2019)
 ##  pyFormex is a tool for generating, manipulating and transforming 3D
 ##  geometrical models by sequences of mathematical operations.
 ##  Home page: http://pyformex.org
 ##  Project page:  http://savannah.nongnu.org/projects/pyformex/
-##  Copyright 2004-2013 (C) Benedict Verhegghe (benedict.verhegghe@ugent.be)
+##  Copyright 2004-2018 (C) Benedict Verhegghe (benedict.verhegghe@ugent.be)
 ##  Distributed under the GNU General Public License version 3 or later.
 ##
 ##  This program is free software: you can redistribute it and/or modify
@@ -30,13 +30,15 @@ to yield a line (red). The line is extruded in y-direction, resulting in
 a rectangle (blue). Finally, an extrusion in the z-direction gives a
 cuboid (yellow).
 """
-from __future__ import print_function
+from __future__ import absolute_import, division, print_function
+
+
 _status = 'checked'
 _level = 'beginner'
 _topics = ['formex']
 _techniques = ['extrude']
 
-from gui.draw import *
+from pyformex.gui.draw import *
 
 def run():
     clear()
@@ -45,21 +47,21 @@ def run():
     view('iso')
     delay(1)
 
-    a = Formex([0.,0.,0.])
-    draw(a,color='black')
+    a = Formex([0., 0., 0.])
+    draw(a, color='black')
 
 
-    b = a.extrude(8,1.,0)
-    draw(b,color='red')
+    b = a.extrude(8, 0)
+    draw(b, color='red')
 
 
-    c = b.extrude(8,1.,1)
-    draw(c,color='blue')
+    c = b.extrude(8, 1)
+    draw(c, color='blue')
 
 
-    d = c.extrude(7,-1.,2)
-    draw(d,color='yellow')
+    d = c.extrude(7, 2, -1.)
+    draw(d, color='yellow')
 
-if __name__ == 'draw':
+if __name__ == '__draw__':
     run()
 # End
