@@ -1,11 +1,11 @@
-# $Id: 954dbe2 on Mon Mar 25 13:11:26 2013 +0100 by Benedict Verhegghe $
+# $Id$
 ##
-##  This file is part of pyFormex 0.9.1  (Tue Oct 15 21:05:25 CEST 2013)
+##  This file is part of pyFormex 1.0.5  (Sat Feb 16 10:40:32 CET 2019)
 ##  pyFormex is a tool for generating, manipulating and transforming 3D
 ##  geometrical models by sequences of mathematical operations.
 ##  Home page: http://pyformex.org
 ##  Project page:  http://savannah.nongnu.org/projects/pyformex/
-##  Copyright 2004-2013 (C) Benedict Verhegghe (benedict.verhegghe@ugent.be)
+##  Copyright 2004-2018 (C) Benedict Verhegghe (benedict.verhegghe@ugent.be)
 ##  Distributed under the GNU General Public License version 3 or later.
 ##
 ##  This program is free software: you can redistribute it and/or modify
@@ -27,28 +27,30 @@
 This example illustrates some surface techniques. A closed surface is cut
 with a number(3) of planes. Each cut leads to a hole, the border of which is
 then extruded over a gioven length in the direction of the plane's positive
-normal. 
+normal.
 """
-from __future__ import print_function
+from __future__ import absolute_import, division, print_function
+
+
 _status = 'checked'
 _level = 'normal'
 _topics = ['surface']
-_techniques = ['extrude','borderfill','cut']
+_techniques = ['extrude', 'borderfill', 'cut']
 
-from gui.draw import *
+from pyformex.gui.draw import *
 
-def cutBorderClose(S,P,N):
+def cutBorderClose(S, P, N):
     """Cut a surface with a plane, and close it
 
     Return the border line and the closed surface.
     """
-    S = S.cutWithPlane(P,N,side='-')
+    S = S.cutWithPlane(P, N, side='-')
     B = S.border()[0]
-    return B,S.close()
-  
+    return B, S.close()
+
 
 def run():
-    import simple
+    from pyformex import simple
     smooth()
     linewidth(2)
     clear()
@@ -56,25 +58,25 @@ def run():
     SA = draw(S)
 
     p = 0
-    for P,N,L,ndiv in [
+    for P, N, L, div in [
         #
         # Each line contains a point, a normal, an extrusion length
         # and the number of elements along this length
         ((0.6, 0., 0.), (1., 0., 0.), 2.5, 5 ),
-        ((-0.6, 0.6, 0.), (-1., 1., 0.), 4., 16),
+        ((-0.6, 0.6, 0.), (-1., 1., 0.), 4., (16, 1.0, 1.0)),
         ((-0.6, -0.6, 0.), (-1., -1., 0.), 3., 2),
         ]:
-        B,S = cutBorderClose(S,P,N)
+        B, S = cutBorderClose(S, P, N)
         draw(B)
         p += 1
-        E = B.extrude(n=ndiv,step=L/ndiv,dir=normalize(N),eltype='tri3').setProp(p)
+        E = B.extrude(div, dir=normalize(N), length=L, eltype='tri3').setProp(p)
         draw(E)
-        
+
     draw(S)
     undraw(SA)
     zoomAll()
 
 
-if __name__ == 'draw':
+if __name__ == '__draw__':
     run()
 # End
