@@ -1,11 +1,11 @@
-# $Id: 954dbe2 on Mon Mar 25 13:11:26 2013 +0100 by Benedict Verhegghe $
+# $Id$
 ##
-##  This file is part of pyFormex 0.9.1  (Tue Oct 15 21:05:25 CEST 2013)
+##  This file is part of pyFormex 1.0.5  (Sat Feb 16 10:40:32 CET 2019)
 ##  pyFormex is a tool for generating, manipulating and transforming 3D
 ##  geometrical models by sequences of mathematical operations.
 ##  Home page: http://pyformex.org
 ##  Project page:  http://savannah.nongnu.org/projects/pyformex/
-##  Copyright 2004-2013 (C) Benedict Verhegghe (benedict.verhegghe@ugent.be)
+##  Copyright 2004-2018 (C) Benedict Verhegghe (benedict.verhegghe@ugent.be)
 ##  Distributed under the GNU General Public License version 3 or later.
 ##
 ##  This program is free software: you can redistribute it and/or modify
@@ -28,28 +28,30 @@ This example illustrates Mesh extrusion using quadratic elements.
 
 First, a Mesh is created consisting of a single point.
 The point is extruded in the x-direction, resulting in a line.
-The line is further extrude in y-direction to yield a quadratic surface.
+The line is further extruded in y-direction to yield a quadratic surface.
 A final extrusion in the z-direction delivers a quadratic volume.
 """
-from __future__ import print_function
+from __future__ import absolute_import, division, print_function
+
+
 _status = 'checked'
 _level = 'beginner'
 _topics = ['mesh']
 _techniques = ['extrude', 'quadratic']
 
-from gui.draw import *
+from pyformex.gui.draw import *
 
 
 
 def run():
     clear()
 
-    nx,ny,nz = 5,3,4
+    nx, ny, nz = 5, 3, 4
     #nx,ny,nz = 3,2,2
     degree = 2           # create quadratic extrusions, change to 1 for linear
     serendipity = False
     show3Dbyborder = False
-    noise = 0.0          # set nonzero to add some noise to the coordinates 
+    noise = 0.0          # set nonzero to add some noise to the coordinates
     sleep = 0
     central = nx//2 + ny//2 * nx + nz//2 * ny * nx
 
@@ -57,44 +59,41 @@ def run():
     view('iso')
     delay(0)
 
-    a = Formex([0.,0.,0.]).toMesh()   # a point at the origin
+    a = Formex([0., 0., 0.]).toMesh()   # a point at the origin
     print(a.elName())
-    draw(a,color='black')
+    draw(a, color='black')
 
     delay(sleep)
 
-    b = a.extrude(nx,1.,0,degree=degree)  # point extruded to quadratic line 
+    b = a.extrude(nx, 0, degree=degree)  # point extruded to quadratic line
     print(b.elName())
-    draw(b.coords,wait=False)
-    draw(b,color='red')
+    draw(b.coords, wait=False)
+    draw(b, color='red')
 
-    c = b.extrude(ny,1.,1,degree=degree)  # line extruded to quadratic surface
+    c = b.extrude(ny, 1, degree=degree)  # line extruded to quadratic surface
     if serendipity:
         c = c.convert('quad8')#.compact()
     print(c.elName())
-    draw(c.coords,wait=False)
-    draw(c,color='blue')
+    draw(c.coords, wait=False)
+    draw(c, color='blue')
+    return
 
     #c1 = c.trl(2,1.)
     #d = c.connect(c1,degree=2)
 
     #d = d.convert('hex20')
-    d = c.extrude(nz,1.,2,degree=degree)  # surface extruded to quadratic volume
+    d = c.extrude(nz, 2, degree=degree)  # surface extruded to quadratic volume
     d = d.compact()
     print(d.elName())
-    #d = d.reverse()
-    if show3Dbyborder:
-        d = d.getBorderMesh()
-    print("Shown as %s" % d.elName())
     clear()
-    draw(d.coords,wait=False)
+    draw(d.coords, wait=False)
     #drawNumbers(d.coords)
-    draw(d,color='yellow',bkcolor='black')
+    draw(d, color='yellow', bkcolor='black')
 
     if noise:
         e = d.addNoise(noise)
-        draw(e.coords,wait=False,clear=True)
-        draw(e,color=cyan)
+        draw(e.coords, wait=False, clear=True)
+        draw(e, color=cyan)
 
     drawNumbers(d)
     print("central = %s" % central)
@@ -116,7 +115,7 @@ def run():
     clear()
     draw(d)
     export({'ExtrudeMesh':d})
-     
-if __name__ == 'draw':
+
+if __name__ == '__draw__':
     run()
 # End
