@@ -1,11 +1,11 @@
-# $Id: 954dbe2 on Mon Mar 25 13:11:26 2013 +0100 by Benedict Verhegghe $
+#
 ##
-##  This file is part of pyFormex 0.9.1  (Tue Oct 15 21:05:25 CEST 2013)
+##  This file is part of pyFormex 1.0.5  (Sat Feb 16 10:40:32 CET 2019)
 ##  pyFormex is a tool for generating, manipulating and transforming 3D
 ##  geometrical models by sequences of mathematical operations.
 ##  Home page: http://pyformex.org
 ##  Project page:  http://savannah.nongnu.org/projects/pyformex/
-##  Copyright 2004-2013 (C) Benedict Verhegghe (benedict.verhegghe@ugent.be)
+##  Copyright 2004-2018 (C) Benedict Verhegghe (benedict.verhegghe@ugent.be)
 ##  Distributed under the GNU General Public License version 3 or later.
 ##
 ##  This program is free software: you can redistribute it and/or modify
@@ -24,13 +24,15 @@
 """Geodesic Dome
 
 """
-from __future__ import print_function
+from __future__ import absolute_import, division, print_function
+
+
 _status = 'checked'
 _level = 'beginner'
-_topics = ['geometry','domes']
+_topics = ['geometry', 'domes']
 _techniques = ['dialog', 'color']
 
-from gui.draw import *
+from pyformex.gui.draw import *
 
 def run():
     clear()
@@ -38,7 +40,7 @@ def run():
 
     m=n=6
     f=0.8
-    res = askItems([('m',m),('n',n),('f',f)])
+    res = askItems([('m', m), ('n', n), ('f', f)])
     if not res:
         return
 
@@ -47,25 +49,25 @@ def run():
     f = res['f']
 
     v=0.5*sqrt(3.)
-    a = Formex([[[0,0],[1,0],[0.5,v]]],1)
-    aa = Formex([[[1,0],[1.5,v],[0.5,v]]],2)
+    a = Formex([[[0, 0], [1, 0], [0.5, v]]], 1)
+    aa = Formex([[[1, 0], [1.5, v], [0.5, v]]], 2)
     draw(a+aa)
     sleep(1)
 
-    d = a.replic2(m,min(m,n),1.,v,bias=0.5,taper=-1)
-    dd = aa.replic2(m-1,min(m-1,n),1.,v,bias=0.5,taper=-1)
+    d = a.replic2(m, min(m, n), 1., v, bias=0.5, taper=-1)
+    dd = aa.replic2(m-1, min(m-1, n), 1., v, bias=0.5, taper=-1)
     clear()
     draw(d+dd)
     sleep(1)
 
-    e = (d+dd).rosette(6,60,point=[m*0.5,m*v,0])
+    e = (d+dd).rosette(6, 60, around=[m*0.5, m*v, 0])
     draw(e)
     sleep(1)
 
-    g = e.mapd(2,lambda d:f*sqrt((m+1)**2-d**2),e.center(),[0,1])
+    g = e.mapd(2, lambda d:f*sqrt((m+1)**2-d**2), e.center(), [0, 1])
     clear()
     draw(g)
 
-if __name__ == 'draw':
+if __name__ == '__draw__':
     run()
 # End
