@@ -1,11 +1,11 @@
-# $Id: 954dbe2 on Mon Mar 25 13:11:26 2013 +0100 by Benedict Verhegghe $
+# $Id$
 ##
-##  This file is part of pyFormex 0.9.1  (Tue Oct 15 21:05:25 CEST 2013)
+##  This file is part of pyFormex 1.0.5  (Sat Feb 16 10:40:32 CET 2019)
 ##  pyFormex is a tool for generating, manipulating and transforming 3D
 ##  geometrical models by sequences of mathematical operations.
 ##  Home page: http://pyformex.org
 ##  Project page:  http://savannah.nongnu.org/projects/pyformex/
-##  Copyright 2004-2013 (C) Benedict Verhegghe (benedict.verhegghe@ugent.be)
+##  Copyright 2004-2018 (C) Benedict Verhegghe (benedict.verhegghe@ugent.be)
 ##  Distributed under the GNU General Public License version 3 or later.
 ##
 ##  This program is free software: you can redistribute it and/or modify
@@ -24,42 +24,41 @@
 """Grid
 
 """
-from __future__ import print_function
+from __future__ import absolute_import, division, print_function
+
+
 _status = 'checked'
 _level = 'beginner'
 _topics = ['geometry']
-_techniques = ['dialog','actor']
+_techniques = ['dialog', 'actor']
 
-from gui.draw import *
-import gui.actors
+from pyformex.gui.draw import *
+from pyformex.opengl.decors import Grid
 
 
 def run():
     clear()
     res = askItems([
-        _I('nx',4),
-        _I('ny',3),
-        _I('nz',2),
-        _I('Grid type',itemtype='radio',choices=['Box','Plane']),
-        _I('alpha',0.3)
+        _I('nx', 4),
+        _I('ny', 3),
+        _I('nz', 2),
+        _I('Grid type', itemtype='radio', choices=['Box', 'Plane']),
+        _I('alpha', 0.3)
         ])
 
     if not res:
         return
 
-    nx = (res['nx'],res['ny'],res['nz'])
+    nx = (res['nx'], res['ny'], res['nz'])
     gridtype = res['Grid type']
     alpha = res['alpha']
 
-    if gridtype == 'Box':
-        GA = actors.GridActor(nx=nx,linewidth=0.2,alpha=alpha)
-    else:
-        GA = actors.CoordPlaneActor(nx=nx,linewidth=0.2,alpha=alpha)
+    t = 'b' if gridtype == 'Box' else 'f'
+    G = Grid(nx=nx, linewidth=0.2, alpha=alpha, lines=t, planes=t)
 
     smooth()
-    drawActor(GA)
-    zoomBbox(GA.bbox())
+    draw(G)
 
-if __name__ == 'draw':
+if __name__ == '__draw__':
     run()
 # End
