@@ -1,11 +1,11 @@
-# $Id: 954dbe2 on Mon Mar 25 13:11:26 2013 +0100 by Benedict Verhegghe $
+# $Id$
 ##
-##  This file is part of pyFormex 0.9.1  (Tue Oct 15 21:05:25 CEST 2013)
+##  This file is part of pyFormex 1.0.5  (Sat Feb 16 10:40:32 CET 2019)
 ##  pyFormex is a tool for generating, manipulating and transforming 3D
 ##  geometrical models by sequences of mathematical operations.
 ##  Home page: http://pyformex.org
 ##  Project page:  http://savannah.nongnu.org/projects/pyformex/
-##  Copyright 2004-2013 (C) Benedict Verhegghe (benedict.verhegghe@ugent.be)
+##  Copyright 2004-2018 (C) Benedict Verhegghe (benedict.verhegghe@ugent.be)
 ##  Distributed under the GNU General Public License version 3 or later.
 ##
 ##  This program is free software: you can redistribute it and/or modify
@@ -27,13 +27,15 @@ This is basically the same example as Torus.py, but it constructs the
 resulting geometry step by step, making it suited for a first time
 initiation.
 """
-from __future__ import print_function
+from __future__ import absolute_import, division, print_function
+
+
 _status = 'checked'
 _level = 'beginner'
 _topics = ['geometry']
 _techniques = ['color']
 
-from gui.draw import *
+from pyformex.gui.draw import *
 
 def run():
     m = 36 # number of cells along helix
@@ -41,17 +43,17 @@ def run():
     reset()
     setDrawOptions({'clear':True})
     bgcolor(white)
-    F = Formex('l:164',[1,2,3]); draw(F)
-    F = F.replic(m,1.,0); draw(F)
-    F = F.replic(n,1.,1); draw(F)
-    F = F.translate(2,1.); draw(F,view='iso')
-    F = F.cylindrical([2,1,0],[1.,360./n,1.]); draw(F)
-    F = F.replic(5,m*1.,2); draw(F)
-    F = F.rotate(-10.,0); draw(F)
-    F = F.translate(0,5.); draw(F)
-    F = F.cylindrical([0,2,1],[1.,360./m,1.]); draw(F)
-    draw(F,view='right')
+    F = Formex('l:164', [1, 2, 3]); draw(F)
+    F = F.replic(m, 1., 0); draw(F)
+    F = F.replic(n, 1., 1); draw(F)
+    F = F.translate(2, 1.); draw(F, view='iso')
+    F = F.cylindrical([2, 1, 0], [1., 360./n, 1.]); draw(F)
+    F = F.replic(5, m*1., 2); draw(F)
+    F = F.rotate(-10., 0); draw(F)
+    F = F.translate(0, 5.); draw(F)
+    F = F.cylindrical([0, 2, 1], [1., 360./m, 1.]); draw(F)
+    draw(F, view='right')
 
-if __name__ == 'draw':
+if __name__ == '__draw__':
     run()
 # End
