@@ -1,11 +1,11 @@
-# $Id: 954dbe2 on Mon Mar 25 13:11:26 2013 +0100 by Benedict Verhegghe $
+# $Id$
 ##
-##  This file is part of pyFormex 0.9.1  (Tue Oct 15 21:05:25 CEST 2013)
+##  This file is part of pyFormex 1.0.5  (Sat Feb 16 10:40:32 CET 2019)
 ##  pyFormex is a tool for generating, manipulating and transforming 3D
 ##  geometrical models by sequences of mathematical operations.
 ##  Home page: http://pyformex.org
 ##  Project page:  http://savannah.nongnu.org/projects/pyformex/
-##  Copyright 2004-2013 (C) Benedict Verhegghe (benedict.verhegghe@ugent.be)
+##  Copyright 2004-2018 (C) Benedict Verhegghe (benedict.verhegghe@ugent.be)
 ##  Distributed under the GNU General Public License version 3 or later.
 ##
 ##  This program is free software: you can redistribute it and/or modify
@@ -33,14 +33,15 @@ Finally, the intersection curves are drawn on the surface. The 'ontop' option
 will draw the curves fully visible (like if the surface were transparent).
 The 'remove surface' option removes the surface, leaving only the curves.
 """
-from __future__ import print_function
+from __future__ import absolute_import, division, print_function
+
+
 _status = 'checked'
 _level = 'advanced'
-_topics = ['geometry','surface','mesh']
-_techniques = ['intersection','dialog']
+_topics = ['geometry', 'surface', 'mesh']
+_techniques = ['intersection', 'dialog']
 
-from gui.draw import *
-from plugins.trisurface import TriSurface
+from pyformex.gui.draw import *
 
 def run():
     reset()
@@ -51,12 +52,12 @@ def run():
     SA = draw(S)
 
     res = askItems([
-        ('direction',[1.,0.,0.]),
-        ('number of sections',20),
-        ('color','red'),
-        ('ontop',False),
-        ('remove surface',False),
-        ]) 
+        ('direction', [1., 0., 0.]),
+        ('number of sections', 20),
+        ('color', 'red'),
+        ('ontop', False),
+        ('remove surface', False),
+        ])
     if not res:
         return
 
@@ -64,17 +65,17 @@ def run():
     n = res['number of sections']
     c = res['color']
 
-    slices = S.slice(dir=d,nplanes=n)
+    slices = S.slice(dir=d, nplanes=n)
     linewidth(2)
-    draw(slices,color=c,view=None,bbox='last',nolight=True,ontop=res['ontop'])
+    draw(slices, color=c, view=None, bbox='last', nolight=True, ontop=res['ontop'])
     export({'_HorseSlice_slices':slices})
-    
+
     if res['remove surface']:
         undraw(SA)
-        
-    zoomAll()
-    
 
-if __name__ == 'draw':
+    zoomAll()
+
+
+if __name__ == '__draw__':
     run()
 # End
