@@ -1,11 +1,11 @@
-# $Id: 954dbe2 on Mon Mar 25 13:11:26 2013 +0100 by Benedict Verhegghe $
+# $Id$
 ##
-##  This file is part of pyFormex 0.9.1  (Tue Oct 15 21:05:25 CEST 2013)
+##  This file is part of pyFormex 1.0.5  (Sat Feb 16 10:40:32 CET 2019)
 ##  pyFormex is a tool for generating, manipulating and transforming 3D
 ##  geometrical models by sequences of mathematical operations.
 ##  Home page: http://pyformex.org
 ##  Project page:  http://savannah.nongnu.org/projects/pyformex/
-##  Copyright 2004-2013 (C) Benedict Verhegghe (benedict.verhegghe@ugent.be)
+##  Copyright 2004-2018 (C) Benedict Verhegghe (benedict.verhegghe@ugent.be)
 ##  Distributed under the GNU General Public License version 3 or later.
 ##
 ##  This program is free software: you can redistribute it and/or modify
@@ -26,30 +26,31 @@
 This script reads horse.pgf, transforms it into a surface,
 loads the surface plugin and cuts the horse in a number of surfaces.
 """
-from __future__ import print_function
+from __future__ import absolute_import, division, print_function
+
+
 _status = 'checked'
 _level = 'normal'
 _topics = ['surface']
-_techniques = ['animation','colors']
+_techniques = ['animation', 'colors']
 
-from gui.draw import *
-from plugins.trisurface import TriSurface
+from pyformex.gui.draw import *
 
 
 def run():
     global y
     reset()
-    wireframe()
+    smooth()
 
     x = 20
-    y = pf.canvas.height()-20
+    y = pf.canvas.height()-100
 
     def say(text):
         global y
-        drawText(text,x,y)
+        drawText(text, (x, y))
         y -=20
 
-    pf.message('Click Step to continue')
+    print('Click Step to continue')
 
     say('A Horse Story...')
     y -= 10
@@ -58,12 +59,11 @@ def run():
     pause()
 
     say('It\'s rather sad, but')
-    smooth()
     pause()
 
 
     say('the horse was badly cut;')
-    T = F.cutWithPlane([0.,0.,0.],[-1.,0.,0.],'+')
+    T = F.cutWithPlane([0., 0., 0.], [-1., 0., 0.], '+')
     undraw(A)
     A = draw(T)
     pause()
@@ -88,13 +88,13 @@ def run():
     pause()
 
     say('A method as yet unknown!')
-    colors = 0.1 * random.random((10,3))
+    colors = 0.1 * random.random((10, 3))
     for color in colors:
-        B = draw(T,color=color)
+        B = draw(T, color=color)
         undraw(A)
         A = B
         sleep(0.5)
 
-if __name__ == 'draw':
+if __name__ == '__draw__':
     run()
 # End
