@@ -1,11 +1,11 @@
-# $Id: 954dbe2 on Mon Mar 25 13:11:26 2013 +0100 by Benedict Verhegghe $
+# $Id$
 ##
-##  This file is part of pyFormex 0.9.1  (Tue Oct 15 21:05:25 CEST 2013)
+##  This file is part of pyFormex 1.0.5  (Sat Feb 16 10:40:32 CET 2019)
 ##  pyFormex is a tool for generating, manipulating and transforming 3D
 ##  geometrical models by sequences of mathematical operations.
 ##  Home page: http://pyformex.org
 ##  Project page:  http://savannah.nongnu.org/projects/pyformex/
-##  Copyright 2004-2013 (C) Benedict Verhegghe (benedict.verhegghe@ugent.be)
+##  Copyright 2004-2018 (C) Benedict Verhegghe (benedict.verhegghe@ugent.be)
 ##  Distributed under the GNU General Public License version 3 or later.
 ##
 ##  This program is free software: you can redistribute it and/or modify
@@ -25,14 +25,15 @@
 
 Torsing a horse is like horsing a torse.
 """
-from __future__ import print_function
+from __future__ import absolute_import, division, print_function
+
+
 _status = 'checked'
 _level = 'advanced'
-_topics = ['geometry','surface']
+_topics = ['geometry', 'surface']
 _techniques = ['animation', 'color']
 
-from gui.draw import *
-from plugins.trisurface import TriSurface
+from pyformex.gui.draw import *
 
 def drawSurf(F,surface=False,**kargs):
     """Draw a Formex as surface or not."""
@@ -49,10 +50,10 @@ def run():
     surf=True
     F = Formex.read(getcfg('datadir')+'/horse.pgf')
     F = F.translate(-F.center())
-    xmin,xmax = F.bbox()
+    xmin, xmax = F.bbox()
 
     F = F.scale(1./(xmax[0]-xmin[0]))
-    FA = drawSurf(F,surf)
+    FA = drawSurf(F, surf)
 
     angle = 360.
     n = 120
@@ -61,9 +62,9 @@ def run():
     F.setProp(1)
     for i in range(n+1):
         a = i*da
-        torse = lambda x,y,z: [x,cos(a*x)*y-sin(a*x)*z,cos(a*x)*z+sin(a*x)*y]
+        torse = lambda x, y, z: [x, cos(a*x)*y-sin(a*x)*z, cos(a*x)*z+sin(a*x)*y]
         G = F.map(torse)
-        GA = drawSurf(G,surf)
+        GA = drawSurf(G, surf)
         undraw(FA)
         FA = GA
 
@@ -74,12 +75,11 @@ def run():
 
     for i in range(nx+1):
         s = 1.0+i*dx
-        H = G.scale([s,1.,1.])
-        GA = drawSurf(H,surf,bbox=None)
+        H = G.scale([s, 1., 1.])
+        GA = drawSurf(H, surf, bbox=None)
         undraw(FA)
         FA = GA
 
-if __name__ == 'draw':
+if __name__ == '__draw__':
     run()
 # End
-
