@@ -1,11 +1,11 @@
-# $Id: 954dbe2 on Mon Mar 25 13:11:26 2013 +0100 by Benedict Verhegghe $
+# $Id$
 ##
-##  This file is part of pyFormex 0.9.1  (Tue Oct 15 21:05:25 CEST 2013)
+##  This file is part of pyFormex 1.0.5  (Sat Feb 16 10:40:32 CET 2019)
 ##  pyFormex is a tool for generating, manipulating and transforming 3D
 ##  geometrical models by sequences of mathematical operations.
 ##  Home page: http://pyformex.org
 ##  Project page:  http://savannah.nongnu.org/projects/pyformex/
-##  Copyright 2004-2013 (C) Benedict Verhegghe (benedict.verhegghe@ugent.be)
+##  Copyright 2004-2018 (C) Benedict Verhegghe (benedict.verhegghe@ugent.be)
 ##  Distributed under the GNU General Public License version 3 or later.
 ##
 ##  This program is free software: you can redistribute it and/or modify
@@ -26,13 +26,15 @@
 """Hyparcap
 
 """
-from __future__ import print_function
+from __future__ import absolute_import, division, print_function
+
+
 _status = 'checked'
 _level = 'beginner'
 _topics = ['geometry']
 _techniques = ['color']
 
-from gui.draw import *
+from pyformex.gui.draw import *
 
 def run():
     clear()
@@ -48,25 +50,25 @@ def run():
     c = (x*s+k1*s*s/2*sin(radians(2*hoek)))/(k1*s*cos(radians(hoek))+k1*s*sin(radians(hoek))) # pentacapvoorwaarde
 
     # compret van 1 blad
-    T = Formex([[[-a,0,d],[-a+2,0,d]],[[-a,0,d],[1-a,3,d]],[[1-a,3,d],[2-a,0,d]]],1)
-    B = Formex([[[1-a,-1,0],[3-a,-1,0]],[[1-a,-1,0],[2-a,2,0]],[[2-a,2,0],[3-a,-1,0]]],2)
-    W1 = Formex([[[2-a,2,0],[1-a,3,d]],[[2-a,2,0],[3-a,3,d]],[[2-a,2,0],[2-a,0,d]]])
-    W2 = Formex([[[1-a,-1,0],[-a,0,d]],[[1-a,-1,0],[2-a,0,d]],[[1-a,-1,0],[1-a,-3,d]]])
-    W3 = Formex([[[0,3*a,d],[0,3*(a-1)-1,0]]])
-    top = T.replic2(a,a,2,3,bias=1,taper=-1).reflect(1,0,True).unique()
-    bot = B.replic2(a-1,a-1,2,3,bias=1,taper=-1).reflect(1,-1,True).unique()
-    web = W1.replic2(a-1,a-1,2,3,bias=1,taper=-1) + W2.replic2(a,a,2,-3,bias=1,taper=-1) + W3
-    blad = (top+bot+web).scale([1.,1./3,1.]).translate([0,a,0])
+    T = Formex([[[-a, 0, d], [-a+2, 0, d]], [[-a, 0, d], [1-a, 3, d]], [[1-a, 3, d], [2-a, 0, d]]], 1)
+    B = Formex([[[1-a, -1, 0], [3-a, -1, 0]], [[1-a, -1, 0], [2-a, 2, 0]], [[2-a, 2, 0], [3-a, -1, 0]]], 2)
+    W1 = Formex([[[2-a, 2, 0], [1-a, 3, d]], [[2-a, 2, 0], [3-a, 3, d]], [[2-a, 2, 0], [2-a, 0, d]]])
+    W2 = Formex([[[1-a, -1, 0], [-a, 0, d]], [[1-a, -1, 0], [2-a, 0, d]], [[1-a, -1, 0], [1-a, -3, d]]])
+    W3 = Formex([[[0, 3*a, d], [0, 3*(a-1)-1, 0]]])
+    top = T.replic2(a, a, 2, 3, bias=1, taper=-1).reflect(1, 0, True).removeDuplicate()
+    bot = B.replic2(a-1, a-1, 2, 3, bias=1, taper=-1).reflect(1, -1, True).removeDuplicate()
+    web = W1.replic2(a-1, a-1, 2, 3, bias=1, taper=-1) + W2.replic2(a, a, 2, -3, bias=1, taper=-1) + W3
+    blad = (top+bot+web).scale([1., 1./3, 1.]).translate([0, a, 0])
     # herschalen
-    vlakblad = blad.scale([s*sin(radians(b/2))/a,s*cos(radians(b/2))/a,1.]).rotate(-45.)
+    vlakblad = blad.scale([s*sin(radians(b/2))/a, s*cos(radians(b/2))/a, 1.]).rotate(-45.)
     # transleren en mappen op hyperbolische paraboloide (z=k1*x*y)
-    vlakblad2=vlakblad.translate([-c,-c,0])
-    j=vlakblad2.map(lambda x,y,z:[x,y,k1*x*y])
+    vlakblad2=vlakblad.translate([-c, -c, 0])
+    j=vlakblad2.map(lambda x, y, z:[x, y, k1*x*y])
     #overige bladen genereren
-    hyparcap=j.translate([c,c,0]).rosette(m,360/m,2,[0.,0.,0.])
+    hyparcap=j.translate([c, c, 0]).rosette(m, 360./m, 2, [0., 0., 0.])
     draw(hyparcap)
 
 
-if __name__ == 'draw':
+if __name__ == '__draw__':
     run()
 # End
