@@ -1,11 +1,11 @@
-# $Id: c596ec9 on Mon Jun 17 21:35:08 2013 +0200 by Benedict Verhegghe $
+# $Id$
 ##
-##  This file is part of pyFormex 0.9.1  (Tue Oct 15 21:05:25 CEST 2013)
+##  This file is part of pyFormex 1.0.5  (Sat Feb 16 10:40:32 CET 2019)
 ##  pyFormex is a tool for generating, manipulating and transforming 3D
 ##  geometrical models by sequences of mathematical operations.
 ##  Home page: http://pyformex.org
 ##  Project page:  http://savannah.nongnu.org/projects/pyformex/
-##  Copyright 2004-2013 (C) Benedict Verhegghe (benedict.verhegghe@ugent.be)
+##  Copyright 2004-2018 (C) Benedict Verhegghe (benedict.verhegghe@ugent.be)
 ##  Distributed under the GNU General Public License version 3 or later.
 ##
 ##  This program is free software: you can redistribute it and/or modify
@@ -29,31 +29,33 @@ Create an icon file from a pyFormex model rendering.
 
 This application was used to create some of the toolbar icons for pyFormex
 """
-from __future__ import print_function
+from __future__ import absolute_import, division, print_function
+
+
 _status = 'checked'
 _level = 'normal'
 _topics = ['geometry']
-_techniques = ['image','icon']
+_techniques = ['image', 'icon']
 
-from gui.draw import *
+from pyformex.gui.draw import *
 
-from gui.actors import CubeActor
-from gui.image import saveIcon
-from plugins.curve import *
-from simple import rectangle
+from pyformex.gui.image import saveIcon
+from pyformex.plugins.curve import *
+from pyformex.simple import rectangle
+from pyformex.examples.Cube import cube_quad
 
 def icon_smooth():
     view('iso')
-    F = CubeActor()
-    drawActor(F)
+    F, color = cube_quad(color='Face')
+    draw(F,color=color)
     smooth()
     zoom(0.8)
 
 
 def icon_wirenone():
     view('front')
-    F = rectangle(2,2)
-    draw(F,color=red)
+    F = rectangle(2, 2)
+    draw(F, color=red)
     smooth()
     zoomAll()
     zoomIn()
@@ -62,10 +64,10 @@ def icon_wirenone():
 
 def icon_wireborder():
     view('front')
-    F = rectangle(2,2)
-    draw(F,color=red)
+    F = rectangle(2, 2)
+    draw(F, color=red)
     B = F.toMesh().getBorderMesh()
-    draw(B,color=black,linewidth=2,ontop=True,opak=True,nolight=True)
+    draw(B, color=black, linewidth=2, ontop=True, opak=True, nolight=True)
     smooth()
     zoomAll()
     zoomIn()
@@ -74,8 +76,8 @@ def icon_wireborder():
 
 def icon_wireall():
     view('front')
-    F = rectangle(2,2)
-    draw(F,color=red,linewidth=2)
+    F = rectangle(2, 2)
+    draw(F, color=red, linewidth=2)
     smoothwire()
     zoomAll()
     zoomIn()
@@ -83,22 +85,22 @@ def icon_wireall():
 
 
 def icon_clock():
-    from examples.Clock import AnalogClock
+    from pyformex.examples.Clock import AnalogClock
     view('front')
     F = AnalogClock()
     F.draw()
-    F.drawTime(11,55)
+    F.drawTime(11, 55)
 
 
 def icon_run():
     view('front')
-    F = Formex('3:016045').trl([-0.3,0.,0.])
+    F = Formex('3:016045').trl([-0.3, 0., 0.])
     draw(F)
 
 
 def icon_rerun():
     icon_run()
-    A = Arc(radius=1.5,angles=(45.,135.)).setProp(1)
+    A = Arc(radius=1.5, angles=(45., 135.)).setProp(1)
     B = A.scale(0.8)
     MA = A.approx().toMesh()
     MB = B.approx().toMesh()
@@ -108,45 +110,45 @@ def icon_rerun():
     draw(D)
     E = C.rotate(180)
     F = D.rotate(180)
-    draw([E,F])
+    draw([E, F])
     zoomAll()
 
 
-def spiral(X,dir=[0,1,2],rfunc=lambda x:1,zfunc=lambda x:1):
+def spiral(X,dir=[0, 1, 2],rfunc=lambda x:1,zfunc=lambda x:1):
     """Perform a spiral transformation on a coordinate array"""
-    theta = X[...,dir[0]]
-    r = rfunc(theta) + X[...,dir[1]]
+    theta = X[..., dir[0]]
+    r = rfunc(theta) + X[..., dir[1]]
     x = r * cos(theta)
     y = r * sin(theta)
-    z = zfunc(theta) + X[...,dir[2]]
-    X = hstack([x,y,z]).reshape(X.shape)
+    z = zfunc(theta) + X[..., dir[2]]
+    X = hstack([x, y, z]).reshape(X.shape)
     return Coords(X)
 
 def icon_reset():
-    T = Formex([[(0,0),(-3,0),(-3,3)]])
-    draw(T,color='steelblue')
-    x = Coords([(-2,2),(-1,3),(3,3),(3,0)])
+    T = Formex([[(0, 0), (-3, 0), (-3, 3)]])
+    draw(T, color='steelblue')
+    x = Coords([(-2, 2), (-1, 3), (3, 3), (3, 0)])
     draw(x)
     P = BezierSpline(control=x)
-    x = Coords([(3,0),(3,-1),(3,-2),(1,-3)])
+    x = Coords([(3, 0), (3, -1), (3, -2), (1, -3)])
     draw(x)
     P1 = BezierSpline(control=x)
-    draw([P,P1],color='indianred')
+    draw([P, P1], color='indianred')
     zoomAll()
 
 
 def icon_script():
     icon_run()
-    from examples import FontForge
+    from pyformex.examples import FontForge
     okfonts = [ f for f in FontForge.fonts if 'Sans' in f and 'Oblique' in f ]
     res = askItems([
-        _I('fontname',None,choices=okfonts),
+        _I('fontname', None, choices=okfonts),
         ])
     if res:
         fontname = res['fontname']
-        curve = FontForge.charCurve(fontname,'S')
+        curve = FontForge.charCurve(fontname, 'S')
         curve = curve.scale(2.5/curve.sizes()[1]).centered()
-        FontForge.drawCurve(curve,color=red,fill=True,with_border=False,with_points=False)
+        FontForge.drawCurve(curve, color=red, fill=True, with_border=False, with_points=False)
         print(curve.bbox())
     zoomAll()
 
@@ -157,8 +159,7 @@ def available_icons():
     The icon name is the second part of the 'icon_' function names.
     """
     icons = [ i[5:] for i in globals().keys() if i.startswith('icon_') and callable(globals()[i]) ]
-    icons.sort()
-    return icons
+    return sorted(icons)
 
 
 def run():
@@ -169,8 +170,8 @@ def run():
 
 
     res = askItems([
-        _I('icon',text='Icon Name',choices=_avail_icons),
-        _I('save',False,text='Save Icon'),
+        _I('icon', text='Icon Name', choices=_avail_icons),
+        _I('save', False, text='Save Icon'),
         ])
 
     if not res:
@@ -190,6 +191,6 @@ def run():
 _avail_icons = available_icons()
 
 
-if __name__ == 'draw':
+if __name__ == '__draw__':
     run()
 # End
