@@ -1,11 +1,11 @@
-# $Id: 954dbe2 on Mon Mar 25 13:11:26 2013 +0100 by Benedict Verhegghe $
+# $Id$
 ##
-##  This file is part of pyFormex 0.9.1  (Tue Oct 15 21:05:25 CEST 2013)
+##  This file is part of pyFormex 1.0.5  (Sat Feb 16 10:40:32 CET 2019)
 ##  pyFormex is a tool for generating, manipulating and transforming 3D
 ##  geometrical models by sequences of mathematical operations.
 ##  Home page: http://pyformex.org
 ##  Project page:  http://savannah.nongnu.org/projects/pyformex/
-##  Copyright 2004-2013 (C) Benedict Verhegghe (benedict.verhegghe@ugent.be)
+##  Copyright 2004-2018 (C) Benedict Verhegghe (benedict.verhegghe@ugent.be)
 ##  Distributed under the GNU General Public License version 3 or later.
 ##
 ##  This program is free software: you can redistribute it and/or modify
@@ -35,19 +35,21 @@ is repeatedly shown while it is shrinking, until it completely
 disappears inside the red sphere. Finally, an intermediate configuration
 is shown.
 """
-from __future__ import print_function
+from __future__ import absolute_import, division, print_function
+
+
 _status = 'checked'
 _level = 'normal'
-_topics = ['Mesh','Geometry','Sphere']
-_techniques = ['subdivide','project','animation']
+_topics = ['Mesh', 'Geometry', 'Sphere']
+_techniques = ['subdivide', 'project', 'animation']
 
-from gui.draw import *
+from pyformex.gui.draw import *
 smooth()
 
 def run():
     clear()
 
-    from arraytools import golden_ratio as phi
+    from pyformex.arraytools import golden_ratio as phi
     s = sqrt(1.+phi*phi)
     a = sqrt(3.)/6.*(3.+sqrt(5.))
 
@@ -56,25 +58,25 @@ def run():
     S = M.projectOnSphere()
 
     delay(0)
-    draw(S,color='red')
+    draw(S, color='red')
 
     a0 = 1./a
     a1 = 1./s - a0
-    A = draw(I.scale(a0),color='yellow')
+    A = draw(I.scale(a0), color='yellow')
     zoomAll()
     n = 100
     delay(0.05)
     for i in arange(n+1)/float(n):
-        B = draw(I.scale(a0+i*a1),color='yellow',bbox='last')
+        B = draw(I.scale(a0+i*a1), color='yellow', bbox='last')
         undraw(A)
         A = B
 
     delay(2)
     wait()
-    draw(I.scale(1./phi),color='yellow')
+    draw(I.scale(1./phi), color='yellow')
     undraw(A)
     delay(0)
 
-if __name__ == 'draw':
+if __name__ == '__draw__':
     run()
 # End
