@@ -1,11 +1,11 @@
-# $Id: e80b733 on Wed May 22 12:49:03 2013 +0200 by Benedict Verhegghe $
+# $Id$
 ##
-##  This file is part of pyFormex 0.9.1  (Tue Oct 15 21:05:25 CEST 2013)
+##  This file is part of pyFormex 1.0.5  (Sat Feb 16 10:40:32 CET 2019)
 ##  pyFormex is a tool for generating, manipulating and transforming 3D
 ##  geometrical models by sequences of mathematical operations.
 ##  Home page: http://pyformex.org
 ##  Project page:  http://savannah.nongnu.org/projects/pyformex/
-##  Copyright 2004-2013 (C) Benedict Verhegghe (benedict.verhegghe@ugent.be)
+##  Copyright 2004-2018 (C) Benedict Verhegghe (benedict.verhegghe@ugent.be)
 ##  Distributed under the GNU General Public License version 3 or later.
 ##
 ##  This program is free software: you can redistribute it and/or modify
@@ -39,16 +39,17 @@ Then, the original and the transformed structure are first shown
 superimposed, in black and red respectively. Transparency is set on.
 After the pause, the original structure is removed, and transparency is set off.
 """
-from __future__ import print_function
+from __future__ import absolute_import, division, print_function
+
 _status = 'checked'
 _level = 'normal'
 _topics = ['geometry']
-_techniques = ['dialog', 'color','isopar','undraw']
+_techniques = ['dialog', 'color', 'isopar', 'undraw']
 
-from gui.draw import *
+from pyformex.gui.draw import *
 
-from plugins import isopar
-import elements
+from pyformex import elements
+from pyformex.plugins import isopar
 
 # First and second order elements to be used for geometry, resp. transform
 elems1 = [ elements.Line2, elements.Quad4, elements.Hex8 ]
@@ -58,9 +59,9 @@ elems2 = [ elements.Line3, elements.Quad9, elements.Hex27 ]
 def run():
     clear()
     res = askItems([
-        _I('geometry','3D',itemtype='radio',choices=['1D','2D','3D']),
-        _I('transformation','3D',itemtype='radio',choices=['1D','2D','3D']),
-        _I('Show trf points',False),
+        _I('geometry', '3D', itemtype='radio', choices=['1D', '2D', '3D']),
+        _I('transformation', '3D', itemtype='radio', choices=['1D', '2D', '3D']),
+        _I('Show trf points', False),
         ])
     if not res:
         return
@@ -103,13 +104,13 @@ def run():
     n = 8
     F = elems1[sdim-1].toFormex()
     for i in range(sdim):
-        F = F.replic(n,1.,dir=i)
+        F = F.replic(n, 1., dir=i)
 
-    for i in range(sdim,tdim):
-        F = F.trl(i,0.5)
+    for i in range(sdim, tdim):
+        F = F.trl(i, 0.5)
 
     transparent()
-    message('This is the initial Formex')
+    print('This is the initial Formex')
     FA=draw(F)
     sz = F.sizes()
 
@@ -118,24 +119,24 @@ def run():
     x1 = x1.scale(sz)
 
     if res['Show trf points']:
-        message('This is the set of nodes in natural coordinates')
-        draw(x0,color=blue,nolights=True)
-        message('This is the set of nodes in cartesian coordinates')
-        draw(x1,color=red,nolights=True)
-        drawNumbers(x1,color=red)
+        print('This is the set of nodes in natural coordinates')
+        draw(x0, color=blue, nolights=True)
+        print('This is the set of nodes in cartesian coordinates')
+        draw(x1, color=red, nolights=True)
+        drawNumbers(x1, color=red)
         drawNumbers(x1)
         pause()
 
-    G=F.isopar(eltype.name(),x1.points(),x0.points())
+    G=F.isopar(eltype.name(), x1.points(), x0.points())
     G.setProp(1)
 
-    message('This is the transformed Formex')
+    print('This is the transformed Formex')
     draw(G)
 
     pause()
     undraw(FA)
     transparent(False)
 
-if __name__ == 'draw':
+if __name__ == '__draw__':
     run()
 # End
