@@ -1,11 +1,11 @@
-# $Id: 954dbe2 on Mon Mar 25 13:11:26 2013 +0100 by Benedict Verhegghe $
+# $Id$
 ##
-##  This file is part of pyFormex 0.9.1  (Tue Oct 15 21:05:25 CEST 2013)
+##  This file is part of pyFormex 1.0.5  (Sat Feb 16 10:40:32 CET 2019)
 ##  pyFormex is a tool for generating, manipulating and transforming 3D
 ##  geometrical models by sequences of mathematical operations.
 ##  Home page: http://pyformex.org
 ##  Project page:  http://savannah.nongnu.org/projects/pyformex/
-##  Copyright 2004-2013 (C) Benedict Verhegghe (benedict.verhegghe@ugent.be)
+##  Copyright 2004-2018 (C) Benedict Verhegghe (benedict.verhegghe@ugent.be)
 ##  Distributed under the GNU General Public License version 3 or later.
 ##
 ##  This program is free software: you can redistribute it and/or modify
@@ -30,18 +30,20 @@ ways:
 
 - all on top of each other
 - in a series one above the other
-- as radii of an n-pointed star  
+- as radii of an n-pointed star
 
 The actual draw method is choosen randomly. Execute again to see another one.
 """
-from __future__ import print_function
+from __future__ import absolute_import, division, print_function
+
+
 _status = 'checked'
 _level = 'beginner'
 _topics = ['illustration']
-_techniques = ['color','lime']
+_techniques = ['color', 'lime']
 
-from gui.draw import *
-from plugins.lima import lima
+from pyformex.gui.draw import *
+from pyformex.plugins.lima import lima
 
 def run():
     clear()
@@ -51,24 +53,24 @@ def run():
     n = 6 # number of generations
 
     # We use the lima module to create six generations of the Koch line
-    F = [ Formex(lima("F",{"F":"F*F//F*F"},i,
-                      { 'F' : 'fd();', '*' : 'ro(60);', '/' : 'ro(-60);' }),i)
+    F = [ Formex(lima("F", {"F":"F*F//F*F"}, i,
+                      { 'F' : 'fd();', '*' : 'ro(60);', '/' : 'ro(-60);' }), i)
           for i in range(n) ]
 
     # scale each Formex individually to obtain same length
     sc = [ 3**(-i) for i in range(n) ]
     sz = sc[0]/3.
-    F = [F[i].scale(sc[i]) for i in range(n)] 
+    F = [F[i].scale(sc[i]) for i in range(n)]
 
-    # display all lines in one (randomly choosen) of three ways 
+    # display all lines in one (randomly choosen) of three ways
     mode = random.randint(3)
     if mode == 0:
         # all on top of each other
-        draw([F[i].translate([0,sz*(i-1),0]) for i in range(n)])
+        draw([F[i].translate([0, sz*(i-1), 0]) for i in range(n)])
 
     elif mode == 1:
         # one above the other
-        draw([F[i].translate([0,sz*n,0]) for i in range(n)])
+        draw([F[i].translate([0, sz*n, 0]) for i in range(n)])
 
     else:
         # as radii of an n-pointed star
@@ -76,6 +78,6 @@ def run():
 
     zoomAll()
 
-if __name__ == 'draw':
+if __name__ == '__draw__':
     run()
 # End
