@@ -1,11 +1,11 @@
-# $Id: 954dbe2 on Mon Mar 25 13:11:26 2013 +0100 by Benedict Verhegghe $
+# $Id$
 ##
-##  This file is part of pyFormex 0.9.1  (Tue Oct 15 21:05:25 CEST 2013)
+##  This file is part of pyFormex 1.0.5  (Sat Feb 16 10:40:32 CET 2019)
 ##  pyFormex is a tool for generating, manipulating and transforming 3D
 ##  geometrical models by sequences of mathematical operations.
 ##  Home page: http://pyformex.org
 ##  Project page:  http://savannah.nongnu.org/projects/pyformex/
-##  Copyright 2004-2013 (C) Benedict Verhegghe (benedict.verhegghe@ugent.be)
+##  Copyright 2004-2018 (C) Benedict Verhegghe (benedict.verhegghe@ugent.be)
 ##  Distributed under the GNU General Public License version 3 or later.
 ##
 ##  This program is free software: you can redistribute it and/or modify
@@ -27,13 +27,15 @@ The lamella dome is a framed dome that has no meridional nor horizontal bars,
 but only diagonal bars spiraling downwards from the top ring to the bottom
 ring.
 """
-from __future__ import print_function
+from __future__ import absolute_import, division, print_function
+
+
 _status = 'checked'
 _level = 'beginner'
-_topics = ['geometry','domes']
+_topics = ['geometry', 'domes']
 _techniques = ['color']
 
-from gui.draw import *
+from pyformex.gui.draw import *
 
 def run():
     clear()
@@ -43,14 +45,14 @@ def run():
     t=50    # slope of the dome at its base (= half angle of the sphere cap)
     a=2     # size of the top opening
     rings=False # set to True to include horizontal rings
-    e1 = Formex([[[0,0],[1,1]]],1).rosette(4,90).translate([1,1,0]) # diagonals
-    e2 = Formex([[[0,0],[2,0]]],0) # border
-    f1 = e1.replic2(nx,ny,2,2)
+    e1 = Formex([[[0, 0], [1, 1]]], 1).rosette(4, 90).translate([1, 1, 0]) # diagonals
+    e2 = Formex([[[0, 0], [2, 0]]], 0) # border
+    f1 = e1.replicm((nx, ny), (2, 2))
     if rings:
-        f2 = e2.replic2(nx,ny+1,2,2)
+        f2 = e2.replicm((nx, ny+1), (2, 2))
     else:
-        f2 = e2.replic2(nx,2,2,2*ny)
-    g = (f1+f2).translate([0,a,1]).spherical(scale=[180/nx,t/(2*ny+a),rd],colat=True)
+        f2 = e2.replicm((nx, 2), (2, 2*ny))
+    g = (f1+f2).translate([0, a, 1]).spherical(scale=[180./nx, t/(2*ny+a), rd], colat=True)
     draw(e1+e2)
 
     draw(f1+f2)
@@ -58,6 +60,6 @@ def run():
     clear()
     draw(g)
 
-if __name__ == 'draw':
+if __name__ == '__draw__':
     run()
 # End
