@@ -1,11 +1,11 @@
-# $Id: 954dbe2 on Mon Mar 25 13:11:26 2013 +0100 by Benedict Verhegghe $
+# $Id$
 ##
-##  This file is part of pyFormex 0.9.1  (Tue Oct 15 21:05:25 CEST 2013)
+##  This file is part of pyFormex 1.0.5  (Sat Feb 16 10:40:32 CET 2019)
 ##  pyFormex is a tool for generating, manipulating and transforming 3D
 ##  geometrical models by sequences of mathematical operations.
 ##  Home page: http://pyformex.org
 ##  Project page:  http://savannah.nongnu.org/projects/pyformex/
-##  Copyright 2004-2013 (C) Benedict Verhegghe (benedict.verhegghe@ugent.be)
+##  Copyright 2004-2018 (C) Benedict Verhegghe (benedict.verhegghe@ugent.be)
 ##  Distributed under the GNU General Public License version 3 or later.
 ##
 ##  This program is free software: you can redistribute it and/or modify
@@ -37,29 +37,31 @@ the transformation of a character '5' from a 'blippo' font to be converted
 to an OpenGL model. This functionality is currently not included in pyFormex,
 but we are working on an equivalent using the 'fontforge' library.
 """
-from __future__ import print_function
+from __future__ import absolute_import, division, print_function
+
+
 _status = 'checked'
 _level = 'normal'
-_topics = ['curve','drawing','illustration']
-_techniques = ['color','persistence','lima','import']
+_topics = ['curve', 'drawing', 'illustration']
+_techniques = ['color', 'persistence', 'lima', 'import']
 
-from gui.draw import *
-from pyformex.apps.Lima import *
+from pyformex.gui.draw import *
+from pyformex.examples.Lima import *
 
 def run():
     resetAll()
     flat()
     linewidth(2)
     fgcolor(blue)
-    grow('Plant1',ngen=7,clearing=False,text=False)
-    data = readGeomFile(os.path.join(pf.cfg['datadir'],'blippo.pgf'))
-    curve = data['blippo_000']
+    grow('Plant1', ngen=7, clearing=False, text=False)
+    data = readGeomFile(os.path.join(pf.cfg['datadir'], 'blippo.pgf'))
+    curve = data['blippo-0']
     bb = curve.coords.bbox()
     ctr = bb.center()
     siz = bb.sizes()
-    curve.coords = curve.coords.trl(0,-ctr[0]).scale(50./siz[0])
-    draw(curve,color=pyformex_pink,linewidth=5)
+    curve.coords = curve.coords.trl(0, -ctr[0]).scale(50./siz[0])
+    draw(curve, color=pyformex_pink, linewidth=5)
 
-if __name__ == 'draw':
+if __name__ == '__draw__':
     run()
 # End
