@@ -1,11 +1,11 @@
-# $Id: 954dbe2 on Mon Mar 25 13:11:26 2013 +0100 by Benedict Verhegghe $
+# $Id$
 ##
-##  This file is part of pyFormex 0.9.1  (Tue Oct 15 21:05:25 CEST 2013)
+##  This file is part of pyFormex 1.0.5  (Sat Feb 16 10:40:32 CET 2019)
 ##  pyFormex is a tool for generating, manipulating and transforming 3D
 ##  geometrical models by sequences of mathematical operations.
 ##  Home page: http://pyformex.org
 ##  Project page:  http://savannah.nongnu.org/projects/pyformex/
-##  Copyright 2004-2013 (C) Benedict Verhegghe (benedict.verhegghe@ugent.be)
+##  Copyright 2004-2018 (C) Benedict Verhegghe (benedict.verhegghe@ugent.be)
 ##  Distributed under the GNU General Public License version 3 or later.
 ##
 ##  This program is free software: you can redistribute it and/or modify
@@ -39,7 +39,7 @@ element numbers included:
 - the unique faces,
 - the border (in the 3D case, this is a set of faces, in the 2D case it is a
   set of lines.
-  
+
 At each step the number of elements is printed.
 
 Remark
@@ -55,30 +55,32 @@ and the 3D cases.
 
 Exercises
 .........
-1. Make this script also work for the 1D case. 
+1. Make this script also work for the 1D case.
 
 """
-from __future__ import print_function
+from __future__ import absolute_import, division, print_function
+
+
 _status = 'checked'
 _level = 'beginner'
 _topics = ['geometry', 'mesh']
-_techniques = ['extrude','border','pause']
+_techniques = ['extrude', 'border', 'pause']
 
-from gui.draw import *
+from pyformex.gui.draw import *
 def atExit():
     #print "THIS IS THE EXIT FUNC"
     pf.GUI.setBusy(False)
-    
+
 
 def run():
     clear()
     smoothwire()
     transparent()
 
-    n = 3,2,5
+    n = 3, 2, 5
     a = Formex(origin())
 
-    res = ask("Choose the model:",["None","2D","3D","Help"])
+    res = ask("Choose the model:", ["None", "2D", "3D", "Help"])
     if res == "None":
         return
     if res == "Help":
@@ -86,7 +88,7 @@ def run():
         return
 
     showInfo("At each step, press Play/Step to continue")
-    
+
     ndim = int(res[0])
 
     if ndim == 2:
@@ -95,7 +97,7 @@ def run():
         view('iso')
 
     for i in range(ndim):
-        a = a.extrude(n[i],1.,i)
+        a = a.extrude(n[i], i)
 
     draw(a)
     drawNumbers(a)
@@ -109,32 +111,32 @@ def run():
 
 
     flat()
-    e = Mesh(m.coords,m.getLowerEntities(1)).setProp(2)
+    e = Mesh(m.coords, m.getLowerEntities(1)).setProp(2)
     clear()
     draw(e)
     drawNumbers(e)
     pause(msg="%s edges" % e.nelems())
 
-    e = Mesh(m.coords,m.getEdges()).setProp(2)
+    e = Mesh(m.coords, m.getEdges()).setProp(2)
     clear()
     draw(e)
     drawNumbers(e)
     pause(msg="%s unique edges" % e.nelems())
 
     smoothwire()
-    e = Mesh(m.coords,m.getLowerEntities(2)).setProp(3)
+    e = Mesh(m.coords, m.getLowerEntities(2)).setProp(3)
     clear()
     draw(e)
     drawNumbers(e)
     pause(msg="%s faces" % e.nelems())
 
-    e = Mesh(m.coords,m.getFaces()).setProp(3)
+    e = Mesh(m.coords, m.getFaces()).setProp(3)
     clear()
     draw(e)
     drawNumbers(e)
     pause(msg="%s unique faces" % e.nelems())
 
-    e = Mesh(m.coords,m.getBorder()).setProp(4)
+    e = Mesh(m.coords, m.getBorder()).setProp(4)
     export({'border':e})
     clear()
     draw(e)
@@ -151,8 +153,8 @@ def run():
     clear()
     draw(e)
     drawNumbers(e)
-    message("border elements inherit the properties")
+    print("border elements inherit the properties")
 
-if __name__ == 'draw':
+if __name__ == '__draw__':
     run()
 # End
