@@ -1,11 +1,11 @@
-# $Id: 954dbe2 on Mon Mar 25 13:11:26 2013 +0100 by Benedict Verhegghe $
+# $Id$
 ##
-##  This file is part of pyFormex 0.9.1  (Tue Oct 15 21:05:25 CEST 2013)
+##  This file is part of pyFormex 1.0.5  (Sat Feb 16 10:40:32 CET 2019)
 ##  pyFormex is a tool for generating, manipulating and transforming 3D
 ##  geometrical models by sequences of mathematical operations.
 ##  Home page: http://pyformex.org
 ##  Project page:  http://savannah.nongnu.org/projects/pyformex/
-##  Copyright 2004-2013 (C) Benedict Verhegghe (benedict.verhegghe@ugent.be)
+##  Copyright 2004-2018 (C) Benedict Verhegghe (benedict.verhegghe@ugent.be)
 ##  Distributed under the GNU General Public License version 3 or later.
 ##
 ##  This program is free software: you can redistribute it and/or modify
@@ -32,34 +32,36 @@ squares. The matching node numbers from the two meshes are printed out.
 Then, after a pause, the parts of both meshes that are connected to the
 common nodes are drawn.
 """
-from __future__ import print_function
+from __future__ import absolute_import, division, print_function
+
+
 _status = 'checked'
 _level = 'normal'
 _topics = ['mesh']
-_techniques = ['draw','replicate','match','cselect']
+_techniques = ['draw', 'replicate', 'match', 'cselect']
 
-from gui.draw import *
+from pyformex.gui.draw import *
 
 def run():
     transparent()
     smoothwire()
     clear()
-    from mesh import Mesh
+    from pyformex.mesh import Mesh
 
     n=5
     nx=4*n
     ny=2*n
 
     # construct a Quad4 Mesh
-    M = Formex('4:0123').replic2(nx,ny).cselect(arange(4*nx,int(7.5*nx))).toMesh().setProp(1)
+    M = Formex('4:0123').replic2(nx, ny).cselect(arange(4*nx, int(7.5*nx))).toMesh().setProp(1)
     draw(M)
-    drawNumbers(M.coords,color=red)
+    drawNumbers(M.coords, color=red)
 
     # construct a Tri3 Mesh
-    M1 = Formex('3:012').replic2(int(0.6*nx),int(0.45*ny),bias=1,taper=-2).toMesh().scale(2).trl(1,1.).setProp(2)
+    M1 = Formex('3:012').replic2(int(0.6*nx), int(0.45*ny), bias=1, taper=-2).toMesh().scale(2).trl(1, 1.).setProp(2)
     draw(M1)
     zoomAll()
-    drawNumbers(M1.coords,color=yellow,trl=[0.,-0.25,0.])
+    drawNumbers(M1.coords, color=yellow, trl=[0., -0.25, 0.])
 
     # find matching nodes
     match = M.matchCoords(M1)
@@ -69,18 +71,18 @@ def run():
     n0 = match[n1]              # node numbers in Mesh M
 
     print("List of the %s matching nodes" % len(n1))
-    print(column_stack([n0,n1]))
+    print(column_stack([n0, n1]))
 
-    draw(M.coords[n0],marksize=10,bbox='last',ontop=True)
+    draw(M.coords[n0], marksize=10, bbox='last', ontop=True)
 
     # compute and draw parts connected to the common nodes
     sleep(4)
     clear()
-    draw(M.coords[n0],marksize=10,bbox='last',ontop=True)
-    M = M.connectedTo(n0)
-    M1 = M1.connectedTo(n1)
-    draw([M,M1])
+    draw(M.coords[n0], marksize=10, bbox='last', ontop=True)
+    M = M.select(M.connectedTo(n0))
+    M1 = M.select(M1.connectedTo(n1))
+    draw([M, M1])
 
-if __name__ == 'draw':
+if __name__ == '__draw__':
     run()
 # End
