@@ -1,11 +1,11 @@
-# $Id: 954dbe2 on Mon Mar 25 13:11:26 2013 +0100 by Benedict Verhegghe $
+# $Id$
 ##
-##  This file is part of pyFormex 0.9.1  (Tue Oct 15 21:05:25 CEST 2013)
+##  This file is part of pyFormex 1.0.5  (Sat Feb 16 10:40:32 CET 2019)
 ##  pyFormex is a tool for generating, manipulating and transforming 3D
 ##  geometrical models by sequences of mathematical operations.
 ##  Home page: http://pyformex.org
 ##  Project page:  http://savannah.nongnu.org/projects/pyformex/
-##  Copyright 2004-2013 (C) Benedict Verhegghe (benedict.verhegghe@ugent.be)
+##  Copyright 2004-2018 (C) Benedict Verhegghe (benedict.verhegghe@ugent.be)
 ##  Distributed under the GNU General Public License version 3 or later.
 ##
 ##  This program is free software: you can redistribute it and/or modify
@@ -26,25 +26,27 @@
 This example shows how to cut a hole in a surface.
 It uses the cutWithPlane function with a series of cutting planes.
 """
-from __future__ import print_function
+from __future__ import absolute_import, division, print_function
+
+
 _status = 'checked'
 _level = 'beginner'
 _topics = ['surface']
 _techniques = ['cut']
 
-from gui.draw import *
+from pyformex.gui.draw import *
 
 def run():
     clear()
     smooth()
 
-    from simple import sphere
+    from pyformex.simple import sphere
     S = sphere(8).scale(3.)
-    T = S.cutWithPlane([[2.,0.,0.],[0.,1.,0.],[-2.,0.,0.],[0.,-1.,0.]],
-                       [[-1.,0.,0.],[0.,-1.,0.],[1.,0.,0.],[0.,+1.,0.]],
+    T = S.cutWithPlane([[2., 0., 0.], [0., 1., 0.], [-2., 0., 0.], [0., -1., 0.]],
+                       [[-1., 0., 0.], [0., -1., 0.], [1., 0., 0.], [0., +1., 0.]],
                        side = '-')
     draw(T)
 
-if __name__ == 'draw':
+if __name__ == '__draw__':
     run()
 # End
