@@ -1,11 +1,11 @@
-# $Id: 3298c1e on Wed Mar 27 15:18:09 2013 +0100 by Gianluca De Santis $
+# $Id$
 ##
-##  This file is part of pyFormex 0.9.1  (Tue Oct 15 21:05:25 CEST 2013)
+##  This file is part of pyFormex 1.0.5  (Sat Feb 16 10:40:32 CET 2019)
 ##  pyFormex is a tool for generating, manipulating and transforming 3D
 ##  geometrical models by sequences of mathematical operations.
 ##  Home page: http://pyformex.org
 ##  Project page:  http://savannah.nongnu.org/projects/pyformex/
-##  Copyright 2004-2013 (C) Benedict Verhegghe (benedict.verhegghe@ugent.be)
+##  Copyright 2004-2018 (C) Benedict Verhegghe (benedict.verhegghe@ugent.be)
 ##  Distributed under the GNU General Public License version 3 or later.
 ##
 ##  This program is free software: you can redistribute it and/or modify
@@ -26,43 +26,41 @@
 This example illustrates the detection of non-manifold nodes and edges in a
 Mesh.
 """
-from __future__ import print_function
+from __future__ import absolute_import, division, print_function
+
+
 _status = 'checked'
 _level = 'normal'
 _topics = ['mesh']
 _techniques = ['']
 
-from gui.draw import *
-import simple
+from pyformex.gui.draw import *
+from pyformex import simple
 
 
 def hex_mesh():
-    nx,ny,nz = 3,2,2
-    F = simple.cuboid().replic2(nx,ny).replic(nz,1.,2)
-    F += F.trl([nx,ny,0])
-    F += F.trl([2*nx,2*ny,nz])
+    nx, ny, nz = 3, 2, 2
+    F = simple.cuboid().replicm((nx, ny,nz))
+    F += F.trl([nx, ny, 0])
+    F += F.trl([2*nx, 2*ny, nz])
     return F.toMesh()
 
 def quad_mesh():
-    nx,ny = 3,2
-    F = Formex('4:0123').replic2(nx,ny)
-    F += F.trl([nx,ny,0.])
+    nx, ny = 3, 2
+    F = Formex('4:0123').replicm((nx, ny))
+    F += F.trl([nx, ny, 0.])
     return F.toMesh()
 
 def tri_mesh():
     return quad_mesh().convert('tri3')
 
-def hex_mesh_orig():
-    x, y, z = 10, 10, 8
-    F = simple.cuboid().replic2(x, x).replic(z, 1., 2)
-    F += F.trl([x, y, z])
+def hex_mesh_orig(nx=10,ny=10,nz=8):
+    F = simple.cuboid().replicm((nx, ny, nz))
+    F += F.trl([nx, ny, nz])
     return F.toMesh()
 
 def hex_mesh_huge():
-    nx,ny,nz = 20,20,8
-    F = simple.cuboid().replic2(nx,ny).replic(nz,1.,2)
-    F += F.trl([nx,ny,nz])
-    return F.toMesh()
+    return hex_mesh_orig(20,20,8)
 
 def quad_mesh_orig():
     F = hex_mesh_orig()
@@ -91,25 +89,25 @@ def showNonMan(M):
     draw(M)
     if M.nelems()<100 and M.nnodes() < 100:
         drawNumbers(M.coords)
-        drawNumbers(M,color=red)
+        drawNumbers(M, color=red)
 
     nm = M.nonManifoldNodes()
     print(nm)
     if len(nm) > 0:
-        draw(M.coords[nm],marksize=10,color=red)
+        draw(M.coords[nm], marksize=10, color=red)
 
     nm = M.nonManifoldEdgeNodes()
     print(nm)
     if len(nm) > 0:
-        draw(M.coords[nm],marksize=10,color=blue)
+        draw(M.coords[nm], marksize=10, color=blue)
 
     nm = M.nonManifoldEdges()
     print(nm)
     if len(nm) > 0:
         ed = M.edges[nm]
         print(ed)
-        ME = Mesh(M.coords,ed,eltype='line2')
-        draw(ME,color=cyan,linewidth=5)
+        ME = Mesh(M.coords, ed, eltype='line2')
+        draw(ME, color=cyan, linewidth=5)
 
 def run():
     examples = [
@@ -129,7 +127,7 @@ def run():
     clear()
 
     res = askItems([
-        _I('example',choices=examplenames),
+        _I('example', choices=examplenames),
         ])
 
     if res:
@@ -139,7 +137,7 @@ def run():
         zoomAll()
 
 
-if __name__ == 'draw':
+if __name__ == '__draw__':
     reset()
     clear()
 
