@@ -1,11 +1,11 @@
-# $Id: 954dbe2 on Mon Mar 25 13:11:26 2013 +0100 by Benedict Verhegghe $
+# $Id$
 ##
-##  This file is part of pyFormex 0.9.1  (Tue Oct 15 21:05:25 CEST 2013)
+##  This file is part of pyFormex 1.0.5  (Sat Feb 16 10:40:32 CET 2019)
 ##  pyFormex is a tool for generating, manipulating and transforming 3D
 ##  geometrical models by sequences of mathematical operations.
 ##  Home page: http://pyformex.org
 ##  Project page:  http://savannah.nongnu.org/projects/pyformex/
-##  Copyright 2004-2013 (C) Benedict Verhegghe (benedict.verhegghe@ugent.be)
+##  Copyright 2004-2018 (C) Benedict Verhegghe (benedict.verhegghe@ugent.be)
 ##  Distributed under the GNU General Public License version 3 or later.
 ##
 ##  This program is free software: you can redistribute it and/or modify
@@ -38,14 +38,16 @@ directly is 7. Higher order curves are approximated by a PolyLine.
 For the last (highest degree) Nurbs curve, also a set of 100 points along
 the curve are shown.
 """
-from __future__ import print_function
+from __future__ import absolute_import, division, print_function
+
+
 _status = 'checked'
 _level = 'normal'
 _topics = ['geometry', 'curve']
 _techniques = ['nurbs']
 
-from gui.draw import *
-from plugins.nurbs import NurbsCurve
+from pyformex.gui.draw import *
+from pyformex.plugins.nurbs import NurbsCurve
 
 resetAll()
 
@@ -68,11 +70,11 @@ custom = ''
 
 
 def run():
-    
+
     res = askItems([
-        dict(name='pattern',value=pattern,choices=predefined),
-        dict(name='custom',value=custom),
-        ],enablers=[('pattern','custom','custom')])
+        dict(name='pattern', value=pattern, choices=predefined),
+        dict(name='custom', value=custom),
+        ], enablers=[('pattern', 'custom', 'custom')])
 
     if not res:
         return
@@ -96,25 +98,24 @@ def run():
     setDrawOptions({'bbox':None})
 
     cmap = colormap() * 2
-    n = min(len(C.coords),len(cmap))
+    n = min(len(C.coords), len(cmap))
     dmax = 7 # maximum Nurbs degree we can draw in OpenGL
-    for d in range(1,n):
+    for d in range(1, n):
         print("Degree %s" % d)
         c = cmap[ (d-1) % len(cmap) ] # wrap around if color map is too short
-        N = NurbsCurve(C.coords,degree=d)
+        N = NurbsCurve(C.coords, degree=d)
         if d <= dmax:
-            draw(N,color=c)
-            draw(N.knotPoints(),color=c,marksize=10)
+            draw(N, color=c)
+            draw(N.knotPoints(), color=c, marksize=10)
         else:
-            draw(N.approx(),color=c)
-            draw(N.knotPoints(),color=c,marksize=5)
+            draw(N.approx(), color=c)
+            draw(N.knotPoints(), color=c, marksize=5)
 
     n = 100
     u = arange(n+1)*1.0/n
     x = N.pointsAt(u)
     draw(x)
-    
-if __name__ == 'draw':
+
+if __name__ == '__draw__':
     run()
 # End
-
