@@ -1,11 +1,11 @@
-# $Id: 0b048e9 on Thu Jun 6 11:30:09 2013 +0200 by Benedict Verhegghe $
+# $Id$
 ##
-##  This file is part of pyFormex 0.9.1  (Tue Oct 15 21:05:25 CEST 2013)
+##  This file is part of pyFormex 1.0.5  (Sat Feb 16 10:40:32 CET 2019)
 ##  pyFormex is a tool for generating, manipulating and transforming 3D
 ##  geometrical models by sequences of mathematical operations.
 ##  Home page: http://pyformex.org
 ##  Project page:  http://savannah.nongnu.org/projects/pyformex/
-##  Copyright 2004-2013 (C) Benedict Verhegghe (benedict.verhegghe@ugent.be)
+##  Copyright 2004-2018 (C) Benedict Verhegghe (benedict.verhegghe@ugent.be)
 ##  Distributed under the GNU General Public License version 3 or later.
 ##
 ##  This program is free software: you can redistribute it and/or modify
@@ -26,24 +26,25 @@
 This example displays all the colors in the default palette on a grid
 of (ncolors+1) x (ncolors-1) squares.
 """
-from __future__ import print_function
+from __future__ import absolute_import, division, print_function
+
 _status = 'checked'
 _level = 'beginner'
 _topics = ['color']
-_techniques = ['palette','align']
+_techniques = ['palette', 'align']
 
-from gui.draw import *
+from pyformex.gui.draw import *
 
 def run():
     clear()
     flat()
     palette = pf.canvas.settings.colormap
     ncolors = len(palette)
-    F = Formex('4:0123').replic2(ncolors/2,2).setProp(range(ncolors))
-    G = Formex('4:0123').replic2(ncolors+1,ncolors-1).setProp(range(ncolors))
-    draw(align([F,G],'|00',offset=[1.,0.,0.]),color='prop')
+    F = Formex('4:0123').replicm((ncolors//2, 2)).setProp(arange(ncolors))
+    G = Formex('4:0123').replicm((ncolors+1, ncolors-1)).setProp(arange(ncolors))
+    draw(align([F, G], '|00', offset=[1., 0., 0.]))
 
 
-if __name__ == 'draw':
+if __name__ == '__draw__':
     run()
 # End
