@@ -1,11 +1,11 @@
-# $Id: 954dbe2 on Mon Mar 25 13:11:26 2013 +0100 by Benedict Verhegghe $
+# $Id$
 ##
-##  This file is part of pyFormex 0.9.1  (Tue Oct 15 21:05:25 CEST 2013)
+##  This file is part of pyFormex 1.0.5  (Sat Feb 16 10:40:32 CET 2019)
 ##  pyFormex is a tool for generating, manipulating and transforming 3D
 ##  geometrical models by sequences of mathematical operations.
 ##  Home page: http://pyformex.org
 ##  Project page:  http://savannah.nongnu.org/projects/pyformex/
-##  Copyright 2004-2013 (C) Benedict Verhegghe (benedict.verhegghe@ugent.be)
+##  Copyright 2004-2018 (C) Benedict Verhegghe (benedict.verhegghe@ugent.be)
 ##  Distributed under the GNU General Public License version 3 or later.
 ##
 ##  This program is free software: you can redistribute it and/or modify
@@ -24,37 +24,39 @@
 """Parabolic Tower
 
 """
-from __future__ import print_function
+from __future__ import absolute_import, division, print_function
+
+
 _status = 'checked'
 _level = 'beginner'
 _topics = ['geometry']
 _techniques = ['color']
 
-from gui.draw import *
+from pyformex.gui.draw import *
 
 h = 25.   # height of tower
 h1 = 18.  # height at neck of tower
 r = 10.   # radius at base of tower
 r1 = 5.   # radius at neck of tower
-m = 10    # number of sides at the base   
+m = 10    # number of sides at the base
 n = 8     # number of levels
 a = (r-r1)/h1**2; b = -2*a*h1; c = r; d = h/n
 g = lambda i: a*(d*i)**2 + b*d*i + c
 f = concatenate([
-    [[[g(i),i,i], [g(i+1),i-1,i+1]],
-     [[g(i),i,i], [g(i+1),i+1,i+1]],
-     [[g(i+1),i-1,i+1], [g(i+1),i+1,i+1]]]
+    [[[g(i), i, i], [g(i+1), i-1, i+1]],
+     [[g(i), i, i], [g(i+1), i+1, i+1]],
+     [[g(i+1), i-1, i+1], [g(i+1), i+1, i+1]]]
     for i in range(n) ])
-F = Formex(f,[3,0,1]).replic(m,2,dir=1)
-T = F.cylindrical(scale=[1,360./(2*m),d])
+F = Formex(f, [3, 0, 1]).replic(m, 2, dir=1)
+T = F.cylindrical(scale=[1, 360./(2*m), d])
 
 
 def run():
     reset()
     clear()
-    draw(T,view='bottom')
+    draw(T, view='bottom')
 
 
-if __name__ == 'draw':
+if __name__ == '__draw__':
     run()
 # End
