@@ -1,11 +1,11 @@
-# $Id: 954dbe2 on Mon Mar 25 13:11:26 2013 +0100 by Benedict Verhegghe $
+# $Id$
 ##
-##  This file is part of pyFormex 0.9.1  (Tue Oct 15 21:05:25 CEST 2013)
+##  This file is part of pyFormex 1.0.5  (Sat Feb 16 10:40:32 CET 2019)
 ##  pyFormex is a tool for generating, manipulating and transforming 3D
 ##  geometrical models by sequences of mathematical operations.
 ##  Home page: http://pyformex.org
 ##  Project page:  http://savannah.nongnu.org/projects/pyformex/
-##  Copyright 2004-2013 (C) Benedict Verhegghe (benedict.verhegghe@ugent.be)
+##  Copyright 2004-2018 (C) Benedict Verhegghe (benedict.verhegghe@ugent.be)
 ##  Distributed under the GNU General Public License version 3 or later.
 ##
 ##  This program is free software: you can redistribute it and/or modify
@@ -52,31 +52,33 @@ This process is illustrated in this example.
 - Finally F3 is obtained by rotating F2 over 180 degrees around the z-axis
   (and adding it to F2).
 """
-from __future__ import print_function
+from __future__ import absolute_import, division, print_function
+
+
 _status = 'checked'
 _level = 'beginner'
 _topics = ['geometry']
 _techniques = ['viewport', 'color', 'symmetry']
 
-from gui.draw import *
-    
+from pyformex.gui.draw import *
+
 def run():
     layout(4)
-    F0 = Formex('3:012934',[1,3])
-    F1 = F0.replic2(3,2)
+    F0 = Formex('3:012934', [1, 3])
+    F1 = F0.replicm((3, 2))
     F2 = F1 + F1.reflect(1)
-    F3 = F2 + F2.rotate(180.,1)
-    
-    for i,F in enumerate([F0,F1,F2,F3]):
+    F3 = F2 + F2.rotate(180., 1)
+
+    for i, F in enumerate([F0, F1, F2, F3]):
         viewport(i)
         flat()
         clear()
         #vp(i)
         draw(F)
-        drawText("F%s"%i,10,20,size=18)
+        drawText("F%s"%i, (10, 20), size=18)
         pf.canvas.update()
-    
-    
-if __name__ == 'draw':
+
+
+if __name__ == '__draw__':
     run()
 # End
