@@ -1,11 +1,11 @@
-# $Id: 954dbe2 on Mon Mar 25 13:11:26 2013 +0100 by Benedict Verhegghe $
+# $Id$
 ##
-##  This file is part of pyFormex 0.9.1  (Tue Oct 15 21:05:25 CEST 2013)
+##  This file is part of pyFormex 1.0.5  (Sat Feb 16 10:40:32 CET 2019)
 ##  pyFormex is a tool for generating, manipulating and transforming 3D
 ##  geometrical models by sequences of mathematical operations.
 ##  Home page: http://pyformex.org
 ##  Project page:  http://savannah.nongnu.org/projects/pyformex/
-##  Copyright 2004-2013 (C) Benedict Verhegghe (benedict.verhegghe@ugent.be)
+##  Copyright 2004-2018 (C) Benedict Verhegghe (benedict.verhegghe@ugent.be)
 ##  Distributed under the GNU General Public License version 3 or later.
 ##
 ##  This program is free software: you can redistribute it and/or modify
@@ -41,13 +41,15 @@ so on. Because the loop parameter is set True, the list of points is wrapped
 around when its end is reached, and the number of multiplex elements is thus
 always equal to the number of points.
 """
-from __future__ import print_function
+from __future__ import absolute_import, division, print_function
+
+
 _status = 'checked'
 _level = 'beginner'
 _topics = ['formex']
-_techniques = ['color','random','connect']
+_techniques = ['color', 'random', 'connect']
 
-from gui.draw import *
+from pyformex.gui.draw import *
 
 def run():
     resetAll()
@@ -55,17 +57,17 @@ def run():
     delay(2)
     setDrawOptions({'clear':True})
     npoints = 30
-    p = random.randint(0,7,(npoints,))
-    P = Formex(random.random((npoints,1,3)),p)
+    p = random.randint(0, 7, (npoints,))
+    P = Formex(random.random((npoints, 1, 3)), p)
     draw(P)
     smooth()
-    for n in range(1,5):
+    for n in range(1, 5):
         F = connect([P] * n,
                     bias=[i*(n-1) for i in range(n)],
                     loop=True)
         F.setProp(p)
         draw(F)
 
-if __name__ == 'draw':
+if __name__ == '__draw__':
     run()
 # End
