@@ -1,11 +1,11 @@
-# $Id: db1c7ff on Wed Oct 2 17:09:46 2013 +0200 by Benedict Verhegghe $
+# $Id$
 ##
-##  This file is part of pyFormex 0.9.1  (Tue Oct 15 21:05:25 CEST 2013)
+##  This file is part of pyFormex 1.0.5  (Sat Feb 16 10:40:32 CET 2019)
 ##  pyFormex is a tool for generating, manipulating and transforming 3D
 ##  geometrical models by sequences of mathematical operations.
 ##  Home page: http://pyformex.org
 ##  Project page:  http://savannah.nongnu.org/projects/pyformex/
-##  Copyright 2004-2013 (C) Benedict Verhegghe (benedict.verhegghe@ugent.be)
+##  Copyright 2004-2018 (C) Benedict Verhegghe (benedict.verhegghe@ugent.be)
 ##  Distributed under the GNU General Public License version 3 or later.
 ##
 ##  This program is free software: you can redistribute it and/or modify
@@ -28,16 +28,18 @@ This example illustrates the use of the mesh_ext.rectangular function
 and the use of seeds in generating Meshes.
 
 """
-from __future__ import print_function
+from __future__ import absolute_import, division, print_function
+
+
 _status = 'checked'
 _level = 'beginner'
 _topics = ['geometry', 'mesh']
-_techniques = ['rectangular','seed','layout']
+_techniques = ['rectangular', 'seed', 'layout']
 
 
-from gui.draw import *
-from plugins.mesh_ext import *
-from gui.viewportMenu import clearAll
+from pyformex.gui.draw import *
+from pyformex.plugins.mesh_ext import *
+from pyformex.gui.menus.Viewport import clearAll
 
 
 def run():
@@ -48,33 +50,33 @@ def run():
     clearAll()
     smoothwire()
     fgcolor(red)
-    layout(6,3)
+    layout(6, 3)
 
     viewport(0)
-    M = rectangle(1.,1.,6,3)
+    M = rectangle(1., 1., 6, 3)
     draw(M)
 
     viewport(1)
-    M = rectangle(1.,1.,(6,0.3),(6,0.3))
+    M = rectangle(1., 1., (6, 0.3), (6, 0.3))
     draw(M)
 
     viewport(2)
-    M = rectangle(1.,1.,(6,0.3),(6,-0.5))
+    M = rectangle(1., 1., (6, 0.3), (6, -0.5))
     draw(M)
 
     viewport(3)
-    M = rectangle(1.,1.,(6,0.5,0.5),(6,1,1))
+    M = rectangle(1., 1., (6, 0.5, 0.5), (6, 1, 1))
     draw(M)
 
     viewport(4)
-    M = rectangle(1.,1.,(6,-1,-1),(6,-1,-1))
+    M = rectangle(1., 1., (6, -1, -1), (6, -1, -1))
     draw(M)
 
     viewport(5)
-    M = rectangle(2.,1.,(6,-1,-1),(6,-1,-1))
+    M = rectangle(2., 1., (6, -1, -1), (6, -1, -1))
     draw(M)
 
 
-if __name__ == 'draw':
+if __name__ == '__draw__':
     run()
 # End
