@@ -1,11 +1,11 @@
-# $Id: 954dbe2 on Mon Mar 25 13:11:26 2013 +0100 by Benedict Verhegghe $
+# $Id$
 ##
-##  This file is part of pyFormex 0.9.1  (Tue Oct 15 21:05:25 CEST 2013)
+##  This file is part of pyFormex 1.0.5  (Sat Feb 16 10:40:32 CET 2019)
 ##  pyFormex is a tool for generating, manipulating and transforming 3D
 ##  geometrical models by sequences of mathematical operations.
 ##  Home page: http://pyformex.org
 ##  Project page:  http://savannah.nongnu.org/projects/pyformex/
-##  Copyright 2004-2013 (C) Benedict Verhegghe (benedict.verhegghe@ugent.be)
+##  Copyright 2004-2018 (C) Benedict Verhegghe (benedict.verhegghe@ugent.be)
 ##  Distributed under the GNU General Public License version 3 or later.
 ##
 ##  This program is free software: you can redistribute it and/or modify
@@ -63,28 +63,30 @@ for the displayed cube by pressing the **Permutations** button.
 This number is not stored, it is calculated each time. It's a nice example
 of how easily Python can handle huge numbers.
 """
-from __future__ import print_function
+from __future__ import absolute_import, division, print_function
+
+
 _status = 'checked'
 _level = 'normal'
-_topics = ['illustration','game']
-_techniques = ['color','dialog','draw','persistence','random']
+_topics = ['illustration', 'game']
+_techniques = ['color', 'dialog', 'draw', 'persistence', 'random']
 _createdby = ['tpraet']
 
-from gui.draw import *
-from gui.viewport import *
+from pyformex.gui.draw import *
+from pyformex.gui.viewport import *
 from numpy.random import rand
 
 
 # General definitions
 def createCube(n=3):
     tol = 0.005
-    front = Formex('4:0123').replic2(n,n).translate([-n/2.,-n/2.,-n/2.])
-    sides = front+front.translate(2,n)
-    darkPosTol = Formex('4:0123').replic2(n,n).translate([-n/2.,-n/2.,0.]).scale(1.-5.*tol/n).translate(2, -n/2.+1+tol)
+    front = Formex('4:0123').replicm((n, n)).translate([-n/2., -n/2., -n/2.])
+    sides = front+front.translate(2, n)
+    darkPosTol = Formex('4:0123').replicm((n, n)).translate([-n/2., -n/2., 0.]).scale(1.-5.*tol/n).translate(2, -n/2.+1+tol)
     darkNegTol = darkPosTol.translate(2, -2*tol)
     dark = darkPosTol.replic(n-1, 1, dir=2) + darkNegTol.replic(n-1, 1, dir=2)
-    cube = sides + sides.rotate(90,1) + sides.rotate(90,0) + dark + dark.rotate(90, 0) + dark.rotate(90, 1)
-    cube.prop = append(repeat(array([5,1,3,2,6,7]),n**2), repeat(array([0]), 6*(n-1)*n**2))
+    cube = sides + sides.rotate(90, 1) + sides.rotate(90, 0) + dark + dark.rotate(90, 0) + dark.rotate(90, 1)
+    cube.prop = append(repeat(array([5, 1, 3, 2, 6, 7]), n**2), repeat(array([0]), 6*(n-1)*n**2))
     return cube
 
 def refresh():
@@ -104,7 +106,7 @@ def turn(x=0,y=0,action=0):
         busy = False
         element = selectElement(pf.canvas, x, y, 2, 2)
         if element == [-1]:
-            message('No element selected.\nPlease select an element of the cube.')
+            print('No element selected.\nPlease select an element of the cube.')
 #        else:
 #            draw(cube[element], color=red, bbox='last', linewidth=5.0)
         busy = False
@@ -122,7 +124,7 @@ def turn(x=0,y=0,action=0):
             v = [dx, dy, 0]
             rot = pf.canvas.camera.rot[:3, :3]
             v2 = dot(v, linalg.inv(rot))
-            V = v2/sqrt(dot(v2,v2.conj()))
+            V = v2/sqrt(dot(v2, v2.conj()))
             centers = cube.centroids()
             P1 = centers[element][0]
 #            draw(Formex([[P1, P1+V]]), color=red, bbox='last', linewidth=3.0)
@@ -136,7 +138,7 @@ def selectElement(self, x, y, w, h):
     self.selection.clear()
     self.selection.setType('element')
     self.selection_filter = None
-    self.pick_window = (x,y,w,h,GL.glGetIntegerv(GL.GL_VIEWPORT))
+    self.pick_window = (x, y, w, h, GL.glGetIntegerv(GL.GL_VIEWPORT))
     self.pick_parts('element', 54, store_closest=True)
     if len(self.picked) != 0:
         self.selection_front = self.closest_pick
@@ -172,7 +174,7 @@ def rotateRow(self, rowElements, rotAxis, dir, steps=1, view=True):
         if steps == 0:
             steps = 1
         for i in range(steps):
-            self[rowElements] = self[rowElements].rotate(angle/steps, rotAxis)        
+            self[rowElements] = self[rowElements].rotate(angle/steps, rotAxis)
             dr = drawn
             drawn = draw(self, bbox='last')
             undraw(dr)
@@ -185,19 +187,19 @@ def perm(n=2):
     even = (n%2==0)
     if even:
         if n<3:
-            return fac(8)*3**7/24
+            return fac(8)*3**7//24
         else:
-            return fac(8)*3**7*(fac(24)/fac(4)**6)**((n-2)/2)**2*fac(24)**((n-2)/2)/24
+            return fac(8)*3**7*(fac(24)//fac(4)**6)**((n-2)//2)**2*fac(24)**((n-2)//2)/24
     else:
         if n<4:
-            return fac(8)*3**7*fac(12)/2*2**11
+            return fac(8)*3**7*fac(12)//2*2**11
         else:
-            return fac(8)*3**7*(fac(24)/fac(4)**6)**(((n-3)/2)**2+(n-3)/2)*fac(12)/2*2**11*fac(24)**((n-3)/2)
+            return fac(8)*3**7*(fac(24)//fac(4)**6)**(((n-3)//2)**2+(n-3)//2)*fac(12)//2*2**11*fac(24)**((n-3)//2)
 
 def fac(x):
     """Return the factorial of x"""
     import functools
-    return functools.reduce(lambda y,z:y*z,range(1,x+1))
+    return functools.reduce(lambda y, z:y*z, list(range(1, x+1)))
 
 # Dialog
 dia = None
@@ -220,22 +222,22 @@ def set():
 def shuffle():
     global cube
     N = int(10*n + 5*n*rand())
-    random = rand(N,6)
+    random = rand(N, 6)
     centers = cube.centroids()
     for i in random:
         rotateCube(cube, int(3*i[0]), i[1]<0.5, centers[int(i[2]*6*n**2)], i[3:6], view=False)
     refresh()
 
 def permutations():
-    message('The total number of permutations of a %sx%s cube is:' % (n,n))
+    print('The total number of permutations of a %sx%s cube is:' % (n, n))
     N = str(perm(n))
-    message(N)
-    message('or roughly %s.%se%s' % (N[0],N[1:4],len(N)-1))
+    print(N)
+    print('or roughly %s.%se%s' % (N[0], N[1:4], len(N)-1))
 
 def close():
-    pf.canvas.resetMouse(LEFT,SHIFT)
+    pf.canvas.resetMouse(LEFT, SHIFT)
     dia.close()
-    # Release script lock 
+    # Release script lock
     scriptRelease(__file__)
 
 def timeOut():
@@ -248,14 +250,14 @@ dia = widgets.InputDialog(
     items=[
         _I('n', 3,  text='Number of elements on a row', itemtype='slider', min=2, max=10, ticks=1),
         _I('steps', 10, text='Animation steps', itemtype='slider', min=0, max=50, ticks=5),
-        _I('t', 0.05, text='Time between steps', min=0),  
+        _I('t', 0.05, text='Time between steps', min=0),
    ],
     actions=[
-        ('New',new),
-        ('Set', set), 
-        ('Shuffle',shuffle),
-        ('Permutations',permutations),
-        ('Close',close),
+        ('New', new),
+        ('Set', set),
+        ('Shuffle', shuffle),
+        ('Permutations', permutations),
+        ('Close', close),
     ])
 
 def run():
@@ -267,16 +269,16 @@ def run():
     cube = createCube()
     busy = False
     refresh()
-    drawText("Rotate a row by moving the mouse with left button pressed.\nUse ALT button to rotate the whole cube.",20,40,color=blue,font='f',size=20)
-    pf.canvas.setMouse(LEFT,turn)
+    drawText("Rotate a row by moving the mouse with left button pressed.\nUse ALT button to rotate the whole cube.", (20, 40), color=blue, size=20)
+    pf.canvas.setMouse(LEFT, turn)
     dia.timeout = timeOut
     dia.show()
     dia.acceptData()
     globals().update(dia.results)
 
-    # Block other scripts 
+    # Block other scripts
     scriptLock(__file__)
 
-if __name__ == 'draw':
+if __name__ == '__draw__':
     run()
 # End
