@@ -1,11 +1,11 @@
-# $Id: 954dbe2 on Mon Mar 25 13:11:26 2013 +0100 by Benedict Verhegghe $
+#
 ##
-##  This file is part of pyFormex 0.9.1  (Tue Oct 15 21:05:25 CEST 2013)
+##  This file is part of pyFormex 1.0.5  (Sat Feb 16 10:40:32 CET 2019)
 ##  pyFormex is a tool for generating, manipulating and transforming 3D
 ##  geometrical models by sequences of mathematical operations.
 ##  Home page: http://pyformex.org
 ##  Project page:  http://savannah.nongnu.org/projects/pyformex/
-##  Copyright 2004-2013 (C) Benedict Verhegghe (benedict.verhegghe@ugent.be)
+##  Copyright 2004-2018 (C) Benedict Verhegghe (benedict.verhegghe@ugent.be)
 ##  Distributed under the GNU General Public License version 3 or later.
 ##
 ##  This program is free software: you can redistribute it and/or modify
@@ -34,30 +34,35 @@ pyFormex code.
 Later I added some nice utilities to make it worthwile as a programming example.
 It would be nice a nice exercise to add a GUI to create and position the shapes.
 """
-from __future__ import print_function
+from __future__ import absolute_import, division, print_function
+
+
 _status = 'checked'
 _level = 'normal'
 _topics = ['illustration']
 _techniques = ['animation']
 
-from gui.draw import *
-   
+from pyformex.gui.draw import *
+
 
 def circle(n=60):
     a1 = 360./n
-    return Formex([[[cosd(i*a1),sind(i*a1),0.] for i in range(n)]])
+    # we do not have the 'polygon' mode anymore!
+    #return Formex([[[cosd(i*a1), sind(i*a1), 0.] for i in range(n)]])
+    # therefore create all triangles
+    return Formex([[[0.,0.],[cosd(i*a1), sind(i*a1)],[cosd((i+1)*a1), sind((i+1)*a1)]] for i in range(n)])
 
 def triangle():
-    return Formex([[[0.,0.,0.],[1.,0.,0.],[0.5,0.5*sqrt(3.),0.]]])
+    return Formex([[[0., 0., 0.], [1., 0., 0.], [0.5, 0.5*sqrt(3.), 0.]]])
 
 def square():
-    return Formex([[[0.,0.,0.],[1.,0.,0.],[1.,1.,0.],[0.,1.,0.]]])
+    return Formex([[[0., 0., 0.], [1., 0., 0.], [1., 1., 0.], [0., 1., 0.]]])
 
 
-class Shape(Geometry):
-    def __init__(self,shape,size,position,color):
+class Shape(object):
+    def __init__(self, shape, size, position, color):
         self.shape = shape
-        self.size = resize(size,(3))
+        self.size = resize(size, (3))
         self.position = position
         self.color = color
         self.F = None
@@ -68,7 +73,7 @@ class Shape(Geometry):
         self.F = globals()[self.shape]().scale(self.size).translate(self.position)
 
     def draw(self):
-        self.A = draw(self.F,color=self.color)
+        self.A = draw(self.F, color=self.color)
 
     def hide(self):
         if self.A:
@@ -93,18 +98,18 @@ class Shape(Geometry):
         self.color = color
         self.draw()
 
-    def move(self,direction,step):
-        self.F = self.F.trl(direction,step)
+    def move(self, direction, step):
+        self.F = self.F.trl(direction, step)
 
 
 def run():
     clear()
     flat()
 
-    wall = Shape('square',[80.,60.],[10.,0.],'red')
-    window = Shape('square',[10.,10.],[30.,30.],'white')
-    roof = Shape('triangle',[100.,40.],[0.,60.],'green')
-    sun = Shape('circle',10,[110.,80.],'yellow')
+    wall = Shape('square', [80., 60.], [10., 0.], 'red')
+    window = Shape('square', [10., 10.], [30., 30.], 'white')
+    roof = Shape('triangle', [100., 40.], [0., 60.], 'green')
+    sun = Shape('circle', 10, [110., 80.], 'yellow')
 
     delay(0)
     window.draw()
@@ -119,13 +124,13 @@ def run():
     setDrawOptions({'bbox':None})
     sun.hide()
     for y in range(n):
-        sun.move(0,sqrt(0.4*(n-y)/n))
-        sun.move(1,-100./n)
+        sun.move(0, sqrt(0.4*(n-y)/n))
+        sun.move(1, -100./n)
         sun.redraw()
 
-        
+
     sun.hide()
-    
-if __name__ == 'draw':
+
+if __name__ == '__draw__':
     run()
 # End
