@@ -1,11 +1,11 @@
-# $Id: 954dbe2 on Mon Mar 25 13:11:26 2013 +0100 by Benedict Verhegghe $
+# $Id$
 ##
-##  This file is part of pyFormex 0.9.1  (Tue Oct 15 21:05:25 CEST 2013)
+##  This file is part of pyFormex 1.0.5  (Sat Feb 16 10:40:32 CET 2019)
 ##  pyFormex is a tool for generating, manipulating and transforming 3D
 ##  geometrical models by sequences of mathematical operations.
 ##  Home page: http://pyformex.org
 ##  Project page:  http://savannah.nongnu.org/projects/pyformex/
-##  Copyright 2004-2013 (C) Benedict Verhegghe (benedict.verhegghe@ugent.be)
+##  Copyright 2004-2018 (C) Benedict Verhegghe (benedict.verhegghe@ugent.be)
 ##  Distributed under the GNU General Public License version 3 or later.
 ##
 ##  This program is free software: you can redistribute it and/or modify
@@ -30,30 +30,31 @@ surface and the animation of the results.
 A model of a horse is repeatedly cut by a plane and the cut-off parts
 are rotated and translated.
 """
-from __future__ import print_function
+from __future__ import absolute_import, division, print_function
+
+
 _status = 'checked'
 _level = 'advanced'
 _topics = ['surface']
-_techniques = ['color','widgets','animation']
+_techniques = ['color', 'widgets', 'animation']
 
-from gui.draw import *
-from plugins.trisurface import TriSurface
+from pyformex.gui.draw import *
 
 def askSlices(bb):
-    res = askItems([('Direction',0),
-                    ('# slices',15),
-                    ('total rot',70.),
-                   ],caption = 'Define the slicing planes')
+    res = askItems([('Direction', 0),
+                    ('# slices', 15),
+                    ('total rot', 70.),
+                   ], caption = 'Define the slicing planes')
     if res:
         axis = res['Direction']
         nslices = res['# slices']
         totalrot = res['total rot']
-        xmin,xmax = bb[:,axis]
+        xmin, xmax = bb[:, axis]
         dx =  (xmax-xmin) / nslices
         x = arange(nslices+1) * dx
         N = unitVector(axis)
         P = [ bb[0]+N*s for s in x ]
-        return P,N,totalrot
+        return P, N, totalrot
     else:
         return None
 
@@ -63,16 +64,17 @@ def run():
     smooth()
     lights(True)
     transparent(False)
-    setView('horse',[20,20,0])
+    setView('horse', [20, 20, 0])
     S = TriSurface.read(getcfg('datadir')+'/horse.off')
     bb = S.bbox()
 
     t = -0.3
     bb[0] = (1.0-t)*bb[0] + t*bb[1]
-    draw(S,bbox=bb,view='front')
+    draw(S, bbox=bb, view='front')
+    return
 
     try:
-        P,n,t = askSlices(S.bbox())
+        P, n, t = askSlices(S.bbox())
     except:
         return
 
@@ -85,29 +87,29 @@ def run():
 
     clear()
     A = None
-    for i,p in enumerate(P):
-        F1,F = F.cutWithPlane(p,-n)
+    for i, p in enumerate(P):
+        F1, F = F.cutWithPlane(p, -n)
         if F1.nelems() > 0:
             F1.setProp(i)
-        G = [ g.rot(a,around=p) for g in G ] 
+        G = [ g.rot(a, around=p) for g in G ]
         G.append(F1)
         #clear()
-        B = draw([F,G])
+        B = draw([F, G])
         if A:
             undraw(A)
         A = B
-            
+
     seterr(**old)
 
-    x = pf.canvas.width()/2
+    x = pf.canvas.width()//2
     y = pf.canvas.height() - 40
-    T = drawText("No animals got hurt during the making of this movie!",x,y,size=18,gravity='C')
+    T = drawText("No animals got hurt during the making of this movie!", (x, y), size=18, gravity='C')
     for i in range(10):
         sleep(0.3)
         undecorate(T)
         sleep(0.3)
         decorate(T)
 
-if __name__ == 'draw':
+if __name__ == '__draw__':
     run()
 # End
