@@ -1,11 +1,11 @@
-# $Id: 954dbe2 on Mon Mar 25 13:11:26 2013 +0100 by Benedict Verhegghe $
+# $Id$
 ##
-##  This file is part of pyFormex 0.9.1  (Tue Oct 15 21:05:25 CEST 2013)
+##  This file is part of pyFormex 1.0.5  (Sat Feb 16 10:40:32 CET 2019)
 ##  pyFormex is a tool for generating, manipulating and transforming 3D
 ##  geometrical models by sequences of mathematical operations.
 ##  Home page: http://pyformex.org
 ##  Project page:  http://savannah.nongnu.org/projects/pyformex/
-##  Copyright 2004-2013 (C) Benedict Verhegghe (benedict.verhegghe@ugent.be)
+##  Copyright 2004-2018 (C) Benedict Verhegghe (benedict.verhegghe@ugent.be)
 ##  Distributed under the GNU General Public License version 3 or later.
 ##
 ##  This program is free software: you can redistribute it and/or modify
@@ -24,15 +24,17 @@
 """Double Layer Flat Space Truss Roof
 
 """
-from __future__ import print_function
+from __future__ import absolute_import, division, print_function
+
+
 _status = 'checked'
 _level = 'advanced'
 _topics = ['FEA']
-_techniques = ['color'] 
+_techniques = ['color']
 
-from gui.draw import *
-from plugins.properties import *
-from plugins.fe_abq import *
+from pyformex.gui.draw import *
+from pyformex.plugins.properties import *
+from pyformex.plugins.fe_abq import *
 import os
 
 def run():
@@ -42,8 +44,8 @@ def run():
 
     dx = 1800 # Modular size [mm]
     ht = 900  # Deck height [mm]
-    nx = 4     # number of bottom deck modules in x direction 
-    ny = 5   # number of bottom deck modules in y direction 
+    nx = 4     # number of bottom deck modules in x direction
+    ny = 5   # number of bottom deck modules in y direction
 
     q = -0.005 #distributed load [N/mm^2]
 
@@ -52,21 +54,22 @@ def run():
     #Creating the model
     ###################
 
-    top = (Formex("1").replic2(nx-1,ny,1,1) + Formex("2").replic2(nx,ny-1,1,1)).scale(dx)
+    top = (Formex('l:1').replicm((nx-1, ny)) + Formex('l:2').replicm((nx, ny-1))).scale(dx)
     top.setProp(3)
-    bottom = (Formex("1").replic2(nx,ny+1,1,1) + Formex("2").replic2(nx+1,ny,1,1)).scale(dx).translate([-dx/2,-dx/2,-ht])
+    bottom = (Formex('l:1').replicm((nx, ny+1)) + Formex('l:2').replicm((nx+1, ny))).scale(dx).translate([-dx/2, -dx/2, -ht])
     bottom.setProp(0)
-    T0 = Formex(4*[[[0,0,0]]]) 	   # 4 times the corner of the top deck
-    T4 = bottom.select([0,1,nx,nx+1])  # 4 nodes of corner module of bottom deck
-    dia = connect([T0,T4]).replic2(nx,ny,dx,dx)
+    T0 = Formex(4*[[[0, 0, 0]]]) 	   # 4 times the corner of the top deck
+    T4 = bottom.select([0, 1, nx, nx+1])  # 4 nodes of corner module of bottom deck
+    dia = connect([T0, T4]).replicm((nx, ny), (dx, dx))
     dia.setProp(1)
 
     F = (top+bottom+dia)
 
     # Show upright
-    createView('myview1',(0.,-90.,0.))
-    clear();linewidth(1);draw(F,view='myview1')
-
+    createView('myview1', (0., -90., 0.))
+    clear()
+    linewidth(1)
+    draw(F, view='myview1')
 
     ############
     #Creating FE-model
@@ -77,17 +80,17 @@ def run():
     ###############
     #Creating elemsets
     ###################
-    # Remember: elems are in the same order as elements in F
-    topbar = where(F.prop==3)[0]
-    bottombar = where(F.prop==0)[0]
-    diabar = where(F.prop==1)[0]
+    # Remember: elements in mesh are in the same order as elements in F
+    topbar = where(M.prop==3)[0]
+    bottombar = where(M.prop==0)[0]
+    diabar = where(M.prop==1)[0]
 
     ###############
     #Creating nodesets
     ###################
 
-    nnod=M.ncoords()
-    nlist=arange(nnod)
+    nnod = M.ncoords()
+    nlist = arange(nnod)
     count = zeros(nnod)
     for n in M.elems.flat:
         count[n] += 1
@@ -96,8 +99,8 @@ def run():
     topcorner = nlist[count==6]
     bottomedge = nlist[count==5]
     bottomcorner = nlist[count==3]
-    support = concatenate([bottomedge,bottomcorner])
-    edge =  concatenate([topedge,topcorner])
+    edge =  concatenate([topedge, topcorner])
+    support = concatenate([bottomedge, bottomcorner])
 
     ########################
     #Defining and assigning the properties
@@ -106,23 +109,23 @@ def run():
     Q = 0.5*q*dx*dx
 
     P = PropertyDB()
-    P.nodeProp(set=field,cload = [0,0,Q,0,0,0])
-    P.nodeProp(set=edge,cload = [0,0,Q/2,0,0,0])
-    P.nodeProp(set=support,bound = [1,1,1,0,0,0])
+    P.nodeProp(set=field, cload = [0, 0, Q, 0, 0, 0])
+    P.nodeProp(set=edge, cload = [0, 0, Q/2, 0, 0, 0])
+    P.nodeProp(set=support, bound = [1, 1, 1, 0, 0, 0])
 
     circ20 = ElemSection(section={'name':'circ20','sectiontype':'Circ','radius':10, 'cross_section':314.159}, material={'name':'S500', 'young_modulus':210000, 'shear_modulus':81000, 'poisson_ratio':0.3, 'yield_stress' : 500,'density':0.000007850})
 
     # example of how to set the element type by set
-    P.elemProp(set=topbar,section=circ20,eltype='T3D2')
-    P.elemProp(set=bottombar,section=circ20,eltype='T3D2')
+    P.elemProp(set=topbar, section=circ20, eltype='T3D2')
+    P.elemProp(set=bottombar, section=circ20, eltype='T3D2')
 
     # alternatively, we can specify the elements by an index value
     # in an array that we will pass in the Abqdata 'eprop' argument
-    P.elemProp(prop=1,section=circ20,eltype='T3D2')
+    P.elemProp(prop=1, section=circ20, eltype='T3D2')
 
     # Since all elements have same characteristics, we could just have used:
     #   P.elemProp(section=circ20,elemtype='T3D2')
-    # But putting the elems in three sets allows for separate postprocessing 
+    # But putting the elems in three sets allows for separate postprocessing
 
 
     # Print node and element property databases
@@ -138,18 +141,18 @@ def run():
     ###################
 
     step = Step(
-        out = [ Output(type='field',variable='preselect') ],
-        res = [ Result(kind='element',keys=['S']),
-                Result(kind='node',keys=['U'])
+        out = [ Output(type='field') ],
+        res = [ Result(kind='element', keys=['S']),
+                Result(kind='node', keys=['U'])
                 ]
         )
-    model = Model(M.coords,M.elems)
+    model = Model(M.coords, M.elems)
 
     if not checkWorkdir():
         return
 
-    AbqData(model,P,[step],eprop=F.prop).write('SpaceTruss')
+    AbqData(model, P, [step], eprop=F.prop).write('SpaceTruss')
 
-if __name__ == 'draw':
+if __name__ == '__draw__':
     run()
 # End
