@@ -1,11 +1,11 @@
-# $Id: 954dbe2 on Mon Mar 25 13:11:26 2013 +0100 by Benedict Verhegghe $
+# $Id$
 ##
-##  This file is part of pyFormex 0.9.1  (Tue Oct 15 21:05:25 CEST 2013)
+##  This file is part of pyFormex 1.0.5  (Sat Feb 16 10:40:32 CET 2019)
 ##  pyFormex is a tool for generating, manipulating and transforming 3D
 ##  geometrical models by sequences of mathematical operations.
 ##  Home page: http://pyformex.org
 ##  Project page:  http://savannah.nongnu.org/projects/pyformex/
-##  Copyright 2004-2013 (C) Benedict Verhegghe (benedict.verhegghe@ugent.be)
+##  Copyright 2004-2018 (C) Benedict Verhegghe (benedict.verhegghe@ugent.be)
 ##  Distributed under the GNU General Public License version 3 or later.
 ##
 ##  This program is free software: you can redistribute it and/or modify
@@ -24,13 +24,15 @@
 """Sphere
 
 """
-from __future__ import print_function
+from __future__ import absolute_import, division, print_function
+
+
 _status = 'checked'
 _level = 'normal'
-_topics = ['geometry','surface','sphere']
+_topics = ['geometry', 'surface', 'sphere']
 _techniques = ['dialog', 'color']
 
-from gui.draw import *
+from pyformex.gui.draw import *
 
 def run():
     clear()
@@ -45,16 +47,16 @@ def run():
 
     # First, a line based model
 
-    base = Formex('l:543',[1,2,3]) # single cell
+    base = Formex('l:543', [1, 2, 3]) # single cell
     draw(base)
 
-    d = base.select([0]).replic2(nx,ny,1,1)   # all diagonals
-    m = base.select([1]).replic2(nx,ny,1,1)   # all meridionals
-    h = base.select([2]).replic2(nx,ny+1,1,1) # all horizontals
+    d = base.select([0]).replicm((nx, ny))   # all diagonals
+    m = base.select([1]).replicm((nx, ny))   # all meridionals
+    h = base.select([2]).replicm((nx, ny)) # all horizontals
     f = m+d+h
     draw(f)
 
-    g = f.translate([0,a,1]).spherical(scale=[360./nx,bot/(ny+a),rd])
+    g = f.translate([0, a, 1]).spherical(scale=[360./nx, bot/(ny+a), rd])
     clear()
     draw(g)
 
@@ -62,32 +64,32 @@ def run():
 
     clear()
     flat()
-    base = Formex( [[[0,0,0],[1,0,0],[1,1,0]],
-                    [[1,1,0],[0,1,0],[0,0,0]]],
-                   [1,3] )
+    base = Formex( [[[0, 0, 0], [1, 0, 0], [1, 1, 0]],
+                    [[1, 1, 0], [0, 1, 0], [0, 0, 0]]],
+                   [1, 3] )
     draw(base)
 
-    f = base.replic2(nx,ny,1,1)
+    f = base.replicm((nx, ny))
     draw(f)
 
-    h = f.translate([0,a,1]).spherical(scale=[360./nx,bot/(ny+a),rd])
+    h = f.translate([0, a, 1]).spherical(scale=[360./nx, bot/(ny+a), rd])
     clear()
     draw(h)
 
     # Both
 
-    g = g.translate([-rd,0,0])
-    h = h.translate([rd,0,0])
+    g = g.translate([-rd, 0, 0])
+    h = h.translate([rd, 0, 0])
     clear()
-    bb = bbox([g,h])
-    draw(g,bbox=bb)
-    draw(h,bbox=bb)
+    bb = bbox([g, h])
+    draw(g, bbox=bb)
+    draw(h, bbox=bb)
 
 
     ##if ack('Do you want to see the spheres with smooth rendering?'):
     ##    smooth()
     ##    pf.canvas.update()
 
-if __name__ == 'draw':
+if __name__ == '__draw__':
     run()
 # End
