@@ -1,11 +1,11 @@
-# $Id: 954dbe2 on Mon Mar 25 13:11:26 2013 +0100 by Benedict Verhegghe $
+# $Id$
 ##
-##  This file is part of pyFormex 0.9.1  (Tue Oct 15 21:05:25 CEST 2013)
+##  This file is part of pyFormex 1.0.5  (Sat Feb 16 10:40:32 CET 2019)
 ##  pyFormex is a tool for generating, manipulating and transforming 3D
 ##  geometrical models by sequences of mathematical operations.
 ##  Home page: http://pyformex.org
 ##  Project page:  http://savannah.nongnu.org/projects/pyformex/
-##  Copyright 2004-2013 (C) Benedict Verhegghe (benedict.verhegghe@ugent.be)
+##  Copyright 2004-2018 (C) Benedict Verhegghe (benedict.verhegghe@ugent.be)
 ##  Distributed under the GNU General Public License version 3 or later.
 ##
 ##  This program is free software: you can redistribute it and/or modify
@@ -30,14 +30,16 @@ one a triangulated surface (simple.sphere3).
 Remark that simple.sphere3 may contain degenerate triangles at the north and
 south pole.
 """
-from __future__ import print_function
+from __future__ import absolute_import, division, print_function
+
+
 _status = 'checked'
 _level = 'normal'
-_topics = ['geometry','surface','sphere']
+_topics = ['geometry', 'surface', 'sphere']
 _techniques = ['color']
 
-from gui.draw import *
-from simple import sphere2,sphere3
+from pyformex.gui.draw import *
+from pyformex.simple import sphere2, sphere3
 
 def run():
     reset()
@@ -49,20 +51,19 @@ def run():
     smooth()
     setView('front')
     for i in range(ns):
-        print("nx=%s, ny=%s" % (nx,ny))
-        b = sphere2(nx,ny,bot=-90,top=90).translate(0,-1.0)
-        s = sphere3(nx,ny,bot=-90,top=90)
-        s = s.translate(0,1.0)
+        print("nx=%s, ny=%s" % (nx, ny))
+        b = sphere2(nx, ny, bot=-90, top=90).translate(0, -1.0)
+        s = sphere3(nx, ny, bot=-90, top=90)
+        s = s.translate(0, 1.0)
         s.setProp(3)
         clear()
-        bb = bbox([b,s])
-        draw(b,bbox=bb,wait=False)
-        draw(s,bbox=bb)#,color='random')
+        bb = bbox([b, s])
+        draw(b, bbox=bb, wait=False)
+        draw(s, bbox=bb)#,color='random')
         nx = int(m*nx)
         ny = int(m*ny)
         sleep(2)
 
-if __name__ == 'draw':
+if __name__ == '__draw__':
     run()
 # End
-
