@@ -1,11 +1,11 @@
-# $Id: 954dbe2 on Mon Mar 25 13:11:26 2013 +0100 by Benedict Verhegghe $
+#
 ##
-##  This file is part of pyFormex 0.9.1  (Tue Oct 15 21:05:25 CEST 2013)
+##  This file is part of pyFormex 1.0.5  (Sat Feb 16 10:40:32 CET 2019)
 ##  pyFormex is a tool for generating, manipulating and transforming 3D
 ##  geometrical models by sequences of mathematical operations.
 ##  Home page: http://pyformex.org
 ##  Project page:  http://savannah.nongnu.org/projects/pyformex/
-##  Copyright 2004-2013 (C) Benedict Verhegghe (benedict.verhegghe@ugent.be)
+##  Copyright 2004-2018 (C) Benedict Verhegghe (benedict.verhegghe@ugent.be)
 ##  Distributed under the GNU General Public License version 3 or later.
 ##
 ##  This program is free software: you can redistribute it and/or modify
@@ -37,7 +37,7 @@ two sets of curves are predefined:
   with a series of parallel planes. The original surface model was
   obtained from medical imaging processes and represents a human
   artery with a kink. These curves are read from a geometry file
-  'splines.pgf' include in the pyFormex distribution. 
+  'splines.pgf' include in the pyFormex distribution.
 
 In the first case, the number of curves will be equal to the specified
 number.  In the latter case, the number can not be larger than the
@@ -48,13 +48,15 @@ consisting of quadrilaterals). The number of elements along the
 splines can be chosen. The number of elements across the splines is
 currently unused.
 """
-from __future__ import print_function
+from __future__ import absolute_import, division, print_function
+from pyformex import zip
+
 _status = 'checked'
 _level = 'advanced'
-_topics = ['geometry','surface']
+_topics = ['geometry', 'surface']
 _techniques = ['spline']
 
-from gui.draw import *
+from pyformex.gui.draw import *
 
 
 ##
@@ -64,12 +66,12 @@ from gui.draw import *
 """Definition of surfaces in pyFormex.
 
 This module defines classes and functions specialized for handling
-two-dimensional geometry in pyFormex. 
+two-dimensional geometry in pyFormex.
 """
 
 import numpy as np
-from geometry import Geometry
-from plugins.curve import *
+from pyformex.geometry import Geometry
+from pyformex.plugins.curve import *
 
 
 ##############################################################################
@@ -84,16 +86,16 @@ def rollCurvePoints(curve,n=1):
 
     This only works for PolyLine and BezierSpline (and derived) classes.
     """
-    if (isinstance(curve,PolyLine) or isinstance(curve,BezierSpline)) and curve.closed:
-        if isinstance(curve,PolyLine):
+    if (isinstance(curve, PolyLine) or isinstance(curve, BezierSpline)) and curve.closed:
+        if isinstance(curve, PolyLine):
             mult = 1
         else:
             mult = curve.degree
-        curve.coords[:-1] = roll(curve.coords[:-1],-mult*n,axis=0)
+        curve.coords[:-1] = roll(curve.coords[:-1], -mult*n, axis=0)
         curve.coords[-1] = curve.coords[0]
     else:
-        raise ValueError,"Expected a closed PolyLine or BezierSpline."
-    
+        raise ValueError("Expected a closed PolyLine or BezierSpline.")
+
 
 def alignCurvePoints(curve,axis=1,max=True):
     """Roll the points of a closed curved according to some rule.
@@ -105,15 +107,15 @@ def alignCurvePoints(curve,axis=1,max=True):
     The function returns nothing: the points are rolled inplace.
     """
     if not curve.closed:
-        raise ValueError,"Expected a closed curve."
+        raise ValueError("Expected a closed curve.")
     if max:
-        ind = curve.pointsOn()[:,axis].argmax()
+        ind = curve.pointsOn()[:, axis].argmax()
     else:
-        ind = curve.pointsOn()[:,axis].argmin()
-    rollCurvePoints(curve,ind)
-    
+        ind = curve.pointsOn()[:, axis].argmin()
+    rollCurvePoints(curve, ind)
 
-class SplineSurface(Geometry):
+
+class SplineSurface(object):
     """A surface created by a sequence of splines.
 
     The surface consists of a list of curves. The parametric value of
@@ -131,7 +133,7 @@ class SplineSurface(Geometry):
         self.uclosed = sum(closed) > 0
         errors = [ c.closed != self.uclosed for c in self.curves ]
         if sum(errors) > 0:
-            raise ValueError,"Either ALL or NONE of the curves should be closed."
+            raise ValueError("Either ALL or NONE of the curves should be closed.")
         if nu <= 0:
             nu = len(curves)-1
         self.grid = self.createGrid(nu)
@@ -142,59 +144,59 @@ class SplineSurface(Geometry):
 
 
     def createGrid(self,nu,nv=None):
-        print("Creating grid %s x %s" % (nu,nv))
+        print("Creating grid %s x %s" % (nu, nv))
         if nv is None:
             nv = self.curves[0].nparts
 
-        CA = [ C.approx(ntot=nu) for C in self.curves ]
+        CA = [ C.approx(nseg=nu) for C in self.curves ]
         print("Curves have %s points" % CA[0].coords.shape[0])
         print("There are %s curves" % len(CA))
         if not self.uclosed:
-            nu += 1 
+            nu += 1
         grid = Coords(stack([CAi.coords[:nu] for CAi in CA]))
         print("Created grid %s x %s" % grid.shape[:2])
         return grid
 
 
     def vCurves(self):
-        return [ BezierSpline(self.grid[:,i,:],curl=0.375) for i in range(self.grid.shape[1]) ]
+        return [ BezierSpline(self.grid[:, i,:], curl=0.375) for i in range(self.grid.shape[1]) ]
 
 
     def uCurves(self):
-        return [ BezierSpline(self.grid[i,:,:],curl=0.375) for i in range(self.grid.shape[0]) ]
+        return [ BezierSpline(self.grid[i,:,:], curl=0.375) for i in range(self.grid.shape[0]) ]
 
 
-    def approx(self,nu,nv):
+    def approx(self, nu, nv):
         CL = self.vCurves()
-        draw(CL,color=red)
-        
+        draw(CL, color=red)
+
 
     def actor(self,**kargs):
-        return [ draw(c,**kargs) for c in self.curves ] 
+        return [ draw(c,**kargs) for c in self.curves ]
 
 
 def gridToMesh(grid,closed=False):
     """Convert a Grid Surface to a Quad Mesh"""
     nu = grid.shape[1]
-    nv = grid.shape[0] -1 
-    elems = array([[ 0,1,nu+1,nu ]])
+    nv = grid.shape[0] -1
+    elems = array([[ 0, 1, nu+1, nu ]])
     if closed:
-        elems = concatenate([(elems+i) for i in range(nu-1)],axis=0)
-        elems = concatenate([elems,[[ nu-1,0,nu,2*nu-1]]],axis=0)
+        elems = concatenate([(elems+i) for i in range(nu-1)], axis=0)
+        elems = concatenate([elems, [[ nu-1, 0, nu, 2*nu-1]]], axis=0)
     else:
         #drawNumbers(self.grid.reshape(-1,3))
         #print elems
-        elems = concatenate([(elems+i) for i in range(nu-1)],axis=0)
+        elems = concatenate([(elems+i) for i in range(nu-1)], axis=0)
     #print elems
     #print nu
-    elems = concatenate([(elems+i*nu) for i in range(nv)],axis=0)
+    elems = concatenate([(elems+i*nu) for i in range(nv)], axis=0)
 
-    x = grid.reshape(-1,3)
+    x = grid.reshape(-1, 3)
     #print nu,nv
     #print x.shape
     #print elems.shape
     #print elems.min(),elems.max()
-    M = Mesh(grid.reshape(-1,3),elems)
+    M = Mesh(grid.reshape(-1, 3), elems)
     #print M.elems
     #drawNumbers(M.coords)
     return M
@@ -209,20 +211,20 @@ def createCircles(n):
     """
     C = circle()
     t = arange(n+1) /float(n)
-    CL = [ C.scale([1.,a,0.]) for a in 0.5 + arange(n+1) /float(n) ]
-    CL = [ Ci.rot(a,2) for Ci,a in zip(CL,arange(n+1)/float(n)*45.) ]
-    CL = [ Ci.trl(2,a) for Ci,a in zip(CL,arange(n+1)/float(n)*4.) ]
+    CL = [ C.scale([1., a, 0.]) for a in 0.5 + arange(n+1) /float(n) ]
+    CL = [ Ci.rot(a, 2) for Ci, a in zip(CL, arange(n+1)/float(n)*45.) ]
+    CL = [ Ci.trl(2, a) for Ci, a in zip(CL, arange(n+1)/float(n)*4.) ]
     return CL
 
 
-def createPowerCurves(nu,nv):
+def createPowerCurves(nu, nv):
     """Create a set of BezierSpline power curves.
 
     The curves are transformations of a straight line. The line is
     transformed by two subsequent power law transformations:
     y = a*x**b and z = c*y**d.
     """
-    X = Formex(origin()).replic(nu+1,1.).coords.reshape(-1,3)
+    X = Formex(origin()).replic(nu+1, 1.).coords.reshape(-1, 3)
     C = BezierSpline(X)
     sx = C.dsize()
     sy = 0.5*sx
@@ -231,7 +233,7 @@ def createPowerCurves(nu,nv):
     print(powers)
     powers = exp(powers)
     print(powers)
-    CL = [ C.map1(1,lambda x:sy*(x/sx)**e,0).map1(2,lambda x:sz*(x/sx)**e,1) for e in powers ]
+    CL = [ C.map1(1, lambda x:sy*(x/sx)**e, 0).map1(2, lambda x:sz*(x/sx)**e, 1) for e in powers ]
     return CL
 
 
@@ -240,16 +242,14 @@ def readSplines():
 
     The geometry file splines.pgf is provided with the pyFormex distribution.
     """
-    from geomfile import GeometryFile
     fn = getcfg('datadir')+'/splines.pgf'
-    f = GeometryFile(fn)
-    obj = f.read()
+    obj = readGeomFile(fn)
     T = obj.values()
-    print(len(T))
-    print([len(Si.coords) for Si in T])
+    print("Number of curve: %s" % len(T))
+    print("Curve lengths: %s" % [len(Si.coords) for Si in T])
     return T
 
-    
+
 def removeInvalid(CL):
     """Remove the curves that contain NaN values.
 
@@ -261,7 +261,7 @@ def removeInvalid(CL):
     CL = [ Ci for Ci in CL if not isnan(Ci.coords).any() ]
     nd = len(CL)
     if nc > nd:
-        print("Removed %s invalid curves, leaving %s" % (nc-nd,nd))
+        print("Removed %s invalid curves, leaving %s" % (nc-nd, nd))
     return CL
 
 
@@ -272,8 +272,8 @@ def area(C,nroll=0):
     The nroll parameter may be specified to roll the coordinates
     appropriately.
     """
-    print(nroll)
-    from plugins.section2d import PlaneSection
+    #print(nroll)
+    from pyformex.plugins.section2d import PlaneSection
     F = C.toFormex().rollAxes(nroll)
     S = PlaneSection(F)
     C = S.sectionChar()
@@ -285,21 +285,21 @@ def run():
     clear()
     smoothwire()
 
-    from gui.widgets import simpleInputItem as I
+    from pyformex.gui.widgets import simpleInputItem as I
 
     res = askItems([
-        I('base',itemtype='vradio',choices=[
+        I('base', itemtype='vradio', choices=[
             'Circles and Ellipses',
             'Power Curves',
             'Kinked Artery',
             ]),
-        I('ncurve',value=12,text='Number of spline curves'),
-        I('nu',value=36,text='Number of cells along splines'),
-        I('refine',False),
-        I('nv',value=12,text='Number of cells across splines'),
-        I('align',False),
-        I('aligndir',1),
-        I('alignmax',True),
+        I('ncurve', value=12, text='Number of spline curves'),
+        I('nu', value=36, text='Number of cells along splines'),
+        I('refine', False),
+        I('nv', value=12, text='Number of cells across splines'),
+        I('align', False),
+        I('aligndir', 1),
+        I('alignmax', True),
         ])
 
     if not res:
@@ -312,7 +312,7 @@ def run():
         nroll = 0
         reverse = False
     elif base == 'Power Curves':
-        CL = createPowerCurves(nu,nv)
+        CL = createPowerCurves(nu, nv)
         nroll = 0
         reverse = False
     else:
@@ -325,9 +325,9 @@ def run():
     CL = removeInvalid(CL)
 
     if reverse:
-        areas = [ area(Ci,nroll) for Ci in CL ]
+        areas = [ area(Ci, nroll) for Ci in CL ]
         print(areas)
-        for i,a in enumerate(areas):
+        for i, a in enumerate(areas):
             if a < 0.0:
                 print("Reversing curve %s" % i)
                 CL[i] = CL[i].reverse()
@@ -336,42 +336,43 @@ def run():
         #view('left')
         for Ci in CL:
             #clear()
-            alignCurvePoints(Ci,aligndir,alignmax)
-            draw(Ci.pointsOn()[0],color=green)
+            alignCurvePoints(Ci, aligndir, alignmax)
+            draw(Ci.pointsOn()[0], color=green)
             #zoomAll()
             #pause()
             #return
 
     draw(CL)
     export({'splines':CL})
-    print("Number of points in the curves:",[ Ci.coords.shape[0] for Ci in CL])
+    print("Number of points in the curves:", [ Ci.coords.shape[0] for Ci in CL])
 
-    PL = [Ci.approx(1) for Ci in CL]
+    PL = [Ci.approx(ndiv=1) for Ci in CL]
 
     createPL = False
     if createPL:
         export({'polylines':PL})
-        draw(PL,color=red)
-        print("Number of points in the PolyLines:",[ Ci.coords.shape[0] for Ci in PL])
+        draw(PL, color=red)
+        print("Number of points in the PolyLines:", [ Ci.coords.shape[0] for Ci in PL])
 
 
-    S = SplineSurface(CL,nu)
-    M = gridToMesh(S.grid,closed = S.uclosed)
-    draw(M,color=yellow,bkcolor='steelblue')
+    S = SplineSurface(CL, nu)
+    M = gridToMesh(S.grid, closed = S.uclosed)
+    M.attrib(name='quadsurface',color=yellow, bkcolor='steelblue')
+    draw(M)
     export({'quadsurface':M})
 
     if refine:
         clear()
         print("Refining to %s" % nv)
-        S = SplineSurface(S.vCurves(),nv)
-        N = gridToMesh(S.grid,closed = S.uclosed)
-        draw(N,color=magenta,bkcolor='olive')
+        S = SplineSurface(S.vCurves(), nv)
+        N = gridToMesh(S.grid, closed = S.uclosed)
+        draw(N, color=magenta, bkcolor='olive')
         export({'quadsurface-1':N})
 
     zoomAll()
 
 ##############################################################################
 
-if __name__ == 'draw':
+if __name__ == '__draw__':
     run()
 # End
