@@ -1,11 +1,11 @@
-# $Id: 954dbe2 on Mon Mar 25 13:11:26 2013 +0100 by Benedict Verhegghe $
+# $Id$
 ##
-##  This file is part of pyFormex 0.9.1  (Tue Oct 15 21:05:25 CEST 2013)
+##  This file is part of pyFormex 1.0.5  (Sat Feb 16 10:40:32 CET 2019)
 ##  pyFormex is a tool for generating, manipulating and transforming 3D
 ##  geometrical models by sequences of mathematical operations.
 ##  Home page: http://pyformex.org
 ##  Project page:  http://savannah.nongnu.org/projects/pyformex/
-##  Copyright 2004-2013 (C) Benedict Verhegghe (benedict.verhegghe@ugent.be)
+##  Copyright 2004-2018 (C) Benedict Verhegghe (benedict.verhegghe@ugent.be)
 ##  Distributed under the GNU General Public License version 3 or later.
 ##
 ##  This program is free software: you can redistribute it and/or modify
@@ -29,13 +29,15 @@ applied on the geometry and the stars are place with random position and
 orientation in a confined space. Finally, the stars are drawn with random
 RGB colors.
 """
-from __future__ import print_function
+from __future__ import absolute_import, division, print_function
+from pyformex import zip
+
 _status = 'checked'
 _level = 'beginner'
 _topics = ['geometry']
-_techniques = ['color','random']
+_techniques = ['color', 'random']
 
-from gui.draw import *
+from pyformex.gui.draw import *
 
 nstars = 200 # number of stars
 minpoints = 5 # minimum number of points in the stars
@@ -56,26 +58,26 @@ def star(n,noise=0.,prop=0):
         n = 3
     if n % 2 == 0:
         n += 1
-    f = Formex([[[0,1]]]).rosette(n,(n/2)*360./n).view()
+    f = Formex([[[0, 1]]]).rosette(n, (n//2)*360./n).view()
     if noise != 0.:
         f = f + noise * random.random(f.shape)
-    P = Formex(concatenate([f,f[:1]]))
-    return connect([P,P],bias=[0,1]).setProp(prop)
+    P = Formex(concatenate([f, f[:1]]))
+    return connect([P, P], bias=[0, 1]).setProp(prop)
 
 def run():
     # create random number of points, rotation and translation
-    npts = random.randint(minpoints-1,maxpoints,(nstars,))
-    rot = random.random((nstars,3))
+    npts = random.randint(minpoints-1, maxpoints, (nstars,))
+    rot = random.random((nstars, 3))
     ang = random.random((nstars,)) * maxrot
-    trl = random.random((nstars,3)) * displ
+    trl = random.random((nstars, 3)) * displ
     # create the stars
-    Stars = Formex.concatenate([ star(n,noise,i).rotate(a,r).translate(t) for i,n,a,r,t in zip(range(nstars),npts,ang,rot,trl) ])
+    Stars = Formex.concatenate([ star(n, noise, i).rotate(a, r).translate(t) for i, n, a, r, t in zip(arange(nstars), npts, ang, rot, trl) ])
     # draw them with random colors
-    colors = random.random((nstars,3))
+    colors = random.random((nstars, 3))
     clear()
     flat()
-    draw(Stars,colormap=colors)
+    draw(Stars, colormap=colors)
 
-if __name__ == 'draw':
+if __name__ == '__draw__':
     run()
 # End
