@@ -1,11 +1,11 @@
-# $Id: 954dbe2 on Mon Mar 25 13:11:26 2013 +0100 by Benedict Verhegghe $
+# $Id$
 ##
-##  This file is part of pyFormex 0.9.1  (Tue Oct 15 21:05:25 CEST 2013)
+##  This file is part of pyFormex 1.0.5  (Sat Feb 16 10:40:32 CET 2019)
 ##  pyFormex is a tool for generating, manipulating and transforming 3D
 ##  geometrical models by sequences of mathematical operations.
 ##  Home page: http://pyformex.org
 ##  Project page:  http://savannah.nongnu.org/projects/pyformex/
-##  Copyright 2004-2013 (C) Benedict Verhegghe (benedict.verhegghe@ugent.be)
+##  Copyright 2004-2018 (C) Benedict Verhegghe (benedict.verhegghe@ugent.be)
 ##  Distributed under the GNU General Public License version 3 or later.
 ##
 ##  This program is free software: you can redistribute it and/or modify
@@ -34,16 +34,18 @@ resulting structure can be shown. The parameters can also be saved to a
 file. Finally, the GUi also allows to replay the whole set of saved
 structures.
 """
-from __future__ import print_function
+from __future__ import absolute_import, division, print_function
+
+
 _status = 'checked'
 _level = 'advanced'
 _topic = ['geometry']
-_techniques = ['dialog','persistence']
+_techniques = ['dialog', 'persistence']
 
-from gui.draw import *
-from simple import rectangle
-from utils import NameSequence
-from plugins.imagearray import *
+from pyformex.gui.draw import *
+from pyformex.simple import rectangle
+from pyformex.utils import NameSequence
+from pyformex.plugins.imagearray import *
 
 dialog = None
 savefile = None
@@ -60,28 +62,28 @@ colormap = None
 def createGrid():
     """Create the grid from global parameters"""
     global B
-    nx,ny = grid_size
-    b,h = x_range[1]-x_range[0], y_range[1]-y_range[0]
+    nx, ny = grid_size
+    b, h = x_range[1]-x_range[0], y_range[1]-y_range[0]
     if grid_base.startswith('tri'):
         diag = grid_base[-1]
     else:
         diag = ''
-    B = rectangle(nx,ny,b,h,diag=diag,bias=grid_bias).translate([x_range[0],y_range[0],1.])
+    B = rectangle(nx, ny, b, h, diag=diag, bias=grid_bias).translate([x_range[0], y_range[0], 1.])
     if grid_skewness != 0.0:
-        B = B.shear(0,1,grid_skewness*b*ny/(h*nx))
+        B = B.shear(0, 1, grid_skewness*b*ny/(h*nx))
     if x_clip:
-        B = B.clip(B.test('any',dir=0,min=x_clip[0]+tol*b,max=x_clip[1]-tol*b))
+        B = B.clip(B.test('any', dir=0, min=x_clip[0]+tol*b, max=x_clip[1]-tol*b))
     if y_clip:
-        B = B.clip(B.test('any',dir=1,min=y_clip[0]+tol*h,max=y_clip[1]-tol*h))
+        B = B.clip(B.test('any', dir=1, min=y_clip[0]+tol*h, max=y_clip[1]-tol*h))
     export({grid_name:B})
-    
+
 
 def createSuperShape():
     """Create a super shape from global parameters"""
     global F
     B = pf.PF[grid_name]
-    F = B.superSpherical(n=north_south,e=east_west,k=eggness)
-    if scale == [1.0,1.0,1.0]:
+    F = B.superSpherical(n=north_south, e=east_west, k=eggness)
+    if scale == [1.0, 1.0, 1.0]:
         pass
     else:
         F = F.scale(scale)
@@ -96,24 +98,24 @@ def drawGrid():
     clear()
     wireframe()
     view('front')
-    draw(B,color=grid_color)
-    
+    draw(B, color=grid_color)
+
 
 def drawSuperShape():
     """Show the last created super shape"""
-    global color,colormap
+    global color, colormap
     clear()
     smoothwire()
-    if type(color) == str and color.startswith('file:'):
+    if isinstance(color, str) and color.startswith('file:'):
         print("trying to convert color")
         im = QtGui.QImage('Elevation-800.jpg')
         print(im)
         print(im.isNull())
-        nx,ny = grid_size
-        color,colormap = image2glcolor(im.scaled(nx,ny))[0]
+        nx, ny = grid_size
+        color, colormap = qimage2glcolor(im.scaled(nx, ny))[0]
         print(color.shape)
 
-    draw(F,color=color,colormap=colormap,bkcolor=bkcolor)
+    draw(F, color=color, colormap=colormap, bkcolor=bkcolor)
 
 
 def acceptData():
@@ -143,7 +145,7 @@ def show():
 
 
 def close():
-    global dialog,savefile
+    global dialog, savefile
     if dialog:
         dialog.close()
         dialog = None
@@ -160,15 +162,15 @@ def save():
     if savefile is None:
         filename = askNewFilename(filter="Text files (*.txt)")
         if filename:
-            savefile = open(filename,'a')
+            savefile = open(filename, 'a')
     if savefile:
         print("Saving to file")
         savefile.write('%s\n' % str(dialog.results))
         savefile.flush()
-        globals().update({'grid_name':gname.next(),'name':sname.next(),})
+        globals().update({'grid_name': gname.next(), 'name': sname.next(),})
         if dialog:
            dialog['grid_name'].setValue(grid_name)
-           dialog['name'].setValue(name)            
+           dialog['name'].setValue(name)
 
 
 def replay():
@@ -177,62 +179,64 @@ def replay():
         filename = savefile.name
         savefile.close()
     else:
-        filename = os.path.join(getcfg('datadir'),'supershape.txt')
-        filename = askFilename(cur=filename,filter="Text files (*.txt)")
+        filename = os.path.join(getcfg('datadir'), 'supershape.txt')
+        filename = askFilename(cur=filename, filter="Text files (*.txt)")
     if filename:
-        savefile = open(filename,'r')
+        savefile = open(filename, 'r')
         for line in savefile:
             print(line)
             globals().update(eval(line))
             replayShape()
-        savefile = open(filename,'a')
+        savefile = open(filename, 'a')
 
 
 ################# Dialog
 
 dialog_items = [
-    _G('Grid data',[
-        _I('grid_size',[24,12],),
-        _I('x_range',(-180.,180.),),
-        _I('y_range',(-90.,90.),),
-        _I('grid_base','quad',itemtype='radio',choices=['quad','tri-u','tri-d','tri-x']),
-        _I('grid_bias',0.0,),
-        _I('grid_skewness',0.0,),
-        _I('x_clip',(-360.,360.),),
-        _I('y_clip',(-90.,90.),),
-        _I('grid_name',gname.peek(),),
-        _I('grid_color','blue',),
+    _G('Grid data', [
+        _I('grid_size', [24, 12],),
+        _I('x_range', (-180., 180.),),
+        _I('y_range', (-90., 90.),),
+        _I('grid_base', 'quad', itemtype='radio', choices=['quad', 'tri-u', 'tri-d', 'tri-x']),
+        _I('grid_bias', 0.0,),
+        _I('grid_skewness', 0.0,),
+        _I('x_clip', (-360., 360.),),
+        _I('y_clip', (-90., 90.),),
+        _I('grid_name', gname.peek(),),
+        _I('grid_color', 'blue',),
         ]),
-    _G('Shape data',[
-        _I('north_south',1.0,),
-        _I('east_west',1.0,),
-        _I('eggness',0.0,),
-        _I('scale',[1.,1.,1.],),
-        _I('post','',),
-        _I('name',sname.peek(),),
-        _I('color','red',),
-        _I('bkcolor','yellow',),
+    _G('Shape data', [
+        _I('north_south', 1.0,),
+        _I('east_west', 1.0,),
+        _I('eggness', 0.0,),
+        _I('scale', [1., 1., 1.],),
+        _I('post', '',),
+        _I('name', sname.peek(),),
+        _I('color', 'red',),
+        _I('bkcolor', 'yellow',),
 #        _I('texture','None',),
         ]),
     ]
 
 dialog_actions = [
-    ('Close',close),
-    ('Reset',reset),
-    ('Replay',replay),
-    ('Save',save),
-    ('Grid',showGrid),
-    ('Show',show)
+    ('Close', close),
+    ('Reset', reset),
+    ('Replay', replay),
+    ('Save', save),
+    ('Grid', showGrid),
+    ('Show', show)
     ]
 
 dialog_default = 'Show'
 
 
 def timeOut():
-    show()
-    close()
-    
-        
+    try:
+        show()
+    finally:
+        close()
+
+
 def createDialog():
     global dialog
 
@@ -260,11 +264,11 @@ def run():
     lights(True)
     transparent(False)
     createDialog()
-    setView('eggview',(0.,-30.,0.))
+    setView('eggview', (0., -30., 0.))
     view('eggview')
     dialog.show()
     scriptLock(__file__)
 
-if __name__ == 'draw':
+if __name__ == '__draw__':
     run()
 # End
